      SUBROUTINE SWEEPIN(SWEEP,SWEEPZ,MAX_RAYS,MAX_GATES,NUM_RAYS,RDTAI,
     + AZ_EL,ICALLSWEEPIN,NUMREC,VRRAD,
     + NYQ,ILATERSWEEP,SWEEPSAVE,U,V,W,IMX,JMX,KMX,SX,SY,SZ,
     + OLAT,OLON,XZ,YZ,ZZ,IUSEWIND,EAZM,EEV,TMSWEEP,RRLAT,RRLON,RRA,
     + SMOTIONU0,SMOTIONV0,CENTIME0,PELEV,NTASWEEPER,
     + RDWS,RDWD,RDVWS,NBINSEND,OLATOUT,OLONOUT,TIMES,
     + IWAVE,ISTORMLEVEL,IPLANE,IREALTIME,IVARIATIONAL,I8,IAFTFORE,
     + ISIGMET,ROLLTOL,NDO,IDBZADD,IDBZMASK,G4P3RADMIN,GROUNDADJUST,
     + IATTEN,RADRAT,RADMASK,IAPPLYMASK,IUNDERONLY,
     + JTRAKAZMMIN,JTRAKAZMMAX,SHORTPULSEADDDB,SHORTPULSEADDRADIUS)
C
C DEFINITION OF PARAMETERS PASSED TO AND FROM THIS ROUTINE
C SWEEP--A COMPLETE SWEEP OR SCAN OF DOPPLER RADIAL VELOCITIES
C        OUTPUT TO CALLING PROGRAM IS QUALITY CONTROLLED AND DE-ALIASED
C SWEEPZ--A COMPLETE SWEEP OR SCAN OF RADAR REFLECTIVITY (DBZ)
C         OUTPUT TO CALLING PROGRAM IS QUALITY CONTROLLED
C MAX_RAYS--AZIMUTHAL DIMENSION OF SWEEP AND SWEEPZ--MAX NO. OF RAYS
C MAX_GATES--RADIAL DIMENSION OF SWEEP AND SWEEPZ
C NUM_RAYS--THE ACTUAL NUMBER OF RAYS IN THE SWEEP
C RDTAI--RADIUS (KM) FROM AIRCRAFT/RADAR FOR EACH RADIAL BIN IN RAYS AND SWEEPS
C AZ_EL--TWO DIMENSIONAL ARRAY (2,MAX_RAYS) WHEN I=1 AZ_EL IS THE AZIMUTH,
C        OR IN THIS CASE THE ROTATION ANGLE IN THE COORDINATE SYSTEM OF THE
C        AIRCRAFT TRACK (0/360 IS UP)  WHEN I=2 AZ_EL IS THE TRACK-RELATIVE
C        ELEVATION,OR TILT, THAT IS THE ANGLE WITH THE PLANE NORMAL TO THE
C        FLIGHT TRACK, WITH POSITIVE BEING FORWARD
C        ICALLSWEEPIN = 0 THE FIRST TIME SWEEPIN IS CALLED, AFTER THAT = 1
C NUMREC APPEARS TO NO LONGER BE USED OR NEEDED **LEGACY REMOVE**
C UNFVEL APPEARS TO NO LONGER BE USED OR NEEDED **LEGACY REMOVE**
C VRRAD A SWEEP OF DATA THAT ARE THE PROJECTION OF THE GUESS 
C TMP1 AND TMP2 APPEAR TO NO LONGER BE USED OR NEED **LEGACY REMOVE*
C        PRECIPITATION MOTION FIELD (GUESS WIND PLUS FALLSPEED) ON THE 
C        POINTING DIRECTION OF THE DOPPLER RADIALS
C        USED FOR DE-ALIASING AND QUALITY CONTROL
C JIINDEX AND JINDEX APPEAR NOT TO BE USED OR NEEDED **LEGACY REMOVE**
C NYQ IS INITIALIZED BUT IT DOES NOT APPEAR TO BE USED **LEGACY REMOVE**
C ILATERSWEEP IS SET BUT NEVER USED **LEGACY REMOVE**
C SWEEPSAVE APPEARS TO BE SET TO VALUES IN SWEEP TWICE BUT
C        NEVER USED **LEGACY REMOVE**
C U,V,W RADIAL, TANGENTIAL, AND VERTICAL PRECIPITATION MOTIONS, RESPECTIVELY,
C        IN THE GUESS/BACKGROUND FIELD
C (IMX,JMX,KMX) ARE THE DIMENSIONS OF THE U, V, AND W ARRAYS
C SX,SY,SZ ARE THE RADIAL, AZIMUTHAL, AND VERTICAL GRID RESOLUTIONS IN KM 
C OLAT AND OLON ARE PASSED FROM MAIN AND ARE FOR THE FIRST GUESS FIELD
C    THEY ARE THE LATITUDE AND LONGITUDE OF THE ORIGIN AT CENTIME
C XZ,YZ,ZZ
C IUSEWIND = 1 MEANS USE A BACKGROUND GUESS FIELD, 0 MEANS DON'T
C WHEN IT IS CALLED BY THE WAVENUMBER 0+MEAN ANALYSIS, IUSEWIND WILL BE 0
C WHEN IT IS CALLED BY THE WAVENUMBER 0/1 ANALYSIS IUSEWIND SHOULD BE 1
C      IF THE FIRST PASS ABOVE WAS DONE, BUT 0 IF THERE IS NOT BACKGROUND
C      FIELD, WHICH IS GENERALLY DONE IN MAJOR HURRICANES
C      THE BACKGROUND FIELD WILL BE USED FOR DE-ALIASING
C EAZM IS EARTH-RELATIVE AZIMUTH POINT DIRECTION OF RADIAL, DEFINED POSITIVE
C      FROM EAST
C EEV IS EARTH-RELATIVE ELEVATION DEFINED POSITIE UPWARD FROM HORIZONTAL
C TMSWEEP IS A ONE DIMENSIONAL ARRAY OF TIMES (SECONDS PAST THE MIDNIGHT BEFORE
C      BEFORE TAKEOFF.  THE TIME THE INDIVIDUAL RAY WAS COLLECTED
C RRLAT AND RRLON ARE THE LATITUDES AND LONGITUDES (DEG) OF THE 
C AIRCRAFT (RADAR) AT THE TIME A RAY WAS COLLECTED 
C (THEY ARE ONE-DIMENSIONAL ARRAYS)
C RRA (M) IS THE ONE DIMENSIONAL ARRAY OF RADAR ALTITUDES OF THE AIRCRAFT
C     AT THE TIME THE RAY WAS OBSERVED
C SMOTIONU (SMOTIONU0) AND SMOTIONV (SMOTIONV0) ARE THE ESTIMATES OF EASTWARD
C     AND NORTHWARE STORM MOTION AND IS THE ADVECTION SPEED OF THE COORDINATE
C     SYSTEM
C CENTIME0 IS THE TIME IN SECONDS AFTER MIDNIGHT WHEN THE ORIGIN OF THE 
C     ANALYSIS WAS AT OLAT, OLON, OFTEN OLAT, OLON, AND CENTIME0 ALL COME
C     FROM A FIX OR VORTEX MESSAGE
C PELEV IS THE ANGLE OF THE ANTENNA RELATIVE TO THE PLANE NORMAL TO THE 
C     FUSELAGE, DEFINED POSITIVELY FORWARD
C     Doppler/Reflectivity processing program. 
C NTASWEEPER IS THE NUMBER OF THE SWEEP SINCE THE BEGINNING OF THE 
C     INTERPOLATION INTERVAL
C RDWS AND RDWD ARE THE WIND SPEED (M/S) AND THE DIRECTION THE WIND IS BLOWING
C     FROM IN NAVIGATIONAL COORDINATES AT THE RADAR (AIRCRAFT) IN AN ARRAY
C     CORRESPONDING TO THE INVIDUAL RADIALS
C RDVWS IS THE VERTICAL WIND SPEED (M/S), NOT THE AIRCRAFT VERTICAL MOTION
C NBINSEND IS THE MAXIMUM NUMBER OF OBSERVATIONS ALONG ANY RAY WITHIN THE 
C     SWEEP
C OLATOUT AND OLONOUT ARE PASSED FROM MAIN AND ARE FOR THE OUTPUT WIND
C    ANALYSIS.  THEY ARE THE LATITUDE AND LONGITUDE OF THE ORIGIN AT CENTIME
C TIMES IS THE TIME (SINGLE VALUE) IN SECONDS OF THE LAST OBSERVATION READ
C IWAVE JUST SAYS WHETHER THE INTERPOLATION THAT USES THESE SWEEPS WILL BE 
C    EITHER WAVENUMBER 0 OR WAVENUMBER 1, BUT IWAVE IS NOT REALLY USED IN THIS
C    ROUTINE
C ISTORMLEVEL IS THE MAX NUMBER OF KM FROM THE RADAR THE FIRST GOOD DOPPLER 
C    OBSERVATION CAN BE BEFORE ALL THE DOPPLER VELOCITIES IN THE RADIAL ARE
C    FLAGGED.  THIS IS DONE FOR THE FIRST PASS THROUGH THE DATA
C IPLANE = 1 FOR P3 AND = 2 FOR G-IV
C IREALTIME IS A PLACEHOLDER, IN CASE AT SOME POINT WE WOULD WANT TO USE IT
C    TO HAVE DIFFERENT QC PARAMETERS FOR RESEARCH RUNS THAN FOR REALTIME RUNS
C IVARIATIONAL = 1 IF VARIATIONAL DE-ALIASING WILL BE DONE, OTHERWISE 0
C I8 = 1 IF MAJOR HURRICANE AND = 0 IF NOT--THE PURPOSE OF THIS IS FOR A
C    SPECIAL CASE NOT GENERALLY USED, WHERE TWO PASSES THROUGH THE DATA
C    TO MAKE ANALYSES WITH INCREASING WAVENUMBER FROM 0 TO 1.  THIS IS NOT
C    PART OF THE PRESENT AUTOMATED PROCESSING.  PART OF SOME TESTING AND
C    NOT GENERALLY RECOMMENDED
C IAFTFORE = 1 FOR AFT SWEEP AND 2 FOR FORE SWEEP
C ISIGMET = 5 MEANS RVP5, 8 MEANS RVP8 OR LATER
C ROLLTOL MAXIMUM ROLL ALLOWED TO USE DOPPLER DATA (DEG)
C NDO = 0 IF PRESENT SWEEP IS NOT SKIPPED IN INTERPOLATION.  
C    IF NDO.NE.0 THEN PRESENT SWEEP WILL NOT BE INTERPOLATED
C IDBZADD HOW MANY DB TO ADD TO THE REFLECTIVITY COMING FROM THE INPUT
C    TDR FILES.  IT IS ESSENTIALLY A CALIBRATION CORRECTION
C IDBZMASK HOW MUCH THE DBZ A GIVEN OBSERVATION MUST EXCEED THE MASK VALUE
C    AT THE SAME LOCATION RELATIVE TO THE AIRCRAFT BEFORE THE OBSERVATION
C    IS INTERPOLATED
C G4P3RADMIN VALUE IN KM OF THE RADIUS FROM THE AIRCRAFT WITHIN WHICH
C    ALL DATA ARE FLAGGED
C GROUNDADJUST A SINGLE CONSTANT VALUE IN METERS, OF THE EARTH'S SURFACE
C    FOR THE PURPOSE OF SURFACE REMOVAL OVER A FLAT LAND SURFACE
C    OBVIOUSLY GENERALLY AN APPROXIMATION
C IATTEN FLAGS WHETHER TO CORRECT FOR INTERVENING ATTENUATION "Y" OR "N"
C RADMASK IS A DISTANCE OUT IN KM TO USE MASK
C RADRAT IS A RATIO OF THE MAXIMUM DISTANCE TO APPLY MASK OVER THE 
C        AIRCRAFT ALTITUDE
C IAPPLYMASK FLAGS WHETHER TO APPLY REFLECTIVITY MASK
C     This program reads the radar tapes or fortran-binary copies of them
C     and writes rays of Doppler data and sends them back to routine abcd
C     to be interpolated.
C  Subroutines used: 
C     READTAPE - Reads merged tapes and returns 1 record.
C
C     UNFLDNEW - A version of unfld written since last changes in biglib
C
C     AZIUNFLD - A version of unfolding that demands azimuthal continuity
C 
C  Logical units: 
C     unit(1) - user's terminal 
C     unit(LUNR) - tape drive LU #
C
C     IF LUNRT IS LESS THAN 6 THEN LUNR IS SET TO 80.  THIS IS A SIGNAL TO
C     READTAPE TO READ FROM A FORTRAN BINARY FILE INSTEAD OF A DATA TAPE
C
C     unit(LP) - line printer LU #. (6/7 dot-matrix printer)--THIS IS LEGACY
C       SINCE C IS NOW THE DEFAULT OUTPUT TO THE TERMINAL
C  Variables in Common Block and Main Program:
C     NIX - Flag for end-of-file/end-of-tape.(NIX=-100).
C     NGATE1 - Gate number to start mapping the data, for negative range del.
C     IFLT/INM - Flight date/ project name.
C     STIME/ETIME - Starting/Ending times of disc file in seconds.
C     WD/WS - Wind direction(deg) and Wind Speed (m/s).
C     IVT - flag to calculate  and subtract the terminal velocity (y/n).
C     RAMFL - flag to open and read the ram data with the GPS information.
C     XR,YR,ZR - east-west,north-south,and vertical distances of radar gate
C      from the radar
C 
C AREA1 APPEARS TO BE A "DINOSAUR" BUT IT IS STILL USED TO TRANSFER A FEW
C VARIABLES BETWEEN THIS ROUTINE AND READTAPE
C AREA1 IS NOT IN ANY OTHER ROUTINES THAN THOSE IN SWEEPIN SUBROUTINES
C **LEGACY MODIFY**
C
      COMMON /AREA1/ INM,IFLT,STIME,ETIME,WD,WS,NIX,NGATE1,LP,LUNR,
     +               IVT,RAMFL
      include "hrd_radar_common_blocks_johns.f"
C
C IT APPEARS THAT PARAMS IS ONLY USED TO SEND VARIABLES TO READTAPE AND RAYCOR1
C
      COMMON /PARAMS/ trakazm,trakelev,driftnew,
     +                rot,track,htbb,dbb,thresh,swthresh,dbzrs,ibst(2),
     +                inob(2),ileg,xniq,irsw,maxnbins,v0,
     +                pcor,dcor,rcor,azmcor,elcor,dbzcor,dbzslope,
     +                iunfoldflag,iattenflag,
     +                badstabflag,surfelimflag,echoflag,atmflag
C
C DRIFTNEW COMMUNICATED THROUGH COMMON JUST TO WRITE THE CORRECTED VALUE
C     TO AN OUTPUT FILE
C TRACK IS THE ACTUAL DIRECTION THE AIRCRAFT IS TRAVELING AND NOT THE 
C     DIRECTION THE AIRCRAFT IS POINTED TOWARD (HEADING)
C ROT IS THE AMOUNT THE COORDINATED SYSTEM IS ROTATED FROM THE Y AXIX
C     POINTING NORTH--THE VALUE IN PARAMS DOES NOT APPEAR TO BE USED
C     ALTHOUGH IT IS SET TO ZERO
C HTBB HEIGHT (KM) OF MIDDLE OF MELTING BAND--IT IS USED FROM PARAMS IN RAYCOR1
C     TO REMOVE FALL SPEED FROM DOPPLER RADIAL, ALTHOUGH AT PRESENT IT IS 
C     TURNED OFF AND CONTROLLED FROM WITHIN SWEEPIN
C DBB WIDTH OF THE MELTING BAND (KM)--SEE HTBB ABOVE
C DBZTHRESH IS THE INPUT VALUE TO INDICATE WHAT REFLECTIVITY MUST BE EXCEEDED
C     FOR DATA TO BE INTERPOLATED
C DBZRS IS ATHE RADIUS WHERE DBZTHRESH IS USED AND THEN THE ACTUAL THRESHOLD
C     BY THE AMOUNT INDICATED BY THE INVERSE SQUARES LAW
C SWTHRESH IS THE SPECTRAL WIDTH THAT MUST NOT BE EXCEEDED, BUT THIS IS NOW
C TURNED OFF FOR RVP8 OR LATER SINCE SQI IS DEFINED DIFFERENTLY
C IBST and INOB ARE BOTH DIMENSIONED AT 2 BUT RECENTLY ONLY ONE IS USED
C IBST IS HOW MANY RADIAL BINS TO SKIP BEFORE USING DATA
C INOB IS THE NUMBER OF BINS AVERAGED WHEN USING BARGEN-BROWN DE-ALIASING
C ILEG IS NO LONGER ADDS INFORMATION AND SHOULD BE SET TO ONE AS IT IS IN
C      THE BLOCK DATA STATEMENT BELOW IN THIS FORTRAN FILE
C XNIQ IS THE NYQUIST VELOCITY
C IRSW TELLS WHICH Z-R RELATIONSHIP SHOULD BE USED FOR RAIN FALL SPEED
C      SEE VTERM_NEW
C MAXNBINS TELLS HOW MANY BINS WILL BE PROCESSED IN RAYCOR1, BUT NOW
C      IS JUST SET TO MAX_HRD_DIM, WHICH IS IN AN INCLUDED FILE
C V0 is the FLIGHT-LEVEL WIND PROJECTED ON THE DOPPLER RADIAL DIRECTION
C      AND IS USED TO SEE BARGEN-BROWN ALONG-RADIAL DE-ALIASING PROCESS
C PCOR IS THE PITCH CORRECTION USED TO CORRECT THE AIRCRAFT PITCH VALUE
C      THAT GOES INTO THE MOTION CORRECTION AND DATA LOCATION FOR RADIAL
C      IT IS SINGLE-VALUED AND THE VALUE IS OFTEN FED FROM PCORS WHERE
C      PCORS(1) IS THE AFT CORRECTION AND PCORS(2) IS THE FORE CORRECTION
C DCOR IS LIKE THE PITCH CORRECTION BUT IS FOR DRIFT
C RCOR IS LIKE THE ROLL CORRECTION BUT IS GENERALLY NOT USED (AZMCOR IS USED)
C AZMCOR IS THE CORRECTION TO THE ROTATION ANGLE  BUT OTHERWISE LIKE PCOR
C ELCOR IS THE CORRECTION TO THE TILT (OR ELEVATION) OF THE ANTENNA, THAT 
C      IS THE ANGLE BETWEEN THE POINTING DIRECTION AND THE PLANE NORMAL TO
C      THE FUSELAGE
C DBZCOR IS HOW MANY DB TO ADD TO THE REFLECTIVITY VALUE IN THE DATA INPUT
C      (NO CORRECTION WOULD BE DBZCOR=0)
C DBZSLOPE IS THE SLOPE OF THE DBZ CORRECTION (DBZSLOPE=1 WOULD BE NO CORR)
C IUNFOLDFLAG MUST = 1 if RAYCOR1 DOES AN INITIAL BARGEN-BROWN UNFOLD ON RAY
C IATTENFLAG MUST = 1 IF RAYCOR1 DOES AN ALONG RAY INTERVENING-ATTENUATION
C      CORRECTION
C BADSTABFLAG = .TRUE. IF DOPPLER DATA ARE CORRECTED BECAUSE ANTENNA  DOES NOT
C      POINT PERFECTLY NORMAL TO THE FLIGHT TRACK.  THIS HAS BEEN ALMOST ALWAYS
C      SET TO TRUE AND IS SET TRUE IN THE BLOCK DATA SECTION BELOW
C SURFELIMFLAG = .TRUE. IF RAYCOR1 SHOULD FLAG DATA BELOW SEA SURFACE
C ECHOFLAG = .TRUE. IF RAYCOR1 ATTEMPTS TO REMOVE ECHO RING AROUND AIRCRAFT 
C ATMFLAG = .TRUE. THEN ATMOSPHERIC ATTENUATION CORRECTION IS DONE IN RAYCOR1 
C      NOTE CHECK TO SEE IF THIS CORRECTION HAS BEEN UNCOMMENTED.  OTHERWISE
C      THIS CORRECTION IS NOT DONE
C
C TSEARCH IS ONLY USED TO PASS PARAMETERS TO RADARDISCREAD1, WHICH READS
C      RVP5 DATA
C 
      common /tsearch/ kountrec,firstsweep(2),keylf(1024,2),
     +                 keyta(4096,2),
     +                 numsweep(2),itimex(2),lastpoint(2),
     +                 iheadertime,ioldsweep(2),kwords,nwords,krays,
     +                 ibuf(2048)
C
C KOUNTREC COUNTS NUMBER OF RECORDS READ SINCE LAST DATA HEADER IN RVP5
C FIRSTSWEEP(2) CONTAINS THE SWEEP NUMBERS OF THE FIRST LF AND TA SWEEP
C      AFTER A NEW HEADER
C KEYLF CONTAINS THE RECORD NUMBER AND TIME OF THE START OF EACH LF SWEEP
C KEYTA CONTAINS THE RECORD NUMBER AND TIME OF THE START OF EACH TA SWEEP
C NUMSWEEP - CURRENT SWEEP NUMBER FOR LF AND TA
C ITIMEX - ARRAY HOLDING THE TIME IN SECONDS FOR LF AND TA
C LASTPOINT LAST POINTER ON KEYLF AND KEYTA
C IHEADERTIME HEADER TIME IN SECONDS
C IOLDSWEEP PREVIOUS SWEEP NUMBER FOR LF AND TA
C KWORDS POINTER IN DATA RECORD
C NWORDS RECORD SIZE IN BYTES
C KRAYS POINTER IN THE RAY HEADER
C IBUF IS THE BUFFER FOR READING IN RVP5 DATA
C 
C RVP8_DATE_TIME CANNOT BE FOUND OUTSIDE SWEEPIN SO IT PROBABLY ISN'T
C      NECESSARY SO LONG AS THERE IS A SAVE COMMAND.  I'M NOT SURE IF IT IS
C      NECESSARY EVEN WITHOUT SAVE
C
      common /rvp8_date_time/rvp8year,rvp8month,rvp8day,
     +  rvp8h,rvp8m,rvp8s
      integer rvp8year,rvp8month,rvp8day,rvp8h,rvp8m,rvp8s
C
C SQIEXISTS CHECKS TO SEE WHETHER BACKDOOR FILE "changesqi" EXISTS
C
      LOGICAL SHORTPULSEADDEXISTS
      REAL SHORTPULSEADDDB,SHORTPULSEADDRADIUS
      LOGICAL DESPECKLEEXISTS,IBSTFILEEXISTS,ZRDIFFMAXEXISTS
      CHARACTER*1 DESPECKLEYESNO
      LOGICAL SQIEXISTS
      LOGICAL CHANGEMELTBANDEXISTS
      LOGICAL ALLOWEDVRDIFFERENCEEXISTS
      LOGICAL badstabflag, surfelimflag, echoflag, atmflag
C
C ICOL AND JCOL ARE WORK DIRECTORIES IN SUBROUTINE CONTIG AND MUST BE 
C      EXPLICITLY DIMENSIONED HERE. (MAX_HRD_DIM) IS A CONSTANT DEFINED
C      IN "hrd_radar_common_blocks_johns.f"
C
      INTEGER ICOL(MAX_HRD_DIM,800),JCOL(MAX_HRD_DIM,800)
C
C THE FOLLOWING "ONE" VARIABLES SAVE THE LAST RADIAL READ BY SWEEPIN BEFORE
C     RETURNING TO ABCD, WHICH WILL ACTUALLY BE THE FIRST RAY OF DATA USED
C     IN THE NEXT SWEEP OF DATA
C RDTAONE RADIUS VECTOR FOR FIRST RAY IN NEW SWEEP
C
      REAL RDTAONE(MAX_HRD_DIM)
C
C TIMEONE TIME OF FIRST RAY IN NEW SWEEP
C BINONE "RAW" VELOCITIES IN FIRST RAY IN NEW SWEEP
C RAONE RADAR ALTITUDE (M) DURING FIRST RAY IN NEW SWEEP
C AZMONE EARTH RELATIVE AZIMUTH OF FIRST RAY IN NEW SWEEP
C EVONE EARTH RELATIVE ELEVATION OF FIRST RAY IN NEW SWEEP
C REFONE REFLECTIVITIES IN FIRST RAY IN NEW SWEEP
C
      REAL TIMEONE,RLATONE,RLONONE,RAONE,AZMONE,EVONE
C
C RDWD AND RDWS ARE FLIGHT-LEVEL WIND DIRECTION AND SPEED FOR EACH RAY
C RDVGS IS FLIGHT-LEVEL VERTICAL GROUND SPEED (OF AIRCRAFT) FOR EACH RAY
C RDGSE AND RDGSN ARE FLIGHT-LEVEL EAST-WEST AND NORTH-SOUTH SPEEDS OF AIRCRAFT
C       FOR EACH RAY
C
      LOGICAL ALTITUDERINGEXISTS
      CHARACTER ALTRINGREMOVE*1
      REAL BINONE(MAX_HRD_DIM),REFONE(MAX_HRD_DIM),RDWD(800),RDWS(800)
      REAL RDVGS(800),RDGSE(800),RDGSN(800)
C
C DV0(800) **LEGACY REMOVE** SEE DV0 DISCUSSION BELOW
C
C OLDTIME IS USED TO DETERMINE IF A NEW MINUTE HAS PASSED AND IF SO TO PRINT
C      OUT CERTAIN VARIABLES.  AT THE MOMENT THAT PRIBTOUT IS COMMENTED OUT
C IITEST, JJTEST AND IKEEP ARE USED TO DESPECKLE THE DATA
C IITEST AND JJTEST ARE USED TO DETERMINE WHICH POINTS WITHIN A 5X5 SUBSET
C      OF A SWEEP HAVE UNFLAGGED DATA
C IKEEP DETERMINES WHETHER A PARTICULAR GRID POINT WILL BE KEPT RATHER THAN 
C      FLAGGED.  0 = FLAG AND 1 = KEEP
      INTEGER OLDTIME,IITEST(5),JJTEST(5),IKEEP(MAX_HRD_DIM,MAX_RAYS)
C
C AVGDBZ1 AND AVGDBZ2 ARE MASKED DATA
C
      REAL AVGDBZ1(610,360),AVGDBZ2(610,360)
C
C RADSWEEP IS THE RADIUS OF EACH GRID POINT FROM THE AIRCRAFT IN A SWEEP
C BINOUT IS THE REFLECTIVITY CORRECTED FOR ATTENUATION.  IT IS USED ONLY
C      FOR QC AND FOR DETERMINING WHETHER TO MASK A GRID POINT
      REAL RADSWEEP(MAX_HRD_DIM,800),BINOUT(MAX_HRD_DIM)
C
C CAIRCRAFT = H, I, N FOR NOAA42, NOAA43, AND NOAA49 RESPECTIVELY
C CCHECK IS READ FROM A FLIGHT ID AND USED TO DETERMINE WHETHER NAIRCRAFT
C      = 42 (NOAA42), 43 (NOAA43), OR 49 (NOAA49)
C      IT LOOKS, HOWEVER, LIKE IT IS NEVER USED, AND H, I, OR N ARE USED
C      DIRECTLY
      CHARACTER*1 CAIRCRAFT(3),CCHECK
C
C IFLTCHK IS THE FIRST SEVEN CHARACTERS OF THE FLIGHT ID FROM DATA FILE
C IFLTCHK2 IS THE FIRST SEVEN CHARACTERS OF THE FLIGHT ID FROM JOBFILE
C
      CHARACTER*7 IFLTCHK,IFLTCHK2
C
C CHARDATE, CHARTIME, AND CHARZONE ARE DATE AND TIME FOR SYSTEM PROCESSOR
C     AND THEY ARE USED TO REPORT TIME OF PROCESSING
C TIMEVALUES ARE ALSO FROM THE SYSTEM PROCESSOR AND THEY ARE USED TO REPORT
C     THE TIME OF PROCESSING
C
      CHARACTER CHARDATE*8,CHARTIME*10,CHARZONE*5
      INTEGER TIMEVALUES(8)
C
C IT APPEARS IBF1 AND IBF2 ARE NO LONGER USED.  THEY ARE COMMENTED AND IF
C      THEY MAKE NO DIFFERENCE THE NEXT LINE WILL BE REMOVED **LEGACY REMOVE**
C
C      INTEGER*2 IBF1,IBF2
C
C IT APPEARS THE NEXT TWO VARIABLES ARE NOT (NO LONGER) USED AND PROBABLY
C      CAN BE REMOVED **LEGACY REMOVE**--UNFVEL AND NDRIFTCORSUM
C
C      REAL UNFVEL(MAX_HRD_DIM,800),NDRIFTCORSUM
C      REAL TMP1(MAX_HRD_DIM,800),TMP2(MAX_HRD_DIM,800)
C      INTEGER JINDEX(MAX_HRD_DIM,800),JIINDEX(MAX_HRD_DIM,800)
      REAL RDVWS(800)
      REAL SWEEP(MAX_HRD_DIM,MAX_RAYS),RDTAI(MAX_HRD_DIM),AZ_EL(2,800)
C
C RDTAIIN IS A WORKING DIRECTORY FOR RANGE FROM RADAR
C
      REAL PELEV(800),RDTAIIN(MAX_HRD_DIM)
C
C VROUT AND ZOUT ARE WORKING DIRECTORIES IN DEFRECKLEBOTH
C BUT SWEEP AND SWEEPZ ARE BOTH INPUT AND OUTPUT FROM DEFRECKLEBOTH
C
      REAL VROUT(MAX_HRD_DIM,800),ZOUT(MAX_HRD_DIM,800)
C
C PAZM IS THE ROTATION ANGLE OF THE RADAR RELATIVE TO THE AIRFRAME WITH
C 0 DEGREES BEING UP AND THE ANGLE IS MEASURED CLOCKWISE LOOKING FORWARD
C RADIIATTEN IS A WORKING DIRECTORY WITHIN INTERVENATTEN2
C
      REAL PAZM(800),RADIIATTEN(MAX_HRD_DIM)
      REAL SWEEPSAVE(MAX_HRD_DIM,800)
      REAL PCORS(2),DCORS(2),RCORS(2)
      REAL AZMCORS(2),RDELCORTAS(2),ELCORS(2)
C
C RAY AND URAY CONTAIN DOPPLER RADIAL VELOCITIES WITH RAY GENERALLY BEING
C AN INPUT TO A BARGEN-BROWN DE-ALISING AND URAY BEING THE UNFOLDED OR
C      DE-ALIASED RAY
C
      REAL RAY(MAX_HRD_DIM),URAY(MAX_HRD_DIM),V0SAVE(800)
      REAL VRRAD(MAX_HRD_DIM,800),NYQ(MAX_HRD_DIM,800)
C
C SWIDTH SET TO SPECTRAL WIDTH (ACTUALLY SQI AS USUALLY SET UP) BUT
C      THEN NEVER USED **LEGACY REMOVE**
C
      REAL SWIDTH(MAX_HRD_DIM,800)
C
C SWONE NEVER SET
C
C      REAL SWONE(MAX_HRD_DIM)
C
C XRSWEEP, ZRSWEEP, AND ZRSWEEP ARE THE X, Y, AND Z COORDINATES RELATIVE
C      TO THE ORIGIN, OR THE CORRESPONDING ELEMENTS OF THE REFLECTIVITY
C      AND VELOCITY SWEEPS 
C
      REAL XRSWEEP(MAX_HRD_DIM,800),YRSWEEP(MAX_HRD_DIM,800)
      REAL ZRSWEEP(MAX_HRD_DIM,800)
C
C XRMIN, YRMIN, ZRMIN, XRMAX, YRMAX, ZRMAX ARE ALL NEVER SET
C      **LEGACY REMOVE**
C
C      REAL XRMIN(MAX_HRD_DIM,800),YRMIN(MAX_HRD_DIM,800)
C      REAL ZRMIN(MAX_HRD_DIM,800)
C      REAL XRMAX(MAX_HRD_DIM,800),YRMAX(MAX_HRD_DIM,800)
C      REAL ZRMAX(MAX_HRD_DIM,800)
C
C AZMIN AND AZMAX NEVER SET
C      **LEGACY REMOVE**
C      REAL AZMIN(MAX_HRD_DIM,800),AZMAX(MAX_HRD_DIM,800)
      REAL SWEEPZ(MAX_HRD_DIM,MAX_RAYS)
C
C     ZDIFF NEVER SET **LEGACY REMOVE**
C     REAL ZDIFF(MAX_HRD_DIM,800)
C 
C LOOKS LIKE ZMIN AND ZMAX NEVER USED **LEGACY REMOVE**
C
      REAL ZMIN(MAX_HRD_DIM,800),ZMAX(MAX_HRD_DIM,800)
C
C XR, ZR, AND ZR ARE THE X, Y, AND Z COORDINATES RELATIVE TO THE SAME
C ELEMENTS OF BIN AND REF
C
      REAL XR(MAX_HRD_DIM),YR(MAX_HRD_DIM),ZR(MAX_HRD_DIM)
      REAL U(IMX,JMX,KMX),V(IMX,JMX,KMX),W(IMX,JMX,KMX)
      REAL EAZM(800),EEV(800),RRLAT(800),RRLON(800),RRA(800)
C
C TRACKSTORE AND HEADSTORE ARE THE STORED VALUES OF TRACK AND HEADING
C      FOR ALL THE RAYS IN A SWEEP
C
      REAL TRACKSTORE(800),HEADSTORE(800)
      REAL TMSWEEP(800)
C
C AZ_EL IS USED FOR SORTING BY AZIMUTH. AZEL IS NEEDED FOR ALSO SORTING
C      AZ_EL
C
      REAL AZEL(2,800)
C
C ISEG, ISEGB, ISEGE ARE USED IN AZIMUTHAL UNFOLDING IN AZIUNFLD AND AZIUNFLDG
C
      INTEGER ISEG(MAX_HRD_DIM,800),ISEGB(MAX_HRD_DIM,800)
      INTEGER ISEGE(MAX_HRD_DIM,800)
C
C CDUMMY IS USED TO READ IN A LINE (AS FROM THE jobfile_radar) BUT NOT USE IT
C
      CHARACTER CDUMMY*80
C
C DUMMYREAD IS LIKE CDUMMY
C
      CHARACTER DUMMYREAD*1
C
C IFLT IS THE CLASSIC FLIGHT ID YYMMDDAI AND INM IS A 12-CHARACTER PROJECT
C      NAME WHICH IS OFTEN THE NAME OF THE STORM
C
      CHARACTER IFLT*8, INM*12
C
C TAPE IS A VESTIGIAL VARIALBE GOING BACK TO THE READING OF PHYSICAL TAPES
C RAMFL IS Y IF A RAMSFILE IS THE BE READ AND N IF NOT
C IVT IS Y IS RAYCOR1 REMOVES FALL SPEED PROJECTION FOR DOPPLER VELOCITIES
C IATTEN IS Y IF THE RADAR REFLECTIVITY IS TO BE CORRECTED FOR INTERVENING
C      ATTENUATION USING THE ALONG-RAY ATTENUATION METHOD
C IYES IS NOT LONGER USED **LEGACY REMOVE**
C
      CHARACTER *1 TAPE, RAMFL, IVT, IATTEN, IYES
C
C NAMERAM IS THE NAME OF THE RAMS FILE USED IN OPENRAMFILE
C IFILE IS AN INPUT FILE NAME (SUCH AS 'jobfile_radar')
C NAMEO IS THE NAME OF FILE THAT IS NOT PRESENTLY USED **LEGACY REMOVE**
C RADARFILE A FILE TO BE OPENED FOR RVP5 AND THE DIRECTORY WHERE SWEEP FILES
C      ARE LOCATED IN RVP8 OR LATER
      CHARACTER *80 NAMERAM, IFILE, NAMEO
      CHARACTER*80 RADARFILE
C
C RADARFILEOUT NOT USED OR SET **LEGACY REMOVE**
C
C      CHARACTER*80 RADARFILEOUT
C
C BIN1 AND REF1 ARE SET BY RAYCOR1 AND NEVER USED **LEGACY REMOVE?**
C
      DIMENSION BIN(MAX_HRD_DIM),REF(MAX_HRD_DIM),BIN1(MAX_HRD_DIM)
      DIMENSION REF1(MAX_HRD_DIM)
C
C PERHAPS WHAT IS SAVED CAN BE MADE SELECTIVE AGAIN, BUT FOR NOW ALL IS SAVED
C FOR THE NEXT RETURN TO THIS ROUTINE
C
      SAVE
C
c      SAVE ISWEEPCHECK,BINONE,REFONE,TIMEONE,RLATONE,RLONONE
c      SAVE RAONE,AZMONE,EVONE,RCAZM,AZELONE,AZELTWO,PELEVONE
c      SAVE ICONSERVE,ITAPEOPEN,RDTAIIN,RADTEST,V0ONE,PAZMONE
c      SAVE OLDTIME,ITIMECHECK,SWONE
c      SAVE PCORS,DCORS,RCORS,AZMCORS,RDELCORTAS,ELCORS
c      SAVE TIME,TIMES
c      SAVE IHS,IHE,IMS,IME,ISS,ISE
C
C ATTENUATION FACTOR AT1 AND AT2 ARE USED HERE ONLY TO LIST THEIR VALUES
C
      DATA AT1/5.33E-5/, AT2/0.889/
C
C DEBUG STATEMENTS
C
      write(6,*)'entered newsweepread'
      write(6,*)'IDBZADD,IDBZMASK = ',IDBZADD,IDBZMASK
      write(6,*)'iapplymask = ',iapplymask
c      pause
C
C H, I, AND N ARE THE TRADITIONAL DESIGNATIONS FOR NOAA42, NOAA43, AND NOAA49,
C RESPECTIVELY GIVEN BY A IN YYYYMMDDAI OR YYMMDDAI FLIGHT ID'S
C
 4275 CAIRCRAFT(1)='H'
      CAIRCRAFT(2)='I'
      CAIRCRAFT(3)='N'
      IMAXBINS=MAX_GATES
      JMAXRAYS=800
C      IF(IAPPLYMASK.EQ.1.AND.IUNDERONLY.EQ.1)THEN
C         JTRAKAZMMIN=135
C         JTRAKAZMMAX=225
C      ELSE
C         JTRAKAZMMIN=-1
C         JTRAKAZMMAX=2001
C      ENDIF
      WRITE(6,*)'JTRAKAZMMIN,JTRAKAZMMAX = ',JTRAKAZMMIN,JTRAKAZMMAX
C
C NO OF BINS IS DIFFERENT FOR EACH RAY OF DATA IN RVP8 OR LATER, SO NBINSMAX
C WILL BE THE MAXIMUM NUMBER OF BINS IN ANY RAY OF THE SWEEP
C
      NBINSMAX=0
C
C RADSAVERTEST WILL BE USED TO DETERMINE WHETHER A GAP IN A RADIAL OF DATA
C IS TOO GREAT TO DE-ALIAS BEYOND THAT GAP WHEN USING BARGEN-BROWN ALONG-RAY
C DE-ALIASING ONLY
C
      RADSAVERTEST=FLOAT(ISTORMLEVEL)
      RADSAVERTEST2=2.*RADSAVERTEST
c      WRITE(6,*)'MAX_GATES = ',MAX_GATES
c      PAUSE
       IF(IUSEWIND.EQ.1)THEN
        WRITE(6,*)'IUSEWIND = ',IUSEWIND
c        PAUSE
       ELSE
        WRITE(6,*)'IUSEWIND = ',IUSEWIND
c        PAUSE
       ENDIF
C
C IF IUSEWIND=1 OLAT AND OLON HAVE BEEN SET BY FIRST GUESS BACKGROUND FIELD
C
      IF(IUSEWIND.EQ.1)THEN
       SMOTIONU=SMOTIONU0
       SMOTIONV=SMOTIONV0
       CENTIME=CENTIME0
      ELSE
       OLAT=OLATOUT
       OLON=OLONOUT
       CENTIME=CENTIME0
      ENDIF
C
C FOR NOW, NO MATTER WHAT, COMPOSITE FIELD MOTION IS SET TO THE INPUT VALUES
C     TO THIS ROUTINE
C
      SMOTIONU=SMOTIONU0
      SMOTIONV=SMOTIONV0
C
C RESET THE RAY BY RAY VALUES OF WINDSPEED (RDWS), WIND DIRECTION (RDWD),
C       AND VERTICAL WIND SPEED (RDVWS)
C
      DO I=1,MAX_RAYS
       RDWS(I)=-999.9
       RDWD(I)=-999.9
       RDVWS(I)=-999.9
      ENDDO
C
C NEXT THREE LINES CAN BE COMMENTED SINCE NO LONGER USED **LEGACY REMOVE**
C
C      DRIFTCORSUMAVG=-888.88
C      DRIFTCORSUM=0.
C      NDRIFTCORSUM=0
C
C THE FOLLOWING WILL ONLY BE DONE ON THE FIRST CALL TO THIS ROUTINE
C
      WRITE(6,*)'SWEEP SHORTPULSEADDDB, SHORTPULSEADDRADIUS = ',
     +           SHORTPULSEADDDB, SHORTPULSEADDRADIUS
c      PAUSE
      IF(ICALLSWEEPIN.EQ.0)THEN
       OPEN(71,FILE='positionstuff')
       INQUIRE(FILE='maskzrdiffmax',EXIST=ZRDIFFMAXEXISTS)
       IF(ZRDIFFMAXEXISTS)THEN
          OPEN(88,FILE='maskzrdiffmax')
          READ(88,*)ZRDIFFMAX
          READ(88,*)ZSPECKLEMAX
          CLOSE(88)
          WRITE(6,'(A,F7.2)')'ZRDIFFMAX WAS READ AND IS',ZRDIFFMAX
       ELSE
          ZRDIFFMAX=100.
          ZSPECKLEMAX=100.
          WRITE(6,'(A,F7.2)')'ZRDIFFMAX WAS NOT READ AND IS',ZRDIFFMAX
       ENDIF
       INQUIRE(FILE='allowedvrdifference',
     +               EXIST=ALLOWEDVRDIFFERENCEEXISTS)
       IF(ALLOWEDVRDIFFERENCEEXISTS)THEN
          WRITE(6,*)'allowedvrdifference file exists'
          OPEN(88,FILE='allowedvrdifference')
          READ(88,*)VNFRACTION
          VN=XNIQTA
          VNALLOWED=VNFRACTION*VN
          WRITE(6,7457)VNALLOWED
 7457     FORMAT(
     + 'MAXIMUM VR DIFFERENCE IN M/S ALLOWED AT FIRST BINS = ',F10.2)
       ELSE
          VNFRACTION=1.
       ENDIF
       WRITE(6,7456)VNFRACTION
 7456     FORMAT(
     + 'MAXIMUM VR FRACTION DIFFERENCE ALLOWED AT FIRST BINS = ',F10.2)
       INQUIRE(FILE='altitude_ring_remove',EXIST=ALTITUDERINGEXISTS)
       IF(ALTITUDERINGEXISTS)THEN
          WRITE(6,*)'ALTITUDE RING FILE EXISTS'
       ELSE
          WRITE(6,*)'ALTITUDE RING FILE DOES NOT EXIST'
       ENDIF
       IF(ALTITUDERINGEXISTS)THEN
          WRITE(6,*)'OPENING altitude_ring_remove'
          OPEN(88,FILE='altitude_ring_remove')
          READ(88,'(A1)')ALTRINGREMOVE
          IF(ALTRINGREMOVE.EQ.'Y'.OR.ALTRINGREMOVE.EQ.'y')THEN
             IALTRINGREMOVE=1
          ELSE
             IALTRINGREMOVE=0
          ENDIF
          CLOSE(88)
       ELSE
          IALTRINGREMOVE=0
       ENDIF
       IF(IALTRINGREMOVE.NE.1)THEN
          WRITE(6,*)'ALTITUDE RING NOT REMOVED'
       ELSE
          WRITE(6,*)'ALTITUDE RING REMOVED'
       ENDIF
       INQUIRE(FILE='despeckleyesno',EXIST=DESPECKLEEXISTS)
       IF(DESPECKLEEXISTS)THEN
          OPEN(37,FILE='despeckleyesno')
          READ(37,'(A1)')DESPECKLEYESNO
          IF(DESPECKLEYESNO.EQ.'0'.OR.DESPECKLEYESNO.EQ.'N'.OR.
     +       DESPECKLEYESNO.EQ.'n')THEN
             IDESPECKLE=0
             IOLDDESPECKLE=0
          ELSEIF(DESPECKLEYESNO.EQ.'O'.OR.DESPECKLEYESNO.EQ.'o')THEN
             READ(37,*)NUMTIMES
             READ(37,*)NUMCONTIG
             IOLDDESPECKLE=1
             IDESPECKLE=1
          ELSE
             READ(37,*)NUMTIMES
             READ(37,*)NUMCONTIG
             IOLDDESPECKLE=0
             IDESPECKLE=1
          ENDIF
          CLOSE(37)
       ELSE
          IDESPECKLE=1
          NUMTIMES=3
          NUMCONTIG=3
          IOLDDESPECKLE=1
       ENDIF
c       IDESPECKLE=2
C
C IT APPEARS THAT THE ONLY WAY IFILECCHECK IS USED IS TO INITIALLY LOCATE
C       THE CORRECT FILE ON A TAPE TO BEGIN PROCESSING
C
       IFILECHECK=0
       RADTEST=-1.
       IFRANCE=0
       IFLIGHTCHECK=0
C
C NSUMRIGHT, SUMRIGHT, NSUMLEFT AND RSUMLEFT DO NOT APPEAR TO BE USED ANYMORE
C       EVEN THOUGH THEY ARE SET AND COMPUTED  **LEGACY REMOVE?**
C
       NSUMRIGHT=0
       SUMRIGHT=0.
       NSUMLEFT=0
       RSUMLEFT=0.
C
C IF THIS IS A FIRST CALL A FILE IS OPEN WHICH WILL CONTAIN FLIGHT LEVEL
C       DATA ASSOCIATED WITH THE DOPPLER RADIALS IN THE SWEEPS
C       AFT inoutradazi_aft.txt, FORE inoutradazi_fore.txt, 
C       OR BOTH (NOAA PARABOLIC) inoutradazi.txt
C
       IF(IAFTFORE.EQ.1)THEN
        OPEN(95,FILE='inoutradazi_aft.txt')
       ELSEIF(IAFTFORE.EQ.2)THEN
        OPEN(95,FILE='inoutradazi_fore.txt')
       ELSE
        OPEN(95,FILE='inoutradazi.txt')
       ENDIF
      ELSE
       IFILECHECK=1
       IFLIGHTCHECK=1
      ENDIF
      deg2rad = acos(-1.0) / 180.0
      rad2deg = 1.0 / deg2rad
      IF(IPLANE.EQ.1)THEN
       half_beam_ta = 1.35 ! degrees, vertical, G-IV
      ELSE
       half_beam_ta = 1.00 ! degrees, vertical, P3
      ENDIF
      half_beam_lf = 2.05 ! degrees, vertical
      beam_wid = 2.0 * half_beam_ta
      WFLAG=-1.0E+10
C 
C DOPPLER processing program
c      write(6,*)'icallsweepin = ',icallsweepin
      ISWEEPSET=2
      SWEEPOLD=0.
      NUM_RAYS=0
      DO I=1,MAX_GATES
       DO J=1,800
        SWEEP(I,J)=-888.8
        SWEEPZ(I,J)=-32.0
       ENDDO
      ENDDO
c      write(6,*)'imx,jmx,kmx = ',imx,jmx,kmx
c      write(6,*)'sx,sy,sz = ',sx,sy,sz
c      write(6,*)'xz,yz,zz = ',xz,yz,zz
      IF(ICALLSWEEPIN.EQ.0)THEN
       DO I=1,MAX_HRD_DIM
        RDTAIIN(I)=1000.
       ENDDO
      ENDIF
      IF(ICALLSWEEPIN.EQ.1)THEN
       NUM_RAYS=0
c       IF(IYEARTEST.GE.2017.AND.IPLANE.EQ.1)THEN
c        IF(IAFTFORE.EQ.1)THEN
c         OPEN(58,FILE='aft.mask')
c        ELSE
c         OPEN(58,FILE='fore.mask')
c        ENDIF
c        DO J=1,360
c         READ(58,'(A)')CDUMMY
c         READ(58,'(A)')CDUMMY
c         READ(58,*)(AVGDBZ1(I,J),I=1,610)
c         READ(58,'(A)')CDUMMY
c         READ(58,*)(AVGDBZ2(I,J),I=1,610)
c        DO I=66,610
c            AVGDBZ2(I,J)=-60.
c         ENDDO
c        ENDDO
c        CLOSE(58)
c       ENDIF
      ENDIF
      IF(ICALLSWEEPIN.EQ.0)THEN
       ISWEEPSET=0
       open(64,file='driftcor')
c       OPEN(1,FILE='/dev/null')
       IF(IUSEWIND.NE.1)THEN
        ICONSERVE=1
       ELSE
        ICONSERVE=0
       ENDIF
c       WRITE(6,*)'Enter job file name'
c       READ(5,'(A80)')IFILE
       IFILE='jobfile_radar'
       OPEN(98,FILE=IFILE,IOSTAT=IERR,ERR=998,STATUS='OLD')
C The Following Parameters are read from input file  - ncepwrite_file.job
C Read Flight ID and Storm Name
       READ(98,'(A8)')IFLT
       READ(IFLT,'(I2)')IYEAR
       IF(IYEAR.LT.50)THEN
          IYEARTAPE=IYEAR+2000
       ELSE
          IYEARTAPE=IYEAR+1900
       ENDIF
       IYEARTEST=IYEARTAPE
       READ(98,'(A12)')INM
       READ(IFLT,'(I6)')IDAYTEST
       DO JIJ=1,4
        READ(98,'(A1)')DUMMYREAD
       ENDDO
       READ(98,*)SXSX,SYSY,SZSZ
       READ(98,*)XZXZ,YZYZ,ZZZZ
       READ(98,*)IMXIMX,JMXJMX,KMXKMX
C      READ(98,'(A8,1X,A12)',IOSTAT=IERR,ERR=999) IFLT,INM
C Read Line Printer LU#, Tape LU# & flag for printing parameters
       LP=6
       READ(98,*)LUNRT
C       READ(315,'(I2,1X,I2)',IOSTAT=IERR,ERR=999) LP,LUNRT
C1       READ(315,*)ITAPEOPEN
C       IF(LUNRT.GT.6)THEN
C        WRITE(6,*)'YOU ARE USING TAPE DRIVE ',LUNRT
C        WRITE(6,*)'IF CORRECT ENTER 1, OTHERWISE 0'
C        READ(5,*)ILUNRT
C        IF(ILUNRT.NE.1)THEN
C         WRITE(6,*)'REENTER TAPE DRIVE UNIT NUMBER'
C         WRITE(6,*)'IF YOU MEANT TO USE A FILE ENTER 0'
C         READ(5,*)LUNRT
C        ENDIF
C       ELSE
C        WRITE(6,*)'YOU WILL BE READING FROM A RADAR FILE'
C       ENDIF
C       READ(315,'(A80)')RADARFILE
       WRITE(LP,'(1X,"NCEP program to write doppler on disc: ",A)')
     +      IFILE
       WRITE(LP,'(2X,"Date:",1X,A8,2X,"Name: ",A12,/,
     +        2X,"Line-Printer:",1X,I2,2X,"Tape-LU#:",I2)')
     + IFLT,INM,LP,LUNRT
C Read Ram File Flag{Y/N} and the Ram File Name 
C       READ(315,'(A1,1X,A80)',IOSTAT=IERR,ERR=999) RAMFL,NAMERAM 
C       IF(RAMFL.EQ.'y')RAMFL='Y'
C       IF(RAMFL.EQ.'n')RAMFL='N'
       RAMFL='N'
C      CALL CASEFOLD(RAMFL)
C Open the Ram File 
       IF (RAMFL .EQ. 'Y') THEN
          CALL OPENRAMFILE(NAMERAM,LP,STIMERAM,ETIMERAM,DATARATE,IERR)
          IF (IERR .NE. 0) GO TO 1050
          WRITE(LP,'(2X,"RAMFL= ",A1,1X,A80)') RAMFL,NAMERAM
       ENDIF 
C Read Unfolding Flag{Y/N},first guess wind and speed
C       READ(315,*,IOSTAT=IERR,ERR=999) IUNFOLDFLAG,WD,WS
c       INFOLDFLAG=1
       WD=0.
       WS=1.
       iunfoldflag=0
       WRITE(LP,'(2X,"IUNFOLDFLAG= ",I1," WD= ",F6.1," WS= ",F6.1)')
     +      IUNFOLDFLAG,WD,WS
C Read the starting bin and the number of bins for averaging
       READ(98,*,IOSTAT=IERR,ERR=999) IBST(1),INOB(1) 
       INQUIRE(FILE='ibstfile',EXIST=IBSTFILEEXISTS)
       IF(IBSTFILEEXISTS)THEN
        WRITE(6,*)'Substituting IBST(1) and INOB(1) from backdoor file'
          OPEN(92,FILE='ibstfile')
          READ(92,*)IBST(1),INOB(1)
          CLOSE(92)
       ENDIF
       WRITE(LP,'(2X,"IBST= ",I4," INOB= ",I4)') IBST(1),INOB(1)
C Enter AZM, Elevation & rdel corrs.
       READ (98,*,IOSTAT=IERR,ERR=999) AZMCORS(1),ELCORS(1),
     +                                  RDELCORTAS(1)
       WRITE(LP,'(2X,"TA AZMCOR=",F6.2,2X,"ELCOR= ",F6.2,
     +      2X,"RDELCORTA= ",F6.2)') AZMCORS(1),ELCORS(1),
     +                               RDELCORTAS(1)
C Enter Pitch, drift and roll corrections:
       READ (98,*,IOSTAT=IERR,ERR=999) PCORS(1),DCORS(1),RCORS(1)
       WRITE(LP,'(2X,"TA PCOR= ",F5.1,2X,"DCOR= ",F5.1,
     +      2X,"RCOR= ",F5.1)') PCORS(1),DCORS(1),RCORS(1)
C Enter AZM, Elevation & rdel corrs.
       READ (98,*,IOSTAT=IERR,ERR=999) AZMCORS(2),ELCORS(2),
     +                                  RDELCORTAS(2)
       RDELCORTA=RDELCORTAS(1)
       WRITE(LP,'(2X,"TF AZMCOR=",F6.2,2X,"ELCOR= ",F6.2,
     +      2X,"RDELCORTA= ",F6.2)') AZMCORS(2),ELCORS(2),
     +                               RDELCORTAS(2)
C Enter Pitch, drift and roll corrections:
       READ (98,*,IOSTAT=IERR,ERR=999) PCORS(2),DCORS(2),RCORS(2)
       WRITE(LP,'(2X,"TF PCOR= ",F5.1,2X,"DCOR= ",F5.1,
     +      2X,"RCOR= ",F5.1)') PCORS(2),DCORS(2),RCORS(2)
C Read threshold value
       READ (98,*,IOSTAT=IERR,ERR=999) THRESH,DBZRS,DBZCOR,DBZSLOPE
       WRITE(LP,'(2X,"NOISE VALUE= ",F5.1,2X,"DBZRS= ",F5.1,
     +          "DBZSLOPE= ",F5.1,2X,"DBZCOR= ",F5.1)')
     +       THRESH,DBZRS,DBZSLOPE,DBZCOR
C Read spectral width threshold value
       READ (98,*,IOSTAT=IERR,ERR=999) swthresh
       IF (SWTHRESH.LE.0.0 .OR. SWTHRESH.GT.13.0) SWTHRESH=99.0
       INQUIRE(FILE='changesqi',EXIST=SQIEXISTS)
       IF(SQIEXISTS)THEN
         OPEN(88,FILE='changesqi')
         READ(88,*)SWTHRESH
         CLOSE(88)
       ENDIF
       SWPASS=SWTHRESH
       SWTHRESH=99.0
       WRITE(LP,'(2X,"SPECTRAL WIDTH THRESHOLD= ",F5.1)') swthresh
C Read Flag for adding the Terminal Velocity Corr. Value, the height &
C depth of the bright band, P. Willis or Joss VT.
       IVT='N'
       HTBB=5.5
       DBB=2.
       IRSW=0
C       READ (98,*,IOSTAT=IERR,ERR=999) IVT,HTBB,DBB,IRSW
       IF(IVT.EQ.'n')IVT='N'
       IF(IVT.EQ.'y')IVT='Y'
C      CALL CASEFOLD(IVT)
       WRITE(LP,'(2X,''VT= '',A1," HTBB= ",F6.2," DBB= ",F6.2, 
     +           " IRSW= ",I1)') 
     +      IVT,HTBB,DBB,IRSW
       IF (IVT .EQ. 'N') HTBB= -99.0
C Read flag to add the intervening attenuation
C       IATTEN='N'
C       READ (98,*,IOSTAT=IERR,ERR=999) IATTEN
       CALL MAKEATTENTABLE1(2)
       IF(IATTEN.EQ.'y')IATTEN='Y'
       IF(IATTEN.EQ.'n')IATTEN='N'
C      CALL CASEFOLD(IATTEN) 
       IF (IATTEN .EQ. 'Y') THEN 
C compute attenuation table if flag is on 
          WRITE(LP,'(1X,"Intervening attenuation: A=",E10.2, 
     +   "*Z**",F4.2)') AT1,AT2
          IATTENFLAG = 1
       ELSE
          IATTENFLAG = 0
       ENDIF   
C Read Start Time and End Time
       READ(98,'(3I2,1X,3I2)',IOSTAT=IERR,ERR=999)
     +     IHS,IMS,ISS,IHE,IME,ISE
       WRITE(LP,'(2X,"Start Time:",3I2.2,2X,"End Time:",3I2.2)')
     +IHS,IMS,ISS,IHE,IME,ISE
C Read a second tape:
       TAPE='N'
C       READ(98,'(A1)',IOSTAT=IERR,ERR=999) TAPE
       IF(TAPE.EQ.'y')TAPE='Y'
       IF(TAPE.EQ.'n')TAPE='N'
C      CALL CASEFOLD(TAPE)
C 
C Read Disk File Name 
C       READ(98,'(A)',IOSTAT=IERR,ERR=999) NAMEO
       READ(98,*)DUMMY
       READ(98,*)DUMMY1,DUMMY2
       READ(98,*)DUMMY1,DUMMY2
       READ(98,'(A80)')CDUMMY
       READ(98,*)AZIIN,AZIOUT
       RADARFILE='DUMMY'
       IF(LUNRT.GT.6)THEN
        ITAPEOPEN=1
        READ(98,'(A80)')RADARFILE
       ELSE
        ITAPEOPEN=0
        WRITE(6,*)'Enter name of radar file'
        READ(98,'(A80)')RADARFILE
       ENDIF
       READ(98,*)IFRANCENO
       IF(IFRANCENO.EQ.3)THEN
        IFRANCE=2
       ELSE
        IFRANCE=IFRANCENO
       ENDIF
       IF(ITAPEOPEN.EQ.1)THEN
        CALL TAPEOPEN(LUNRT,0,LUNR)
        CALL TAPECONTROL(LUNR,2,1) !back up 1 file
       ELSE
        LUNR=80
        WRITE(6,*)'OPENING RADAR DIRECTORY'
c       PAUSE
        WRITE(6,*)'ISIGMET = ',ISIGMET
c       PAUSE
        IF(ISIGMET.NE.5)THEN
         ISIGMETACTUAL=8
        ELSE
         ISIGMETACTUAL=5
        ENDIF
        IF(ISIGMET.NE.5)THEN
         LUNRNC=LUNR
         write(6,*)'about to call substitute_open_rvp8_file'
c        pause
         CALL substitute_open_rvp8_file(RADARFILE,LUNRNC,1,IERROPEN)
C Use the following two lines when GPS data are not available in sweep files
c        nav_choice=1
c        alt_choice=3
C
         write(6,*)'returned'
c        pause
         LUNR=LUNRNC
         WRITE(6,*)'OPENED RADAR DIRECTORY'
c        PAUSE
        ELSE
         LUNRNC=LUNR
         CALL OPENRADARFILE(RADARFILE,LUNRNC,1,IERROPEN)
         LUNR=LUNRNC
c        OPEN(80,FILE=RADARFILE,FORM='UNFORMATTED',RECL=2,
c     1       ACCESS='DIRECT')
         WRITE(6,*)'OPENED RADAR FILE'
        ENDIF
       ENDIF
       SWTHRESH8=0.
       IF(ISIGMET.EQ.5)THEN
        READ(98,*)IATCFNO
        READ(98,*,END=842)SWTHRESH
        GO TO 841
 842    SWTHRESH=6.25
        GO TO 1840
       ELSE
        READ(98,*)IATCFNO
        READ(98,*,END=840)SWTHRESH8
        GO TO 841
 840    IF(IPLANE.EQ.2.OR.IYEARTEST.GE.2019)THEN
         SWTHRESH8=SWPASS
        ELSEIF(IYEARTEST.GE.2017.AND.IPLANE.EQ.1)THEN
         SWTHRESH8=0.63
        ELSE
         SWTHRESH8=0.
        ENDIF
        GO TO 1840
       ENDIF
 841   READ(98,*,END=1840)AFTVNYQ
       GO TO 1842
 1840  AFTVNYQ=-888.8
 1842  CLOSE(98)
      INQUIRE(FILE='changemeltingband',EXIST=CHANGEMELTBANDEXISTS)
      IF(CHANGEMELTBANDEXISTS)THEN
         OPEN(88,FILE='changemeltingband')
         READ(88,*)HTBB,DBB
         CLOSE(88)
      ENDIF
      WRITE(6,'("MELTING BAND HEIGHT THICKNESS ARE",2F8.2)')HTBB,DBB
       NAMEO='DUMMY'
       IF(ISIGMET.EQ.5)THEN
        WRITE(6,*)'SWPASS,SWTHRESH = ',SWPASS,SWTHRESH
       ELSE
        WRITE(6,*)'SWPASS,SWTHRESH8,AFTVNYQ = ',
     +   SWPASS,SWTHRESH8,AFTVNYQ
       ENDIF
      ENDIF
c      WRITE(LP,'(2X,"NCEP Output File Name:",A)') NAMEO
c      WRITE(LP,*)trakazm,trakelev,driftnew,
c     +         rot,track,htbb,dbb,thresh,swthresh,dbzrs,ibst(1),ibst(2),
c     +         inob(1),inob(2),ileg,xniq,irsw,maxnbins,v0,
c     +         pcor,dcor,rcor,azmcor,elcor,dbzcor,dbzslope,
c     +         iunfoldflag,iattenflag,
c     +         badstabflag,surfelimflag,echoflag,atmflag
C Open Disk File
c      OPEN(320,FILE=NAMEO,IOSTAT=IERR,ERR=1000,STATUS='UNKNOWN',
c     +     FORM='unformatted') 
C 
      STIME=FLOAT(IHS)*3600.0 + FLOAT(IMS)*60.0 + FLOAT(ISS)
      ETIME=FLOAT(IHE)*3600.0 + FLOAT(IME)*60.0 + FLOAT(ISE)
C
C Search for the start time:
c971   write(6,*)'itapeopen,icallsweepin = ',itapeopen,icallsweepin
       WRITE(6,*)'ICALLSWEEPIN,IUSEWIND,ICONSERVE = ',
     1            ICALLSWEEPIN,IUSEWIND,ICONSERVE
 971  IF(ICALLSWEEPIN.EQ.0)THEN
       write(6,*)'calling rvp8_search'
       write(6,*)'lunr,stime = ',lunr,stime
       ROLDTIME=200000.
97100  WRITE(6,*)'CALLING READTAPE'
       kwords=0
       nwords=-1
       TIME=STIME
c       pause
       IF(ISIGMET.NE.5)THEN
        LUNRNC=LUNR
        STIMENC=STIME
        CALL rvp8_search(LUNRNC,2,2,STIMENC,IERR)
        WRITE(6,*)'RVP8_SEARCH IERR = ',IERR
        WRITE(6,*)'LUNRNC,STIME,ITAPEOPEN = ',LUNRNC,STIME,ITAPEOPEN
        LUNR=LUNRNC
        STIME=STIMENC
        write(6,*)'returned from rvp8_search'
       ELSE
        LUNRNC=LUNR
        STIMENC=STIME
        call discsearch(lunrnc,2,2,STIMENC,IERR)
        LUNR=LUNRNC
        STIME=STIMENC
        write(6,*)'returned from discsearch'
c        pause
       ENDIF
c       pause
c       IF(ISIGMET.NE.5)
       WRITE(6,*)'ITAPEOPEN = ',ITAPEOPEN
       WRITE(6,*)'ISIGMET = ',ISIGMET
       IF(ISIGMETACTUAL.EQ.8)THEN
        write(6,*)'iyear,month,iday = ',rvp8year,rvp8month,rvp8day
        write(6,*)'ih,im,is = ',rvp8h,rvp8m,rvp8s
        iyear=rvp8year
        month=rvp8month
        iday=rvp8day
        ih=rvp8h
        im=rvp8m
        is=rvp8s
       ENDIF
       IF(IFLIGHTCHECK.EQ.0)THEN
        IFLIGHTCHECK=1
        IF(ISIGMET.NE.5)iyear=iyear-2000
        if(iyear.lt.0)iyear=iyear+100
        write(6,*)'inair = ',inair
        write(6,6104)iyear,month,iday,caircraft(inair)
        write(IFLTCHK,6104)iyear,month,iday,caircraft(inair)
        write(6,*)'caircraft(inair) = ',caircraft
6104    FORMAT(3I2.2,A)
        read(IFLT,'(A7)')IFLTCHK2
        WRITE(6,'(A7)')IFLTCHK
        write(6,'(A7)')IFLTCHK2
        CALL FINDIDAYS(IDAYSCHK,NAIRCHK,IFLTCHK)
        CALL FINDIDAYS(IDAYSCHK2,NAIRCHK2,IFLTCHK2)
        WRITE(6,*)'IDAYS FROM TAPE = ',IDAYSCHK
        WRITE(6,*)'IDAYS FROM JOBFILE = ',IDAYSCHK2
        IDAYSDIFF=IDAYSCHK-IDAYSCHK2
        READ(IFLT,'(3I2,A1)')IYEAR,MONTHTAPE,IDAYTAPE,CCHECK
        IYEARTAPE=IYEAR
        IF(CCHECK.EQ.'H')THEN
         NAIRCRAFT=42
        ELSEIF(CCHECK.EQ.'I')THEN
         NAIRCRAFT=43
        ELSEIF(CCHECK.EQ.'N')THEN
         NAIRCRAFT=49
        ENDIF
        INAIR=1
        IF(NAIRCRAFT.EQ.42)THEN
         INAIR=1
        ELSEIF(NAIRCRAFT.EQ.43)THEN
         INAIR=2
        ELSEIF(NAIRCRAFT.EQ.49.OR.NAIRCRAFT.EQ.0)THEN
         INAIR=3
         NAIRCRAFT=49
        ELSE         
         WRITE(6,*)'NAIRCRAFT = ',NAIRCRAFT
         WRITE(6,*)'NAIRCRAFT DOES NOET EQUAL 42 OR 43'
c         STOP
        ENDIF
        IF(IAFTFORE.EQ.1.AND.NAIRCRAFT.EQ.42)THEN
         OPEN(58,FILE='aft_42.mask')
         WRITE(6,*)'OPENED aft_42.mask'
        ELSEIF(IAFTFORE.EQ.2.AND.NAIRCRAFT.EQ.42)THEN
         OPEN(58,FILE='fore_42.mask')
         WRITE(6,*)'OPENED fore_42.mask'
        ELSEIF(IAFTFORE.EQ.1.AND.NAIRCRAFT.EQ.43)THEN
         OPEN(58,FILE='aft_43.mask')
         WRITE(6,*)'OPENED aft_43.mask'
        ELSEIF(IAFTFORE.EQ.2.AND.NAIRCRAFT.EQ.43)THEN
         OPEN(58,FILE='fore_43.mask')
         WRITE(6,*)'OPENED fore_43.mask'
        ELSEIF(IAFTFORE.EQ.1.AND.NAIRCRAFT.EQ.49)THEN
         OPEN(58,FILE='aft_49.mask')
         WRITE(6,*)'OPENED aft_49.mask'
        ELSEIF(IAFTFORE.EQ.2.AND.NAIRCRAFT.EQ.49)THEN
         OPEN(58,FILE='fore_49.mask')
         WRITE(6,*)'OPENED fore_49.mask'
        ENDIF
        IF(IAFTFORE.LE.2)THEN
           DO J=1,360
              READ(58,'(A)')CDUMMY
              READ(58,'(A)')CDUMMY
              READ(58,*)(AVGDBZ1(I,J),I=1,610)
              READ(58,'(A)')CDUMMY
              READ(58,*)(AVGDBZ2(I,J),I=1,610)
              DO I=66,610
                 AVGDBZ2(I,J)=-60.
              ENDDO
           ENDDO
           CLOSE(58)
        ELSE 
           DO J=1,360
              DO I=1,610
                 AVGDBZ1(I,J)=-60.
                 AVGDBZ2(I,J)=-60.
              ENDDO
           ENDDO
        ENDIF
        IF(IYEAR.GT.50)THEN
           IYEARTEST=IYEAR+1900
        ELSE
           IYEARTEST=IYEAR+2000
        ENDIF
        IF(IDAYSDIFF.EQ.1)THEN
         IADD86400=1
        ELSEIF(IDAYSDIFF.NE.0)THEN
         WRITE(6,*)'FILES WITH INCORRECT DATE--STOPPING'
         IF(IAFTFORE.EQ.1)THEN
          OPEN(62,FILE="testcharaft")
          INUMBEROUT=1
          WRITE(62,*)INUMBEROUT
          CLOSE(62)
          STOP
         ELSE
          OPEN(62,FILE="testcharfore")
          INUMBEROUT=1
          WRITE(62,*)INUMBEROUT
          CLOSE(62)
          STOP
         ENDIF
        ELSE
         IADD86400=0
        ENDIF
        IADD86400=0
        IF(IFLTCHK2.NE.IFLTCHK)THEN
         write(6,*)'flight id on jobfile inconsistent with tape'
c         write(6,*)'do you want to continue?'
c         OPEN(1,FILE='/dev/tty')
c         READ(5,'(A1)')IYES
c         CLOSE(1)
c         IF(IYES.EQ.'N'.OR.IYES.EQ.'n')THEN
c          WRITE(6,*)'rerun jobfilemaker and continue'
c          STOP
c         ENDIF
        ENDIF
c        PAUSE
       ENDIF
c       PAUSE
c       IF(IADD86400.EQ.1)TIME=TIME+86400.
c       DO I=1,MAX_GATES
c        IF(REF(I).GT.64.)THEN
c         WRITE(6,*)'I,REF(I) = ',I,REF(I)
c         PAUSE
c        ENDIF
c       ENDDO
c       PAUSE
       write(6,*)'today 1 and isigmetactual = ',isigmetactual
       CALL READTAPE(TIME,RLAT,RLON,RA,AZM,EV,BIN,REF,BIN1,REF1,RCAZM,
     +  ITAPEOPEN,RADARFILE,NUMREC,PCORS,DCORS,RCORS,AZMCORS,
     +  RDELCORTAS,ELCORS,ISIGMETACTUAL,NDO)
       write(6,*)'returned from readtape after search'
c       pause
       NTASWEEPER=NTASWEEP
c       WRITE(6,*)'TIME,RLAT,RLON,RA = ',TIME,RLAT,RLON,RA
c       WRITE(6,*)'TIME,OLDTIME = ',TIME,ROLDTIME
       IF(TIME.EQ.ROLDTIME)GO TO 97100
       TIMEMSTIME=TIME-STIME
c       WRITE(6,*)'TIME,STIME,TIMEMSTIME = ',TIME,STIME,TIMEMSTIME
       IF(TIMEMSTIME.LT.-72000..AND.ITAPEOPEN.EQ.1)THEN
c        WRITE(6,*)'BACKSPACING'
        CALL TAPECONTROL(LUNR,2,1)
        CALL TAPECONTROL(LUNR,2,1)
        ROLDTIME=TIME
        GO TO 97100
c        WRITE(6,*)'SHOULD NOT GET HERE.  STOPPING'
c        STOP
       ENDIF
97101  IF(IADD86400.EQ.1)THEN
c        STIMESEARCH=STIME-86400.
       ELSE
        STIMESEARCH=STIME
       ENDIF
       IF(LUNR.NE.80)THEN
        CALL TAPESEARCH(LUNR,2,2,STIMESEARCH,IERR)
c        WRITE(6,*)'SHOULD NOT GET HERE.  STOPPING'
c        STOP
       ELSE
c94826        WRITE(6,*)'CALLING DISCSEARCH'
94826   IF(ISIGMET.EQ.5)THEN
         WRITE(6,*)'CALLING DISCSEARCH'
         LUNRNC=LUNR
         CALL DISCSEARCH(LUNRNC,2,2,STIMESEARCH,IERR)
         LUNR=LUNRNC
        ENDIF
c        PAUSE
c        CALL rvp8_search(LUNR,2,2,STIMESEARCH,IERR)
        WRITE(6,*)'CALLED RVP8_SEARCH'
c        PAUSE
        NTIMER=0
c        write(6,*)'called discsearch'
        timetest=itimex(2)
c        write(6,*)'timetest,etime = ',timetest,etime
        if(timetest.gt.etime)then
         itimex(2)=1
         time=itimex(2)
c         write(6,*)'new time,itimex = ',time,itimex(2)
         ierr=20
         go to 94826
        endif
      ENDIF
c       WRITE(6,*)'IERR = ',IERR
       IF (IERR.LT.0) GO TO 970
      WRITE(6,*)'CALLING READTAPE'
      CALL READTAPE(TIME,RLAT,RLON,RA,AZM,EV,BIN,REF,BIN1,REF1,RCAZM,
     +ITAPEOPEN,RADARFILE,NUMREC,PCORS,DCORS,RCORS,AZMCORS,
     +RDELCORTAS,ELCORS,ISIGMETACTUAL,NDO)
      NTASWEEPER=NTASWEEP
c      WRITE(6,*)'TIME,RLAT,RLON,RA = ',TIME,RLAT,RLON,RA
c      PAUSE
c      IF(IADD86400.EQ.1)TIME=TIME+86400
       IF((TIME-STIME).LT.-60000..AND.ITAPEOPEN.EQ.1)THEN
        CALL TAPECONTROL(LUNR,2,1) !back up 1 file
        CALL TAPECONTROL(LUNR,2,1) !back up 1 file
        GO TO 97101
c        WRITE(6,*)'SHOULD NOT GET HERE.  STOPPING'
c        STOP
       ELSEIF((TIME-STIME).LT.1.)THEN
c        WRITE(6,*)'SETTING IFILECHECK TO 1'
        IFILECHECK=1
       ELSE
c        WRITE(6,*)'TIME IS ',TIME
       ENDIF
      ENDIF
      OLDTIME=0
      ITIMECHECK=0
C      WRITE(6,*)'START XNIQ AND XNIQTA = ',XNIQ,XNIQTA
c7040  write(6,*)'calling readtape'
      TIMEBEFORE=TIME
      IF(IAFTFORE.EQ.2)RDELCORTA=RDELCORTAS(2)
7040    CALL READTAPE(TIME,RLAT,RLON,RA,AZM,EV,BIN,REF,BIN1,REF1,RCAZM,
     +ITAPEOPEN,RADARFILE,NUMREC,PCORS,DCORS,RCORS,AZMCORS,
     +RDELCORTAS,ELCORS,ISIGMETACTUAL,NDO)
c        WRITE(6,*)'TIME,RADAZM,ELEV,RCAZM = ',TIME,RADAZM,ELEV,RCAZM
c        WRITE(6,*)'RA,GROUNDADJUST = ',RA,GROUNDADJUST
        RA=RA-GROUNDADJUST
c        WRITE(6,*)'NEW RA = ',RA
c      WRITE(6,*)'TIME,IAFTFORE,ELEV,ICALLSWEEPIN,NTASWEEP,IERR = ',
c     + TIME,IAFTFORE,ELEV,ICALLSWEEPIN,NTASWEEP,IERR
c      WRITE(6,*)'RLAT,RLON,RA,AZM,EV,RCAZM = ',RLAT,RLON,RA,AZM,EV,RCAZM
      IF(IAFTFORE.EQ.1.AND.ELEV.GE.0..AND.ICALLSWEEPIN.NE.0)GO TO 7040
      IF(IAFTFORE.EQ.2.AND.ELEV.LE.0..AND.ICALLSWEEPIN.NE.0)GO TO 7040
      IF(ABS(RADVWS).GT.100.OR.ABS(RADVGS).GT.100.)GO TO 7040
      IF(IYEARTEST.GE.2019)THEN
         IF(SHORTPULSEADDRADIUS.LT.0.AND.SHORTPULSEADDDB.LT.0.)THEN
            ADDRADIUS=5.6
            IF(INAIR.EQ.1)REFADD=9.
            IF(INAIR.EQ.2)REFADD=5.
c            IF(INAIR.EQ.2)THEN
c               IF(IYEARTEST.GE.2020)THEN
c                  REFADD=5.
c               ELSE
c                  REFADD=0.
c               ENDIF
c            ENDIF
            IF(INAIR.EQ.3)REFADD=0.
            IF(INAIR.EQ.3)ADDRADIUS=0.
         ELSE
            REFADD=SHORTPULSEADDDB
            ADDRADIUS=SHORTPULSEADDRADIUS
         ENDIF
         DO I=1,400
            IF(RADIITA(I).LT.ADDRADIUS)THEN
C            WRITE(6,*)'I,RADIITA(I),SHORTPULSEADDRADIUS = ',
C     1                 I,RADIITA(I),SHORTPULSEADDRADIUS
               IF(REF(I).GT.-32.)REF(I)=REF(I)+REFADD
            ENDIF
         ENDDO
c         PAUSE
      ENDIF
C      IF((IYEARTEST.GE.2019.AND.INAIR.EQ.1).OR.
C     +   (IYEARTEST.GE.2020.AND.INAIR.EQ.2))THEN
C         DO I=1,76
C            IF(REF(I).GT.-32.)REF(I)=REF(I)+9.
C         ENDDO
C      ENDIF
C temporary kluge
c      WRITE(6,*)TIME,'7040 WIDTHBUFFER = '
c      WRITE(6,'(10F8.2)')(WIDTHBUFFER(I),I=1,80)
      IF(IAFTFORE.EQ.1.AND.AFTVNYQ.GT.0.)THEN
         XNIQ=AFTVNYQ
         XNIQTA=AFTVNYQ
      ENDIF
c      WRITE(6,*)'IAFTFORE,XNIQ,XNIQTA = ',IAFTFORE,XNIQ,XNIQTA
      IF(NDO.NE.0)GO TO 76583
c      WRITE(6,*)'TIMES,NUM_RAYS,EV,AZM,RCAZM = ',
c     +   TIMES,NUM_RAYS,EV,AZM,RCAZM
c      WRITE(6,'(10F8.2)')(REF(I),I=1,300)
      DO I=NBINS+1,MAX_HRD_DIM
         BIN(I)=-888.8
         REF(I)=-32.
      ENDDO
c      WRITE(6,*)'Velocity IAFTFORE,RCAZM,TIME = ',IAFTFORE,RCAZM,TIME
c      WRITE(6,2972)(BIN(I),I=1,200)
c      WRITE(6,*)'REFLECTIVITY IAFTFORE,RCAZMTIME = ',IAFTFORE,RCAZM,TIME
c      WRITE(6,2972)(REF(I),I=1,200)
c      WRITE(6,*)'SQI IAFTFORE,TIME = ',IAFTFORE,RCAZM,TIME
c      WRITE(6,2972)(WIDTHBUFFER(I),I=1,200)
 2972 FORMAT(10F8.2)
      IF(IYEARTEST.GT.2016.AND.IPLANE.EQ.1)THEN
         DO I=1,NBINS
            IF(RADIITA(I).GT.44.)THEN
               BIN(I)=-888.8
               REF(I)=-32.
            ENDIF
            IF(REF(I).LT.-10.)THEN
               REF(I)=-32.
               BIN(I)=-888.8
            ENDIF
         ENDDO
      ENDIF
      TIMES=TIME
      ISCANDIM=NBINS
      CALL VRLOCATER(TIMES,OLAT,OLON,
     + RLAT,RLON,RA,EV,AZM,RADIITA,XR,YR,ZR,
     + ISCANDIM,SMOTIONU,SMOTIONV,CENTIME)
      IF((ELEV.GT.0..OR.IFRANCE.NE.2).AND.TIME.NE.TIMEBEFORE)THEN
       PIDIV=.01745329
       CALCTRACK=ATAN2(GSE,GSN)/PIDIV
       IF(CALCTRACK.LT.0.)CALCTRACK=CALCTRACK+360.
       IF(HEADING.LT.0.)HEADING=HEADING+360.
       WRITE(71,7620)TIME,RLAT,RLON,TRACK,DRIFTNEW,HEADING,GSE,GSN,
     + RADGS,RADVGS,CALCTRACK
 7620 FORMAT(12F12.6)
      ENDIF
c      WRITE(6,*)'SWPASS = ',SWPASS
C      PAUSE
      SWPASSTEST=SWPASS*XNIQTA
      SWPASSTEST7=SWPASSTEST*.7
c      WRITE(6,*)'ISIGMET = ',ISIGMET
c      WRITE(6,*)'XNIQTA,SWPASS,SWPASSTEST,SWPASSTEST7 = ',
c     +  XNIQTA,SWPASS,SWPASSTEST,SWPASSTEST7
c      WRITE(6,*)'WIDTHBUFFER = '
c      WRITE(6,'(10F8.2)')(WIDTHBUFFER(I),I=1,80)
      RA1000=RA/1000.
      IF(IAFTFORE.EQ.2.AND.IYEARTEST.GE.2017.AND.IPLANE.EQ.1)THEN
         SWPASSTEST=SWPASS-0.03
         SWTHRESH8TEST=SWTHRESH8-0.03
      ELSEIF(ISIGMET.EQ.8)THEN
         SWPASSTEST=SWPASS
         SWTHRESH8TEST=SWTHRESH8
      ENDIF
c      WRITE(6,*)'NBINS = ',NBINS
c      WRITE(6,'(10F8.2)')(RDTAIIN(I),I=1,NBINS)
      DO I=1,NBINS
       RADDIFF=ABS(RDTAIIN(I)-RA/1000.)
       RATEST=RDTAIIN(I)/RA1000
       IF(ISIGMET.NE.5)THEN
        IF(IYEARTEST.GE.2017.AND.IPLANE.EQ.1.AND.RDTAIIN(I).LT.10)THEN
           IYEARTESTTEST=1
        ELSE
           IYEARTESTTEST=0
        ENDIF
c        IF(WIDTHBUFFER(I).LT.SWPASS.AND.BIN(I).LT.20.AND.
        IF(WIDTHBUFFER(I).LT.SWPASSTEST.AND.
     +     (IPLANE.NE.1.OR.RADDIFF.LT.2.OR.IYEARTESTTEST.EQ.1))THEN
         BIN(I)=-888.8
         REF(I)=-32.
        ENDIF
        IF(WIDTHBUFFER(I).LT.SWTHRESH8TEST)THEN
         BIN(I)=-888.8
         REF(I)=-32.
        ENDIF
       ELSEIF(ISIGMET.EQ.5.AND.
c     + WIDTHBUFFER(I).GT.SWPASSTEST7.AND.RADDIFF.LT.2.)THEN
     +  ((WIDTHBUFFER(I).GT.SWPASSTEST7.AND.RADDIFF.LT.2.).OR.
     +  WIDTHBUFFER(I).LE.0.0))THEN
c        WRITE(6,*)
c     +  'I,J,RADDIFF,WIDTHBUFFER,SWPASSTEST7,BIN(I),REF(I) = ',
c     +   I,J,RADDIFF,WIDTHBUFFER(I),SWPASSTEST7,BIN(I),REF(I)
        BIN(I)=-888.8
        REF(I)=-32.
       ELSEIF(ISIGMET.EQ.5.AND.
c     + ((WIDTHBUFFER(I).GT.SWPASSTEST.AND.RATEST.LT.2..AND.
     + ((WIDTHBUFFER(I).GT.SWPASSTEST7.AND.RATEST.LT.2..AND.
     +   ZR(I).LT.3.).OR.
     +  WIDTHBUFFER(I).LE.0.02))THEN
c        write(6,*)'i,widthbuffer,ra,rdtaiin,ratest,zr,swpasstest = ',
c     + i,widthbuffer(i),ra,rdtaiin(i),ratest,zr(i),swpasstest
        BIN(I)=-888.8
        REF(I)=-32.
       ENDIF
      ENDDO
c      write(6,*)'7040 time,num_rays = ',time,num_rays
c       write(6,*)ucom,vcom,wd,ws,radwd,radws
       IF(ABS(V0).GT.100.)THEN
        DO I=1,MAX_HRD_DIM
         BIN(I)=-888.8
        ENDDO
c        WRITE(6,*)'V0,WD,WS = ',V0,WD,WS
       ENDIF
c       radwd=0
c       radws=0
c       ucom=0
c       vcom=0
c       write(6,*)'i got to another pause'
       if(elev.le.0.)then
        write(96,7000)ih,im,is,time
 7000  format(3i2.2,f12.3)
        write(96,7001)elev,radazm
        write(96,7001)radwd,radws,radvws
        write(96,7001)pitch,roll,heading
 7001  format(3f10.2)
       else
        write(97,7000)ih,im,is,time
        write(97,7001)elev,radazm
        write(97,7001)radwd,radws,radvws
        write(97,7001)pitch,roll,heading
       endif
c      write(6,*)airs_wind_dir,airs_wind_vel
c      IF(UCOM.LT.-900.)THEN
c       RADWD = airs_wind_dir
c       RADWS = airs_wind_vel
c       IF(RADWD.LT.-270.)THEN
c        RADWD = -999.9
c        RADWS = -999.9
c        UCOM = -999.9
c        VCOM = -999.9
c       ELSE
c        UCOM = -RADWS * SIN(RADWD*3.14159/180.)
c        VCOM = -RADWS * COS(RADWD*3.14159/180.)
c       ENDIF
c      ENDIF
      IF(ABS(RADVWS).GT.100.)THEN
       RADVWS = 0.
c       WRITE(6,*)'WD,WS,UCOM,VCOM,VWS = ',RADWD,RADWS,UCOM,VCOM,RADVWS
c       WRITE(6,6867)IH,IM,IS,ELEV,RCAZM
      ENDIF
 6867 FORMAT(3I2,X,2F10.2)
c      write(6,*)'radvws,radwd,radws = ',radvws,radwd,radws
      if(radvws.lt.-900..or.radwd.lt.-900.
     + .or.radws.lt.-900.)go to 7040
c      write(6,*)'rlat,rlon,ra = ',rlat,rlon,ra
c      write(6,*)'gse,gsn,gs,vgs = ',gse,gsn,gs,vgs
c      write(6,*)'ucom,vcom,wd,ws,vws = ',ucom,vcom,wd,ws,vws
c      write(6,*)'pitch,roll,drift,heading,track = ',
c     + pitch,roll,drift,heading,track
c      write(6,*)'elev,azm = ',elev,azm
c      write(6,*)'num_rays = ',num_rays
c      write(6,8684)(bin(i),i=1,nbins)
c 8684 format(10F8.2)
c      WRITE(6,*)'NUM_RAYS,BIN = ',NUM_RAYS,(BIN(I),I=300,500)
c      write(6,*)'nix,nbins,nbinta = ',nix,nbins,nbinta
      IF(NIX.LE.-100)GO TO 7040
      IF(NBINS.NE.NBINTA)GO TO 7040
      IF(NBINS.LE.0)GO TO 7040
      IF(NBINS.GT.NBINSMAX)NBINSMAX=NBINS
c      write(6,*)'time,rlat,rlon,ra,azm,ev = ',time,rlat,rlon,ra,azm,ev
c      write(6,'(3i2.2)')ih,im,is
c      write(6,*)'nbins = ',nbins
c      write(6,*)'wd,ws,w = ',radwd,radws,radvws
c      write(6,*)'gse,gsn,radgs,radvgs = ',gse,gsn,radgs,radvgs
      ipause = 0
      do i=1,400
       if(bin(i).gt.-100.)ipause =1
       if(ref(i).gt.0.)ipause =1
      enddo
c      write(6,*)'radiita = ',(radiita(i),i=1,40)
c       write(6,*)'num_rays = ',num_rays
c      write(6,*)'vr = ',(bin(i),i=1,40)
c      write(6,*)'ref = ',(ref(i),i=1,40)
c      write(6,*)'velbuffer = ',(velbuffer(i),i=1,40)
c      write(6,*)'ref = ',(ref(i),i=1,40)
c      write(6,*)'dbzbuffer = ',(dbzbuffer(i),i=1,40)
c      write(6,'(3i2.2)')ih,im,is
c      if(ipause.eq.1)pause
       IF(IBST(1).GE.1)THEN
        DO I=1,IBST(1)
         RDTAIIN(I)=1000.
        ENDDO
       ENDIF
       DO I=IBST(1)+1,NBINS
        RDTAIIN(I)=RADIITA(I)
       ENDDO
c       WRITE(6,*)NBINS
c       WRITE(6,*)RDTAIIN
      TRACKLATLON=180./3.14159*ATAN2(GSE,GSN)
      IF(TRACKLATLON.LT.0.)TRACKLATLON=TRACKLATLON+360.
      TRACKDIFF=TRACK-TRACKLATLON
c      write(6,*)'track,tracklatlon,trackdiff = ',
c     + track,tracklatlon,trackdiff
      IF(TRACKDIFF.GT.180.)TRACKDIFF=TRACKDIFF-360.
      IF(TRACKDIFF.LT.-180.)TRACKDIFF=TRACKDIFF+360.
      IF(TRACKDIFF.GT.2.)THEN
c      IF(ABS(TRACKDIFF).GT.2..OR.ABS(PITCH).LT..1.OR.
c     +   ABS(HEADING).LT..1)THEN
C     +   ABS(ROLL).LT..1.OR.ABS(HEADING).LT..1)THEN
c       WRITE(6,*)'TRACK,TRACKLATLON,PITCH,ROLL,HEADING = ',
c     +  TRACK,TRACKLATLON,PITCH,ROLL,HEADING
       DO I=1,MAX_GATES
        BIN(I)=-888.8
        BIN1(I)=-888.8
        REF(I)=-32.
        REF1(I)=-32.
       ENDDO
      ENDIF
C      IF(IPLANE.EQ.1)THEN
       DO I=1,MAX_HRD_DIM
        IF(REF(I).GT.-32.)REF(I)=REF(I)+FLOAT(IDBZADD)
       ENDDO
C      ENDIF
c       write(6,*)'returned from readtape'
c       write(6,*)'time,rlat,rlon = ',time,rlat,rlon
c       write(6,*)'pitch,roll,headnign = ',pitch,roll,heading
c       WRITE(6,*)'AFTER READTAPE TIME = ',TIME
c      IF(TIME.GT.86400.)PAUSE
c      TIME=TIME-86400.
c       IF(IADD86400.EQ.1)TIME=TIME+86400
c       write(6,*)'elev,roll = ',elev,roll
       IF(ABS(ELEV).LT..001)THEN
        DO I=1,MAX_GATES
         BIN(I)=-888.88
         REF(I)=-32.
        ENDDO
       ENDIF
       IF(ABS(ROLL).GT.ROLLTOL)THEN
        DO I=1,MAX_GATES
         BIN(I)=-888.88
        ENDDO
       ENDIF
       DO I=1,MAX_GATES
        IF(REF(I).GT.60.)THEN
c         WRITE(6,*)'AFTER READTAPE,I,REF(I) = ',I,REF(I)
c         PAUSE
         REF(I)=-32.
         BIN(I)=-888.88
        ENDIF
       ENDDO
      NTASWEEPER=NTASWEEP
c      IF(NUM_RAYS.GE.92.AND.NUM_RAYS.LE.93)THEN
c       WRITE(6,*)'BIN = ',BIN
c      ENDIF
c      WRITE(6,*)'BIN = ',(BIN(I),I=1,10)
c      WRITE(6,*)'REF = ',(REF(I),I=1,10)
      DO I=1,MAX_GATES
         RADIIATTEN(I)=RADIITA(I)
      ENDDO
      DO I=2,MAX_GATES
       IF(RADIITA(I).LT.RADIITA(I-1))THEN
        DO L=I,MAX_GATES
         RADIITA(L)=1000.
        ENDDO
        GO TO 5699
       ENDIF
      ENDDO
5699  CONTINUE
c       write(6,*)'time,bin = ',time,(bin(i),i=1,100)
c      write(6,*)'back from readtape'
C      WRITE(6,*)'TIME,NTASWEEP,ISWEEPSET,ISWEEPCHECK = ',
C     + TIME,NTASWEEP,ISWEEPSET,ISWEEPCHECK
c      write(6,*)'time,stime = ',time,stime
      IF(TIME.GT.ETIME)THEN
       write(6,*)'time,etime,ntimer = ',time,etime,ntimer
       IF(TIME-ETIME.GT.1000..AND.NTIMER.LT.100)THEN
        TIME=1
        ITIMEX(2)=1
        NTIMER=NTIMER+1
        GO TO 7040
       ELSE
        NTIMER=0
       ENDIF
      ENDIF
c      write(6,*)'time,stime,ifilecheck,itapeopen = ',
c     1  time,stime,ifilecheck,itapeopen
      IF(TIME.GT.STIME.AND.IFILECHECK.EQ.0.AND.ITAPEOPEN.EQ.1)THEN
c       WRITE(6,*)'SHOULD NOT GET HERE STOPPING'
c       STOP
       WRITE(6,*)'BACKING UP TWO FILES LOOKING FOR STARTIME'
       CALL TAPECONTROL(LUNR,2,1) !back up 1 file
       CALL TAPECONTROL(LUNR,2,1) !back up 1 file
       IFILECHECK=1
       GO TO 971
      ELSE
       IFILECHECK=1
      ENDIF
      OOLAT=RLAT
      OOLON=RLON
c      write(6,*)'time = ',time
c      write(6,*)'times = ',times
      TIMES=TIME
c      write(6,*)'time,times = ',time,times
      ALAT=.5*(RLAT+OLAT)
      ALON=.5*(RLON+OLON)
      XMOVE=(CENTIME-TIME)*SMOTIONU/1000.
      YMOVE=(CENTIME-TIME)*SMOTIONV/1000.
c      WRITE(6,*)'CENTIME,TIME,SMOTIONU,SMOTIONV,XMOVE,YMOVE = ',
c     1 CENTIME,TIME,SMOTIONU,SMOTIONV,XMOVE,YMOVE
      DELX=XMOVE+(111.1*COS(ALAT*3.14159/180.)*(RLON-OLON))
      DELY=YMOVE+(111.1*(RLAT-OLAT))
c      WRITE(6,*)'OLAT,RLAT,OLON,RLON,DELX,DELY = ',
c     1           OLAT,RLAT,OLON,RLON,DELX,DELY
      OLATDRIFT=OLAT-YMOVE/111.1
      OLONDRIFT=OLON-XMOVE/111.1/COS(ALAT*3.14159/180.)
      IF(ABS(DELX).LT..0001.AND.ABS(DELY).LT..0001)THEN
       STORMRADIUS=.0001
       DELX=.0001
       DELY=.0001
      ELSE
       STORMRADIUS=SQRT(DELX*DELX+DELY*DELY)
      ENDIF
      STORMAZIMUTH=180./3.14159*ATAN2(DELY,DELX)
      IF(STORMRADIUS.GT.1000.)THEN
       STORMRADIUS=.0001
       DELX=.0001
       DELY=.0001
      ENDIF
      VRAD=(UCOM*DELX+VCOM*DELY)/STORMRADIUS
      VTAN=(VCOM*DELX-UCOM*DELY)/STORMRADIUS
      IF(STORMAZIMUTH.LT.0.)STORMAZIMUTH=STORMAZIMUTH+360.
      TIMES=TIME
      TIMESINCE=TIMES-TIMESLAST
      AZITEST1=90.-AZIIN
      IF(AZITEST1.LT.0.)AZITEST1=AZITEST1+360.
      AZITEST2=90.-AZIOUT
      IF(AZITEST2.LT.0.)AZITEST2=AZITEST2+360.
      AZIDIFF1=STORMAZIMUTH-AZITEST1
      IF(AZIDIFF1.GT.180.)AZIDIFF1=AZIDIFF1-360.
      IF(AZIDIFF1.LT.-180.)AZIDIFF1=AZIDIFF1+360.
      AZIDIFF1=ABS(AZIDIFF1)
      AZIDIFF2=STORMAZIMUTH-AZITEST2
      IF(AZIDIFF2.GT.180.)AZIDIFF2=AZIDIFF2-360.
      IF(AZIDIFF2.LT.-180.)AZIDIFF2=AZIDIFF2+360.
      AZIDIFF2=ABS(AZIDIFF2)
c      WRITE(6,*)'STORMAZIMUTH,AZIDIFF1,AZIDIFF2 = ',
c     + STORMAZIMUTH,AZIDIFF1,AZIDIFF2
c      WRITE(6,*)'DELX,DELY = ',DELX,DELY
c      WRITE(6,*)'AZIIN,AZIOUT,AZITEST1,AZITEST2 = ',
c     + AZIIN,AZIOUT,AZITEST1,AZITEST2
      IF(AZIDIFF1.LT.45..AND.TIMES.LT.CENTIME)THEN
       INOUT=1
      ELSEIF(AZIDIFF2.LT.45..AND.TIMES.GT.CENTIME)THEN
       INOUT=2
      ELSE
       INOUT=0
      ENDIF
c      WRITE(6,*)'TIMES,CENTIME,INOUT = ',TIMES,CENTIME,INOUT
c      write(6,*)'times,timeslast,timesince,inout,radius,azi = ',
c     + times,timeslast,timesince,inout,stormradius,stormazimuth
c      WRITE(6,'(4F10.4)')RLAT,OLAT,RLON,OLON
      INTTIME=INT(TIMES)
      ITH=INTTIME/3600
      ITM=(INTTIME-IH*3600)/60
      ITM1=ITM/10
      ITM2=ITM-ITM1*10
      ITS=INTTIME-IH*3600-IM*60
      ITS1=ITS/10
      ITS2=ITS-ITS1*10
c      IF(ABS(XR(1)).GT.2.*XZXZ.OR.ABS(YR(1)).GT.2.*YZYZ)GO TO 7040
c      IF(TIMESINCE.GE.1..AND.ICALLSWEEPIN.NE.0.AND.IUSEWIND.EQ.1)THEN
      IF(TIMESINCE.GE.1..AND.ICALLSWEEPIN.NE.0)THEN
       RAOUTPUT=RA/1000.
       WRITE(95,5206)INOUT,STORMRADIUS,STORMAZIMUTH,
     + ITH,ITM1,ITM2,ITS1,ITS2,RAOUTPUT,RLAT,RLON,
     + UCOM,VCOM,RADVWS,RADVGS,XR(1),YR(1),ZR(1)
       WRITE(96,5207)INOUT,STORMRADIUS,STORMAZIMUTH,ITH,ITM1,ITM2,
     + ITS1,ITS2,VRAD,VTAN,DELX,DELY,UCOM,VCOM,OLATDRIFT,OLONDRIFT,
     + RADVWS,RADGS,RADVGS
c       WRITE(95,*)'AZITEST1,AZIDIFF1 = ',AZITEST1,AZIDIFF1
c       WRITE(95,*)'AZITEST2,AZIDIFF2 = ',AZITEST2,AZIDIFF2
5206   FORMAT(I1,2F8.2,X,I2,4I1,F8.2,9F10.4)
5207   FORMAT(I1,2F8.2,X,I2,4I1,6F8.2,5F10.4)
       TIMESLAST=TIMES
      ENDIF
c      WRITE(95,'(8F10.4)')RLAT,OLAT,RLON,OLON,
c     1 DELX,DELY,STORMRADIUS,STORMAZIMUTH
c      IF(IUSEWIND.NE.1)CENTIME=TIME
      ISCANDIM=MAX_GATES
      IBINS=MAX_GATES
      IF((RADIITA(11)-RADIITA(10)).GT..08.OR.ISIGMET.NE.5)THEN
       I150=1
      ELSE
       I150=0
      ENDIF
c      I150=1
c      WRITE(6,*)'SET I150 = ',I150
      IF(RADTEST.GT.0..AND.RADIITA(50).NE.RADTEST)THEN
       INEWRAD=1
       RADTEST=RADIITA(50)
      ELSE
       INEWRAD=0
      ENDIF     
      IF(TIME.LT.STIME)THEN
c       write(6,*)'calling int'
       ITIME=INT(TIME)
c       write(6,*)'returned from int'
       IF(ITIME.GT.ITIMECHECK)THEN
c        WRITE(6,*)'TIME,STIME = ',TIME,STIME
        ITIMECHECK=ITIME
       ENDIF
c       write(6,*)'itime,itimecheck = ',itime,itimecheck
c       write(6,*)'going to 7040 time,stime = ',time,stime
       GO TO 7040
      ENDIF
c29654 write(6,*)'calling vrlocater' 
29654 CALL VRLOCATER(TIMES,OLAT,OLON,
     + RLAT,RLON,RA,EV,AZM,RDTAIIN,XR,YR,ZR,
     + ISCANDIM,SMOTIONU,SMOTIONV,CENTIME)
       IF(NUM_RAYS.GE.0.AND.IUSEWIND.EQ.1)THEN
        RADIANEV=EV*3.14159/180.
        RADIANAZM=AZM*3.14159/180.
        DIRCOSX=COS(RADIANEV)*COS(RADIANAZM)
        DIRCOSY=COS(RADIANEV)*SIN(RADIANAZM)
        DIRCOSZ=SIN(RADIANEV)
        XMIN=-XZ
        YMIN=-YZ
        XMAX=-XZ+IMX*SX
        YMAX=-YZ+JMX*SY
        ZZMAX=ZZ+(KMX-1)*SZ
        DO IR=1,MAX_GATES
         IF(BIN(IR).GT.-800.)THEN
          IINT=INT((XR(IR)+XZ+.5*SX)/SX)
          JINT=INT((YR(IR)+YZ+.5*SY)/SY)
          KINT=1+INT((ZR(IR)-ZZ)/SZ)
          VRRAD(IR,NUM_RAYS+1)=0.
          VRSUM=0.
          DO I=IINT,IINT+1
           DO J=JINT,JINT+1
            DO K=KINT,KINT+1
             IF(I.GE.1.AND.I.LE.IMX)THEN
              IF(J.GE.1.AND.J.LE.JMX)THEN
               IF(K.GE.1.AND.K.LE.KMX)THEN
                IF(U(I,J,K).GT.WFLAG)THEN
                 XG=(I-1)*SX-XZ+.5*SX
                 YG=(J-1)*SY-YZ+.5*SY
                 ZG=(K-1)*SZ+ZZ
                 XI=XR(IR)-XG
                 YI=YR(IR)-YG
                 ZI=ZR(IR)-ZG
                 RADR=SQRT(XR(IR)*XR(IR)+YR(IR)*YR(IR))
                 RADG=SQRT(XG*XG+YG*YG)
                 VRAD=(U(I,J,K)*XG+V(I,J,K)*YG)/RADG
                 VTAN=(V(I,J,K)*XG-U(I,J,K)*YG)/RADG
                 URAD=(VRAD*XR(IR)-VTAN*YR(IR))/RADR
                 VRAD=(VRAD*YR(IR)+VTAN*XR(IR))/RADR
                 DISTPOINT=SQRT(XI*XI+YI*YI+ZI*ZI)
                 IF(DISTPOINT.GT.0.)THEN
                  RINT=1./DISTPOINT
                 ELSE
                  RINT=1000000.
                 ENDIF
                 VRRAD(IR,NUM_RAYS+1)=VRRAD(IR,NUM_RAYS+1)+
     1              RINT*(URAD*DIRCOSX+VRAD*DIRCOSY+
     1              W(I,J,K)*DIRCOSZ)
                 VRSUM=VRSUM+RINT
                ENDIF
               ENDIF
              ENDIF
             ENDIF
            ENDDO
           ENDDO
          ENDDO
          IF(VRSUM.GT.0.)THEN
           VRRAD(IR,NUM_RAYS+1)=VRRAD(IR,NUM_RAYS+1)/VRSUM
          ELSE
           VRRAD(IR,NUM_RAYS+1)=-888.8
          ENDIF
         ELSE
          VRRAD(IR,NUM_RAYS+1)=-888.8
         ENDIF
        ENDDO
       ENDIF
       ISCANONE=1
       RDTAONE(1)=.0001
       BINNONE=0.
       REFFONE=0.
       CALL VRLOCATER(TIMES,OLATOUT,OLONOUT,
     +  RLAT,RLON,RA,EV,AZM,RDTAONE,XR,YR,ZR,
     +  ISCANONE,SMOTIONU,SMOTIONV,CENTIME)
c       write(6,*)'olat,olon,rlat,rlon = ',olatout,olonout,rlat,rlon
       IF(NAIRCRAFT.NE.42)GO TO 76583
        HEADSTORM=ATAN2(XR(1),YR(1))
        HEADSTORM=HEADSTORM*180./3.14159
        IF(HEADSTORM.LT.0.)HEADSTORM=HEADSTORM+360.
c        write(6,*)'headstorm = ',headstorm
        TANDIR=HEADSTORM+90.
        IF(HEADSTORM.GE.360.)HEADSTORM=HEADSTORM-360.
        IF(TANDIR.GE.360.)TANDIR=TANDIR-360.
c        write(6,*)'headstorm,tandir = ',headstorm,tandir
c        write(6,*)'ucom,vcom = ',ucom,vcom
c        write(6,*)'radws,radwd = ',
c     +             radws,radwd
c        pause
        TANDIF=ABS(TANDIR-RADWD)
        IF(TANDIF.GT.180.)TANDIF=360.-TANDIF
c        WRITE(6,*)'TANDIF = ',TANDIF
        WSTANTEST=RADWS*TANDIF
        IF(WSTANTEST.GT.1200.)THEN
         IFLAGGING=1
        ENDIF
        IFLAGGING=0
       IF(IFLAGGING.EQ.1)THEN
        WRITE(6,*)'FLAGGING RAY'
        write(6,*)'headstorm,tandir = ',headstorm,tandir
        write(6,*)'ucom,vcom = ',ucom,vcom
        write(6,*)'radws,radwd = ',
     +             radws,radwd
        WRITE(6,*)'TANDIF = ',TANDIF
        DO I=1,MAX_GATES
         BIN(I)=-888.8
        ENDDO
       ENDIF
c76583 write(6,*)'at 76583 num_rays = ',num_rays 
76583 IF(NUM_RAYS.GE.0.AND.NDO.EQ.0)THEN
       CALL VRLOCATER(TIMES,OLAT,OLON,
     + RLAT,RLON,RA,EV,AZM,RDTAIIN,XR,YR,ZR,
     + MAX_GATES,SMOTIONU,SMOTIONV,CENTIME)
       DO I=1,MAX_GATES
        XRSWEEP(I,NUM_RAYS+1)=XR(I)
        YRSWEEP(I,NUM_RAYS+1)=YR(I)
        ZRSWEEP(I,NUM_RAYS+1)=ZR(I)
       ENDDO
      ENDIF
C
C ISWEEPSET EQUALS ZERO MEANS START TIME HAS NOT BEEN REACHED
C
c      WRITE(6,*)'1 SWEEPTEST,SWEEPOLD,ELEV,RADAZM,TRAKELEV,TRAKAZM = ',
c     + SWEEPTEST,SWEEPOLD,ELEV,RADAZM,TRAKELEV,TRAKAZM
      SWEEPTEST=1.
      IF(ABS(ELEV).GT.0.)THEN
       SWEEPTEST=ELEV*SWEEPOLD
       SWEEPOLD=ELEV
      ENDIF
      IF(IFRANCE.NE.1.OR.ISIGMET.NE.5)SWEEPTEST=1.
      IF(ISWEEPCHECK.NE.NTASWEEP.AND.IFRANCE.NE.1)SWEEPTEST=-1.
      IF(ISWEEPCHECK.NE.NTASWEEP.AND.ISIGMET.NE.5)SWEEPTEST=-1.
c      IF(SWEEPTEST.LT.0.)WRITE(6,*)'ISWEEPCHECK,NTASWEEP,SWEEPTEST = ',
c     +  ISWEEPCHECK,NTASWEEP,SWEEPTEST
c      WRITE(6,*)'ISWEEPCHECK,NTASWEEP,SWEEPTEST = ',
c     +  ISWEEPCHECK,NTASWEEP,SWEEPTEST
c      IF(IFRANCE.EQ.2.AND.ISWEEPCHECK.NE.NTASWEEP)SWEEPTEST=-1.
c      IF(IFRANCE.NE.1.AND.ISWEEPCHECK.NE.NTASWEEP)SWEEPTEST=-1
c      IF(IFRANCE.NE.1.AND.ISWEEPCHECK.EQ.NTASWEEP)SWEEPTEST=1.
c      WRITE(6,*)'2 SWEEPTEST,SWEEPOLD,ELEV,RADAZM,TRAKELEV,TRAKAZM = ',
c     + SWEEPTEST,SWEEPOLD,ELEV,RADAZM,TRAKELEV,TRAKAZM
c      write(6,*)'isweepset,isweepcheck,ntasweep = ',
c     + isweepset,isweepcheck,ntasweep
      IF(ISWEEPSET.EQ.0)THEN
       ISWEEPCHECK=NTASWEEP
       ISWEEPSET=1
       GO TO 7040
C
C ISWEEPSET EQUALS ONE MEANS START THIME HAS BEEN REACHED BUT 
C STILL WAITING FOR THE BEGINNING OF THE NEXT SWEEP TO START PROCESSING
C
C      ELSEIF(ISWEEPSET.EQ.1.AND.NTASWEEP.EQ.ISWEEPCHECK)THEN
      ELSEIF(ISWEEPSET.EQ.1.AND.SWEEPTEST.GE.0.)THEN
c       WRITE(6,*)'ISWEEP 1 NTASWEEP = ',NTASWEEP
       GO TO 7040
C      ELSEIF(ISWEEPSET.EQ.1.AND.NTASWEEP.NE.ISWEEPCHECK)THEN
      ELSEIF(ISWEEPSET.EQ.1.AND.SWEEPTEST.LT.0.)THEN
c       pause
c       write(6,*)'ibst(1) = ',ibst(1)
       RDDIFF=RDTAIIN(IBST(1)+1)-RDTAIIN(1)
c       pause
c       IF(NBINS.LT.MAX_GATES)THEN
c        DO I=NBINS+1,MAX_GATES
c         RDTAIIN(I)=1000.
c        ENDDO
c       ENDIF
C
C SETTING ISWEEPSET TO 2 MEANS WE HAVE REACHED THE START TIME
C
c       write(6,*)'setting isweepset to 2'
       ISWEEPSET=2
       ISWEEPCHECK=NTASWEEP
       GO TO 7040
C
C THE FOLLOWING BEING TRUE MEANS WE HAVE STARTED THE PROCESSING AND 
C HAVE JUST REACHED A NEW SWEEP
C
C      ELSEIF((ISWEEPSET.EQ.2.AND.NTASWEEP.NE.ISWEEPCHECK).
C     1       OR.NUM_RAYS.EQ.800)THEN
      ELSEIF((ISWEEPSET.EQ.2.AND.SWEEPTEST.LT.0.).
     1       OR.NUM_RAYS.EQ.799)THEN
       NUM_RAYS=NUM_RAYS+1
       IF(NUM_RAYS.EQ.800)THEN
        WRITE(6,*)'SPECIAL END TO SWEEP'
       ENDIF
       ISWEEPCHECK=NTASWEEP
       CALL CTME1(TIME,IIHH,IIMM,IISS)
       OPEN(72,FILE='lastsweep.txt')
       IF(IWAVE.EQ.0)THEN
        WRITE(72,*)'wavenumber 0 pass'
       ELSE
        WRITE(72,*)'wavenumber 1 pass'
       ENDIF
       CALL CTME1(TIME,IIHH,IIMM,IISS)
       WRITE(72,72726)IIHH,IIMM,IISS
72726  FORMAT('PROCESSING COMPLETED ON SWEEP ENDING AT ',3I2.2)
       WRITE(6,*)'SWEEP END TIME IS '
       WRITE(6,'(3I2)')IIHH,IIMM,IISS
       CALL DATE_AND_TIME(CHARDATE,CHARTIME,CHARZONE,TIMEVALUES)
       WRITE(72,72727)(TIMEVALUES(IJI),IJI=5,7),CHARDATE
       WRITE(6,72727)(TIMEVALUES(IJI),IJI=5,7),CHARDATE
72727  FORMAT('PROCESSOR TIME IS ',3I2.2,' on ',A)
       CLOSE(72)
       IF(NDO.NE.0)RETURN
c       WRITE(67,'(3I2)')IIHH,IIMM,IISS
       TIMEONE=TIME
       RLATONE=RLAT
       RLONONE=RLON
       GSEONE=GSE
       GSNONE=GSN
       RAONE=RA
       RDVWSONE=RADVWS
       AZMONE=AZM
       EVONE=EV
       V0ONE=V0
       VGSONE=VGS
       AZELONE=TRAKAZM
       AZELTWO=TRAKELEV
       PELEVONE=ELEV
       PAZMONE=RADAZM
       IF(IBST(1).GE.1)THEN
        DO I=1,IBST(1)
         BIN(I)=-888.8
         REF(I)=-32.
        ENDDO
       ENDIF
       DO I=IBST(1)+1,MAX_GATES
        BIN(I)=BIN(I)
        REF(I)=REF(I)
       ENDDO
C
C THE NEXT SECTION LOOKS LIKE AN ATTEMPT TO DETERMINE A RUNNING CORRECTION
C     OF DRIFT. DV0 IS THE DERIVATIVE OF THE PROJECTED GROUND SPEED WITH 
C     RESPECT TO AZIMUTH.  IT WILL BE COMMENTED FOR NOW TO SAVE TIME
C     **LEGACY REMOVE**
C
C       V0G1=-(GSE*COS((AZM+2.)*PIDIV)+GSN*SIN((AZM+2.)*PIDIV))
C     1         *COS(EV*PIDIV)+VGSONE*SIN(EV*PIDIV)
C       V0G2=-(GSE*COS((AZM+1.)*PIDIV)+GSN*SIN((AZM+1.)*PIDIV))
C     1         *COS(EV*PIDIV)+VGSONE*SIN(EV*PIDIV)
C      V0G3=-(GSE*COS(AZM*PIDIV)+GSN*SIN(AZM*PIDIV))
C     1         *COS(EV*PIDIV)+VGSONE*SIN(EV*PIDIV)
C       V0G4=-(GSE*COS((AZM-1.)*PIDIV)+GSN*SIN((AZM-1.)*PIDIV))
C     1         *COS(EV*PIDIV)+VGSONE*SIN(EV*PIDIV)
C       V0G5=-(GSE*COS((AZM-2.)*PIDIV)+GSN*SIN((AZM-2.)*PIDIV))
C     1         *COS(EV*PIDIV)+VGSONE*SIN(EV*PIDIV)
C       DV0ONE=(-1.*V0G5+8.*V0G4-8.*V0G2+1.*V0G1)/12.
C       DVG=DV0ONE
       IF(IPLANE.EQ.1.AND.IYEARTEST.GE.2017)THEN
          TRAKAZM1=89.
          TRAKAZM2=271.
c          TRAKAZM1=97.
c          TRAKAZM2=263.
          ISECONDTRIP=0
       ELSE
          TRAKAZM1=91.
          TRAKAZM2=269.
          ISECONDTRIP=0
       ENDIF
c       WRITE(6,*)'IPLANE,IYEARTEST,ISECONDTRIP = ',
c     + IPLANE,IYEARTEST,ISECONDTRIP
c       WRITE(6,*)'TRAKAZM,TRAKAZM1,TRAKAZM2 = ',
c     + TRAKAZM,TRAKAZM1,TRAKAZM2
       IF(TRAKAZM.GT.TRAKAZM1.AND.TRAKAZM.LT.TRAKAZM2)THEN
        IBST1=IBST(1)
c        IBEG=0
        RMAXTATA=299792/2/PRF_HIGHTA
c        WRITE(6,*)'RMAXTATA = ',RMAXTATA
c        RMAXTATA=44.
        RASEND=RA
        CALL FIND_GROUND(RDTAIIN,DEG2RAD,BEAM_WID,RS_TH,RS_M,
     + DBZ_MAX,IBEG,NG2,IBST1,BIN,ISECONDTRIP,RMAXTATA,RASEND)
c        WRITE(6,*)'IBEG = ',IBEG
c        CALL FIND_GROUND(RDTAIIN,DEG2RAD,BEAM_WID,RS_TH,RS_M,
c     + DBZ_MAX,IBEG,NG2,IBST1,BIN,DVG,DRIFTCOR)
c       WRITE(6,*)'RS_TH,RS_M,DBZ_MAX,IBEG,NG2 = ',RS_TH,RS_M,DBZ_MAX,
c     +  IBEG,NG2
        IBEGNEW=IBEG
        REFL=-32.
        IF(IBEG.GT.1)THEN
c         DO L=1,20
c          IBEGL=IBEG-L+1
c          IF((IBEGL-1).GE.5)THEN
cc          WRITE(6,*)'IBEGL,L,REF(IBEGL),REF(IBEGL-1) = ',
cc     +               IBEGL,L,REF(IBEGL),REF(IBEGL-1)
c           IF(DBZBUFFER(IBEGL).GT.-31.95)REFL=DBZBUFFER(IBEGL)
c           IF(REFL.GT.-31.95.AND.DBZBUFFER(IBEGL-1).GT.-31.95)THEN
c            IF(REFL-DBZBUFFER(IBEGL-1).GT.5.)THEN
c             IBEGNEW=IBEGL
c            ENDIF
c           ENDIF
c          ENDIF
c         ENDDO
         IBEG=IBEGNEW-1
c         WRITE(6,*)'J,MAX_GATES = ',J,MAX_GATES
         DO I=IBEG,MAX_GATES
          BIN(I)=-999.9
          REF(I)=-999.9
         ENDDO
         NUMMAX=3.5*RA1000
         IF(IPLANE.EQ.2)NUMMAX=1.5*RA1000
         IF(IBEG.GT.NUMMAX)THEN
            IBEGPASS=IBEG-1
            EVPASS=EV
c            WRITE(6,*)'RA1000,NUMMAX = ',RA1000,NUMMAX
            CALL GROUNDCHECKI(REF,BIN,IBEGPASS,NBINS,EVPASS,NUMMAX)
         ENDIF
         ELSEIF(IBEG.EQ.-2)THEN
            WRITE(6,*)'I SHOULD NOT GET HERE'
            DO I=1,NBINS
               IF(RADIITA(I).GT.0.)THEN
                  SECONDRADIUS=RADIITA(I)+RMAXTATA
                  POWERDIFF=((RADIITA(I)+SECONDRADIUS)/RADIITA(I))**4.
                  DBZPOWERDIFF=10.*ALOG10(POWERDIFF)
c        WRITE(6,*)'I,RADIITA,SECONDRADIUS,POWERDIFF,DBZPOWERDIFF = ',
c     +             I,RADIITA(I),SECONDRADIUS,POWERDIFF,DBZPOWERDIFF
               ENDIF
               DBZTEST=45.-DBZPOWERDIFF
c               WRITE(6,*)'REF(I),DBZTEST = ',REF(I),DBZTEST
               IF(WIDTHBUFFER(I).LT..75)THEN
                  BIN(I)=-999.9
                  REF(I)=-999.9
               ENDIF
            ENDDO
        ELSEIF(IBEG.LT.0)THEN
c         WRITE(6,*)'J,MAX_GATES = ',J,MAX_GATES
         DO I=1,MAX_GATES
          BIN(I)=-999.9
          REF(I)=-999.9
         ENDDO 
        ENDIF
       ENDIF
c       IF(IYEARTEST.GE.2017.AND.IPLANE.EQ.1)THEN
        RADRES=RDTAIIN(41)-RDTAIIN(40)
        DBZSUMMER=0.
        CALL INTERVENATTEN2(REF,NBINS,RADIIATTEN,BINOUT)
        DO I=1,NBINS
           RADTEST=RMAXTATA-1.
           IF(RDTAIIN(I).GT.RADTEST)THEN
              BIN(I)=-888.8
              REF(I)=-32.
           ENDIF
        ENDDO
        DO I=1,MAX_GATES
C         IF(REF(I).GT.30)DBZSUMMER=DBZSUMMER+RADRES*REF(I)*3.0
C         REFTESTSUB=DBZSUMMER/40.
C         IF(IATTENFLAG.EQ.1)REFTESTSUB=0.
         IF(REF(I).GT.-32.)THEN
            REFTESTSUB=10.**(BINOUT(I)/10)-10.**(REF(I)/10)
         ELSE
            REFTESTSUB=0.
         ENDIF
c         IF(ZR(I).LT.2.0)REFTESTSUB=REFTESTSUB+
c     +                   FLOAT(IDBZMASK)*.5*(2.-ZR(I))
c         REFTESTSUB=100.
c         IF(REF(I).GT.-32..AND.REFTESTSUB.GT.1.)
c     +    WRITE(6,*)'I,REF,REFTESTSUB = ',I,REF(I),REFTESTSUB
         RADIUSRATIO=RDTAIIN(I)*1000./RA
         RADIUSDIFF=(RDTAIIN(I)-RA/1000.)
         IRADIUS1=NINT(RADIUSDIFF*10.)+110
         IRADIUS2=NINT(RDTAIIN(I)*10.)+10
         IF(IRADIUS1.GT.610)THEN
            BIN(I)=-888.8
            REF(I)=-32.0
         ENDIF
         ZRDIFF=ZR(I)-(RA/1000)
         IF((RADIUSRATIO.LE.RADRAT.OR.ABS(RDTAIIN(I)).LE.RADMASK).
     +     AND.ZRDIFF.LT.ZRDIFFMAX )THEN
c         IF(RADIUSRATIO.LE.RADRAT.OR.ABS(RDTAIIN(I)).LE.RADMASK)THEN
c         IF(ABS(RDTAIIN(I)).LE.40.)THEN
          IF(IRADIUS1.GT.610.OR.IRADIUS1.LE.0)IRADIUS1=-1
          IF(IRADIUS2.GT.610.OR.IRADIUS2.LE.0)IRADIUS2=-1
          IF(TRAKAZM.LT.0.)THEN
           TRACKAZM=TRAKAZM+360.
          ELSE
           TRACKAZM=TRAKAZM
          ENDIF
          JTRAKAZM=NINT(TRACKAZM)+1
          IF(JTRAKAZM.GT.360)JTRAKAZM=1
c       WRITE(6,*)'I,J,RA,RDTAIIN(I),TRAKAZM,IRADIUS,JTRAKAZM = ',
c     1            I,J,RA,RDTAIIN(I),TRAKAZM,IRADIUS,JTRAKAZM
          IF(REF(I).GT.-32..AND.IRADIUS1.GT.0.AND.IRADIUS1.LE.610
     1       .AND.JTRAKAZM.GT.JTRAKAZMMIN.AND.
     1        JTRAKAZM.LT.JTRAKAZMMAX)THEN
C          IF(REF(I).GT.-32..AND.IRADIUS1.GT.0.AND.IRADIUS1.LE.610)THEN
C           REFTEST=AVGDBZ1(IRADIUS1,JTRAKAZM)+FLOAT(IDBZMASK)-
C     +             REFTESTSUB
C           REFTEST=AVGDBZ1(IRADIUS1,JTRAKAZM)+FLOAT(IDBZMASK)
C          WRITE(6,*)'I,REF,REFTEST,REFTEST1,IDBZMASK,REFTESTSUB = ',
C     1     I,REF(I),REFTEST,REFTEST1,IDBZMASK,REFTESTSUB
           REFTEST1=AVGDBZ1(IRADIUS1,JTRAKAZM)
           REFTEST2=AVGDBZ1(IRADIUS1,JTRAKAZM)+FLOAT(IDBZMASK)
           REFTEST102A=10.**(REFTEST2/10.)-REFTESTSUB
           REFTEST101A=10.**(REFTEST1/10.)+10.**(FLOAT(IDBZMASK)/10.)
     +     -REFTESTSUB
           RATEST=RA/1000.
c           IF(RDTAIIN(I).GT.2.*RATEST)THEN
           IF(RDTAIIN(I).GT.10.)THEN
              REFTEST10A=REFTEST101A
           ELSE
              REFTEST10A=REFTEST102A
           ENDIF
           REFTEST10B=10.**(REF(I)/10.)
           IF(REFTEST10B.LT.REFTEST102A.AND.IAPPLYMASK.EQ.1)THEN
C           IF(REF(I).LT.REFTEST)THEN
            REF(I)=-32.
            BIN(I)=-999.9
           ENDIF
C         NUM1(IRADIUS,JTRAKAZM)=NUM1(IRADIUS,JTRAKAZM)+1
C         DBZSUMMER(IRADIUS,JTRAKAZM)=DBZSUMMER(IRADIUS,JTRAKAZM)
C     1    +REF(I)
          ENDIF
          IF(REF(I).GT.-32..AND.IRADIUS2.GT.0.AND.IRADIUS2.LE.610
     1       .AND.JTRAKAZM.GT.JTRAKAZMMIN.AND.
     1        JTRAKAZM.LT.JTRAKAZMMAX)THEN
c          IF(REF(I).GT.-32..AND.IRADIUS2.GT.0.AND.IRADIUS2.LE.610)THEN
           REFTEST=AVGDBZ2(IRADIUS2,JTRAKAZM)+FLOAT(IDBZMASK)-
     +             REFTESTSUB
C          WRITE(6,*)'REF,REFTEST,REFTEST1,IDBZMASK = ',
C     1     REF(I),REFTEST,REFTEST1,IDBZMASK
           IF(REF(I).LT.REFTEST.AND.IAPPLYMASK.EQ.1)THEN
            REF(I)=-32.
            BIN(I)=-999.9
           ENDIF
C         NUM1(IRADIUS,JTRAKAZM)=NUM1(IRADIUS,JTRAKAZM)+1
C         DBZSUMMER(IRADIUS,JTRAKAZM)=DBZSUMMER(IRADIUS,JTRAKAZM)
C     1    +REF(I)
          ENDIF
         ENDIF
        ENDDO
c       ENDIF
       DO I=1,MAX_GATES
        SWEEP(I,NUM_RAYS)=BIN(I)
        SWEEPZ(I,NUM_RAYS)=REF(I)
       ENDDO
       GO TO 2000
      ENDIF
      IF(NDO.NE.0)GO TO 7040
c      write(6,*)'num_rays = ',num_rays
      IF(IFRANCENO.EQ.1.AND.ABS(ELEV).LT..001)GO TO 7040
      NUM_RAYS=NUM_RAYS+1
c      WRITE(6,*)'NUM_RAYS = ',NUM_RAYS
c      PAUSE
      RRLAT(NUM_RAYS)=RLAT
      RRLON(NUM_RAYS)=RLON
      RRA(NUM_RAYS)=RA
      EAZM(NUM_RAYS)=AZM
      EEV(NUM_RAYS)=EV
      TRACKSTORE(NUM_RAYS)=TRACK
      HEADSTORE(NUM_RAYS)=HEADING
c      write(6,*)'time,num_rays = ',time,num_rays
      TMSWEEP(NUM_RAYS)=TIME
c      write(6,*)'tmsweep(num_rays) = ',tmsweep(num_rays)
      RDGSE(NUM_RAYS)=GSE
      RDGSN(NUM_RAYS)=GSN
      RDWD(NUM_RAYS)=RADWD
      RDWS(NUM_RAYS)=RADWS
      RDVWS(NUM_RAYS)=RADVWS
      RDVGS(NUM_RAYS)=VGS
c      write(6,*)'num_rays = ',num_rays
c      write(6,*)'trakazm = ',trakazm
      IF(IPLANE.EQ.1.AND.IYEARTEST.GE.2017)THEN
         TRAKAZM1=89.
         TRAKAZM2=271.
c         TRAKAZM1=97.
c         TRAKAZM2=263.
         ISECONDTRIP=0
      ELSE
         TRAKAZM1=91.
         TRAKAZM2=269.
         ISECONDTRIP=0
      ENDIF
c       WRITE(6,*)'IPLANE,IYEARTEST,ISECONDTRIP = ',
c     + IPLANE,IYEARTEST,ISECONDTRIP
c       WRITE(6,*)'TRAKAZM,TRAKAZM1,TRAKAZM2 = ',
c     + TRAKAZM,TRAKAZM1,TRAKAZM2
c       PAUSE
      IF(TRAKAZM.GT.TRAKAZM1.AND.TRAKAZM.LT.TRAKAZM2)THEN
       IBST1=IBST(1)
c       IBEG=0
       J=NUM_RAYS
C 
C SEE THE DISCUSSION OF DV0 ABOVE **LEGACY REMOVE**
C
C       V0G1=-(GSE*COS((AZM+2.)*PIDIV)+GSN*SIN((AZM+2.)*PIDIV))
C     1         *COS(EV*PIDIV)+RDVGS(J)*SIN(EV*PIDIV)
C       V0G2=-(GSE*COS((AZM+1.)*PIDIV)+GSN*SIN((AZM+1.)*PIDIV))
C     1         *COS(EV*PIDIV)+RDVGS(J)*SIN(EV*PIDIV)
C       V0G3=-(GSE*COS(AZM*PIDIV)+GSN*SIN(AZM*PIDIV))
C     1         *COS(EV*PIDIV)+RDVGS(J)*SIN(EV*PIDIV)
C       V0G4=-(GSE*COS((AZM-1.)*PIDIV)+GSN*SIN((AZM-1.)*PIDIV))
C     1         *COS(EV*PIDIV)+RDVGS(J)*SIN(EV*PIDIV)
C       V0G5=-(GSE*COS((AZM-2.)*PIDIV)+GSN*SIN((AZM-2.)*PIDIV))
C     1         *COS(EV*PIDIV)+RDVGS(J)*SIN(EV*PIDIV)
C       DV0(NUM_RAYS)=(-1.*V0G5+8.*V0G4-8.*V0G2+1.*V0G1)/12.
C       DVG=DV0(NUM_RAYS)
c       WRITE(6,*)'DVG = ',DVG
        RMAXTATA=299792/2/PRF_HIGHTA
       RASEND=RA
       CALL FIND_GROUND(RDTAIIN,DEG2RAD,BEAM_WID,RS_TH,RS_M,
     + DBZ_MAX,IBEG,NG2,IBST1,BIN,ISECONDTRIP,RMAXTATA,RASEND)
c       WRITE(6,*)'IBEG = ',IBEG
c       CALL FIND_GROUND(RDTAIIN,DEG2RAD,BEAM_WID,RS_TH,RS_M,
c     + DBZ_MAX,IBEG,NG2,IBST1,BIN,DVG,DRIFTCOR)
c       IF(DRIFTCOR.GT.-10.)THEN
c        DRIFTCORSUM=DRIFTCORSUM+DRIFTCOR*COS(EV*PIDIV)
c        NDRIFTCORSUM=NDRIFTCORSUM+COS(EV*PIDIV)
c        DRIFTCORSUMAVG=DRIFTCORSUM/NDRIFTCORSUM
c        write(6,*)'driftcoravg = ',driftcorsumavg
c       ENDIF
c       WRITE(6,*)'RS_TH,RS_M,DBZ_MAX,IBEG,NG2,RADAZM = ',
c     +  RS_TH,RS_M,DBZ_MAX,IBEG,NG2,RADAZM
       IBEGNEW=IBEG
       REFL=-32.
       IF(IBEG.GT.0)THEN
c        DO L=1,20
c         IBEGL=IBEG-L+1
c         IF((IBEGL-1).GE.5)THEN
cc          WRITE(6,*)'IBEGL,L,REF(IBEGL),REF(IBEGL-1) = ',
cc     +               IBEGL,L,REF(IBEGL),REF(IBEGL-1)
c          IF(DBZBUFFER(IBEGL).GT.-31.95)REFL=DBZBUFFER(IBEGL)
c          IF(REFL.GT.-31.95.AND.DBZBUFFER(IBEGL-1).GT.-31.95)THEN
c           IF(REFL-DBZBUFFER(IBEGL-1).GT.5.)THEN
c            IBEGNEW=IBEGL
c           ENDIF
c          ENDIF
c         ENDIF
c        ENDDO
        IBEG=IBEGNEW-1
c        WRITE(6,*)'NUM_RAYS,IBEG = ',NUM_RAYS,IBEG
c        WRITE(6,6927)(REF(I),BIN(I),I=1,600)
c        WRITE(6,6977)(WIDTHBUFFER(I),I=1,400)
        IF(IBEG.LT.1)IBEG=1
        DO I=IBEG,MAX_GATES
         BIN(I)=-999.9
         REF(I)=-999.9
        ENDDO
        NUMMAX=3.5*RA1000
        IF(IPLANE.EQ.2)NUMMAX=1.5*RA1000
        IF(IBEG.GT.NUMMAX)THEN
           IBEGPASS=IBEG-1
           EVPASS=EV
c           WRITE(6,*)'RA1000,NUMMAX = ',RA1000,NUMMAX
           CALL GROUNDCHECKI(REF,BIN,IBEGPASS,NBINS,EVPASS,NUMMAX)
        ENDIF
        IBEGDONE=IBEG-NG2-1
        I=IBEG-1
        DO WHILE(I.GT.0.AND.I.GT.IBEGDONE)
C        IF(BIN(I).LT.-800)REF(I)=-999.9
         I=I-1
        ENDDO
c        WRITE(6,*)'SECOND,NUM_RAYS,IBEG = ',SECOND,NUM_RAYS,IBEG
c        WRITE(6,6927)(REF(I),BIN(I),I=1,400)
6927   FORMAT(10F8.2)
 6977  FORMAT(10F8.3)
       ELSEIF(IBEG.EQ.-2)THEN
          WRITE(6,*)'I SHOULD NOT GET HERE'
          DO I=1,NBINS
             IF(RADIITA(I).GT.0.)THEN
                SECONDRADIUS=RADIITA(I)+RMAXTATA
                POWERDIFF=((RADIITA(I)+SECONDRADIUS)/RADIITA(I))**4.
                DBZPOWERDIFF=10.*ALOG10(POWERDIFF)
c        WRITE(6,*)'I,RADIITA,SECONDRADIUS,POWERDIFF,DBZPOWERDIFF = ',
c     +             I,RADIITA(I),SECONDRADIUS,POWERDIFF,DBZPOWERDIFF
             ENDIF
             DBZTEST=45.-DBZPOWERDIFF
c               WRITE(6,*)'REF(I),DBZTEST = ',REF(I),DBZTEST
             IF(WIDTHBUFFER(I).LT..75)THEN
                BIN(I)=-999.9
                REF(I)=-999.9
             ENDIF
          ENDDO
       ELSEIF(IBEG.LT.0)THEN
        DO I=1,MAX_GATES
         BIN(I)=-999.9
         REF(I)=-999.9
        ENDDO 
       ENDIF
      ENDIF
c      IF(IYEARTEST.GE.2017.AND.IPLANE.EQ.1)THEN
       DBZSUMMER=0.
       RADRES=RDTAIIN(41)-RDTAIIN(40)
       CALL INTERVENATTEN2(REF,NBINS,RADIIATTEN,BINOUT)
       DO I=1,NBINS
          RADTEST=RMAXTATA-1.
          IF(RDTAIIN(I).GT.RADTEST)THEN
             BIN(I)=-888.8
             REF(I)=-32.
          ENDIF
       ENDDO
       DO I=1,MAX_GATES
C        IF(REF(I).GE.30.)DBZSUMMER=DBZSUMMER+RADRES*REF(I)*3.0
C        REFTESTSUB=DBZSUMMER/40.
C        IF(IATTENFLAG.EQ.1)REFTESTSUB=0.
        IF(REF(I).GT.-32.)THEN
           REFTESTSUB=10.**(BINOUT(I)/10)-10.**(REF(I)/10)
c           REFTESTSUB=(BINOUT(I)-REF(I))*2.
        ELSE
           REFTESTSUB=0.
        ENDIF
c        IF(ZR(I).LT.2.0)REFTESTSUB=REFTESTSUB+
c     +                   FLOAT(IDBZMASK)*.5*(2.-ZR(I))
c        REFTESTSUB=100.
c        IF(REF(I).GT.-32..AND.REFTESTSUB.GT.1.)
c     +    WRITE(6,*)'I,REF,REFTESTSUB = ',I,REF(I),REFTESTSUB
        RADIUSRATIO=RDTAIIN(I)*1000./RA
c        IF(RADIUSRATIO.LE.3.OR.ABS(RDTAIIN(I)).LE.10)THEN
        RADIUSDIFF=(RDTAIIN(I)-RA/1000.)
        IRADIUS1=NINT(RADIUSDIFF*10.)+110
c        WRITE(6,*)'I,RDTAIIN(I),RA,RADIUSDIFF,IRADIUS1 = ',
c     +   I,RDTAIIN(I),RA,RADIUSDIFF,IRADIUS1
        IRADIUS2=NINT(RDTAIIN(I)*10.)+10
        IF(IRADIUS1.GT.610)THEN
           BIN(I)=-888.8
           REF(I)=-32.0
        ENDIF
        ZRDIFF=ZR(I)-(RA/1000)
        IF((RADIUSRATIO.LE.RADRAT.OR.ABS(RDTAIIN(I)).LE.RADMASK).
     +     AND.ZRDIFF.LT.ZRDIFFMAX )THEN
c        IF(RADIUSRATIO.LT.RADRAT.OR.ABS(RDTAIIN(I)).LE.RADMASK)THEN
         IF(IRADIUS1.GT.610.OR.IRADIUS1.LE.0)IRADIUS1=-1
         IF(IRADIUS2.GT.610.OR.IRADIUS2.LE.0)IRADIUS2=-1
         IF(TRAKAZM.LT.0.)THEN
          TRACKAZM=TRAKAZM+360.
         ELSE
          TRACKAZM=TRAKAZM
         ENDIF
         JTRAKAZM=NINT(TRACKAZM)+1
         IF(JTRAKAZM.GT.360)JTRAKAZM=1
c       WRITE(6,*)'I,J,RA,RDTAIIN(I),TRAKAZM,IRADIUS1,JTRAKAZM = ',
c     1            I,J,RA,RDTAIIN(I),TRAKAZM,IRADIUS1,JTRAKAZM
          IF(REF(I).GT.-32..AND.IRADIUS1.GT.0.AND.IRADIUS1.LE.610
     1       .AND.JTRAKAZM.GT.JTRAKAZMMIN.AND.
     1        JTRAKAZM.LT.JTRAKAZMMAX)THEN
c          IF(REF(I).GT.-32..AND.IRADIUS1.GT.0.AND.IRADIUS1.LE.610)THEN
c           REFTEST=AVGDBZ1(IRADIUS1,JTRAKAZM)+FLOAT(IDBZMASK)-
c     +             REFTESTSUB
c           WRITE(6,*)'RCAZM,EV,I,REF,REFTEST,REFTESTSUB,IDBZMASK = ',
c     1     RCAZM,EV,I,REF(I),REFTEST,REFTESTSUB,IDBZMASK
          REFTEST1=AVGDBZ1(IRADIUS1,JTRAKAZM)
          REFTEST2=AVGDBZ1(IRADIUS1,JTRAKAZM)+FLOAT(IDBZMASK)
          REFTEST102A=10.**(REFTEST2/10.)-REFTESTSUB
          REFTEST101A=10.**(REFTEST1/10.)+10.**(FLOAT(IDBZMASK)/10.)
     +     -REFTESTSUB
C          IF(REFTEST101A.LT.REFTEST102A)THEN
          RATEST=RA/1000.
C          IF(RDTAIIN(I).GT.2.*RATEST)THEN
          IF(RDTAIIN(I).GT.10.)THEN
             REFTEST10A=REFTEST101A
          ELSE
             REFTEST10A=REFTEST102A
          ENDIF
c          REFTEST10A=REFTEST101A
          REFTEST10B=10.**(REF(I)/10.)
          IF(REFTEST10B.LT.REFTEST102A.AND.IAPPLYMASK.EQ.1)THEN
c          IF(REF(I).LT.REFTEST)THEN
           REF(I)=-32.
           BIN(I)=-999.9
c           WRITE(6,*)'REFLECTIVITY REMOVED'
          ELSE
c           WRITE(6,*)'REFLECTIVITY NOT REMOVED'
          ENDIF
C         NUM1(IRADIUS,JTRAKAZM)=NUM1(IRADIUS,JTRAKAZM)+1
C         DBZSUMMER(IRADIUS,JTRAKAZM)=DBZSUMMER(IRADIUS,JTRAKAZM)
C     1    +REF(I)
         ENDIF
          IF(REF(I).GT.-32..AND.IRADIUS2.GT.0.AND.IRADIUS2.LE.610
     1       .AND.JTRAKAZM.GT.JTRAKAZMMIN.AND.
     1        JTRAKAZM.LT.JTRAKAZMMAX)THEN
c         IF(REF(I).GT.-32..AND.IRADIUS2.GT.0.AND.IRADIUS2.LE.610)THEN
          REFTEST=AVGDBZ2(IRADIUS2,JTRAKAZM)+FLOAT(IDBZMASK)-
     +            REFTESTSUB
c          WRITE(6,*)'REF,REFTEST,REFTEST1,IDBZMASK = ',
c     1     REF(I),REFTEST,REFTEST1,IDBZMASK
          IF(REF(I).LT.REFTEST.AND.IAPPLYMASK.EQ.1)THEN
           REF(I)=-32.
           BIN(I)=-999.9
          ENDIF
C         NUM1(IRADIUS,JTRAKAZM)=NUM1(IRADIUS,JTRAKAZM)+1
C         DBZSUMMER(IRADIUS,JTRAKAZM)=DBZSUMMER(IRADIUS,JTRAKAZM)
C     1    +REF(I)
         ENDIF
        ENDIF
       ENDDO
c      ENDIF
c      IF (TIME.GT.ETIME .OR. NIX.EQ.-100)GO TO 2000
2222  IF (NIX.EQ.-100)GO TO 2000
      IF (TAPE .EQ. 'Y') THEN 
C          call radartaperewind(lunr)
          WRITE(6,'("Change Radar Tape; RETURN to continue")')
c7060      PAUSE
7060      WRITE(6,'("1-continue, 2-pause:")')
          READ(5,*,err=7060) irewind
          if (irewind .ne. 1) go to 7060
          TAPE='N'
          GO TO 7040
      ENDIF 
C 
C Write Radar Information To Disk  
      ITIME=TIME
      AZ_EL(1,NUM_RAYS)=TRAKAZM
      AZ_EL(2,NUM_RAYS)=TRAKELEV
      PELEV(NUM_RAYS)=ELEV
      PAZM(NUM_RAYS)=RADAZM
      V0SAVE(NUM_RAYS)=V0
      IF(IBST(1).GE.1)THEN
       DO I=1,IBST(1)
        BIN(I)=-888.8
        REF(I)=-32.
        WIDTHBUFFER(I)=-888.8      
       ENDDO
      ENDIF
      DO I=1,NBINS
       SWEEP(I,NUM_RAYS)=BIN(I)
       SWEEPZ(I,NUM_RAYS)=REF(I)
C       IF(SWEEPZ(I,NUM_RAYS).GT.64)THEN
C        WRITE(6,*)'ONE'
C        WRITE(6,*)'I,NUM_RAYS,SWEEPZ = ',I,NUM_RAYS,SWEEPZ(I,NUM_RAYS)
C        WRITE(6,*)'REF(I) = ',REF(I)
C        PAUSE
C       ENDIF
c       SWEEP(I,NUM_RAYS)=REF(I)
c       SWEEPZ(I,NUM_RAYS)=DBZBUFFER(I)
       SWIDTH(I,NUM_RAYS)=WIDTHBUFFER(I)
c       write(6,*)i,j,swthresh,widthbuffer(i),sweepz(i,num_rays)
c       IF(WIDTHBUFFER(I).GT.SWTHRESH)SWEEPZ(I,NUM_RAYS)=-32.
c       write(6,*)i,j,swthresh,widthbuffer(i),sweepz(i,num_rays)
      ENDDO
c      WRITE(6,*)'NUM_RAYS = ',NUM_RAYS
c      WRITE(6,8677)(SWEEP(I,NUM_RAYS),I=1,100)
c 8677 FORMAT(10F8.2)
      IF(NBINS.LT.MAX_GATES)THEN
c       WRITE(6,*)'NBINS LT MAX_GATES AND NBINS,MAX_GATES = ',
c     1  NBINS,MAX_GATES
       DO I=NBINS+1,MAX_GATES
        SWEEP(I,NUM_RAYS)=-888.8
        SWEEPZ(I,NUM_RAYS)=-32.
C       IF(SWEEPZ(I,NUM_RAYS).GT.64)THEN
C        WRITE(6,*)'TWO'
C        WRITE(6,*)'I,NUM_RAYS,SWEEPZ = ',I,NUM_RAYS,SWEEPZ(I,NUM_RAYS)
C        PAUSE
C       ENDIF
       ENDDO
      ENDIF
5675  FORMAT(4(I3,F10.4))
      IF (MOD(ITIME,60).EQ.0 .AND. itime.NE.OLDTIME) THEN
         CALL CTME1(TIME,IH,IM,IS)
c         WRITE(6,'(" Writing: ",3i2.2,1x,3(f9.3,1x),2(f12.4,1x))')
c     +        IH,IM,IS,RLAT,RLON,RA,AZM,EV
      ENDIF
      OLDTIME=ITIME
c      write(6,*)'going to 7040 itime = ',itime
      GO TO 7040
C 
C <<<<<<Error Conditions<<<<<<
970   WRITE(LP,'(1X," Error searching for start time:",i6)') IERR
      GO TO 2000
998   WRITE(LP,'(1X,"Error Opening Input File: ",A,1X,"IERR= ",I6)')
     +      IFILE,IERR
      GO TO 2000
999   WRITE(LP,'(1X,"Bad Input Data",I4)') IERR 
      GO TO 2000
1000  WRITE(LP,1030)IERR,NAMEO
1030  FORMAT(1X,'Error on Creating Output File= ',I5,1X,A) 
      GO TO 2000
1040  WRITE(LP,1045)IERR,NAMEO
1045  FORMAT(1X,'Error on Write= ',I5,1X,A)
      GO TO 2000
1050  WRITE(LP,'("Error on opening Ram File: ",I5,1X,A80)') IERR,NAMERAM 
2000  NUM_RAYS=NUM_RAYS-2
c      WRITE(6,*)'I GOT HERE AND NUM_RAYS = ',NUM_RAYS
c      NLLLL=NUM_RAYS/3
c      DO LLLL=1,NLLLL
c       L1=1+(LLLL-1)*3
c       L2=LLLL*3
c       WRITE(67,'(8X,3(F8.2,16X))')(AZ_EL(1,LL),LL=L1,L2)
c       DO I=1,100
c        WRITE(67,'(I8,9F8.2)')I,
c     1  (SWEEP(I,LL),SWEEPZ(I,LL),SWIDTH(I,LL),LL=L1,L2)
c       ENDDO
c      ENDDO
      NBINS=NBINSMAX
      IF(NUM_RAYS.GT.0)THEN
c       WRITE(6,*)'AZ_EL = '
c       WRITE(6,'(10F8.2)')(AZ_EL(1,J),J=1,NUM_RAYS)
c       WRITE(6,*)'PAZM = ',(PAZM(J),J=1,NUM_RAYS)
c       WRITE(6,*)'AZ_EL = ',(AZ_EL(1,J),J=1,NUM_RAYS)
c       WRITE(6,*)'VOSAVE = '
c       WRITE(6,591)(V0SAVE(J),J=1,NUM_RAYS)
c 591   FORMAT(15F9.2)
c      WRITE(6,*)'BEFORE AZISORT I150 = ',I150
       DO I=1,2
        DO J=1,NUM_RAYS
         AZEL(I,J)=AZ_EL(I,J)
        ENDDO
       ENDDO
c       WRITE(6,*)'AZEL = '
c       WRITE(6,'(10F8.1)')(AZEL(1,J),J=1,NUM_RAYS)
c       WRITE(6,*)'JUST BEFORE RAY SORTING'
c       DO J=1,NUM_RAYS
c        WRITE(6,*)'J AZI TIME SWEEP = ',J,AZEL(1,J),TMSWEEP(J)
c        WRITE(6,7777)(SWEEP(I,J),I=1,NBINS)
c        WRITE(6,*)'J AZI TIME SWEEPZ = ',J,AZEL(1,J),TMSWEEP(J)
c        WRITE(6,7777)(SWEEPZ(I,J),I=1,NBINS)
c       ENDDO
       CALL AZISORT(NUM_RAYS,AZ_EL,RDVWS)
       CALL AZISORT(NUM_RAYS,AZ_EL,PAZM)
       CALL AZISORT(NUM_RAYS,AZ_EL,PELEV)
       CALL AZISORT(NUM_RAYS,AZ_EL,EAZM)
       CALL AZISORT(NUM_RAYS,AZ_EL,EEV)
       CALL AZISORT(NUM_RAYS,AZ_EL,RRLAT)
c       WRITE(6,*)'A I150 = ',I150
       CALL AZISORT(NUM_RAYS,AZ_EL,RRLON)
       CALL AZISORT(NUM_RAYS,AZ_EL,RRA)
       CALL AZISORT(NUM_RAYS,AZ_EL,TMSWEEP)
       CALL AZISORT(NUM_RAYS,AZ_EL,V0SAVE)
       CALL AZISORT(NUM_RAYS,AZ_EL,TRACKSTORE)
       CALL AZISORT(NUM_RAYS,AZ_EL,HEADSTORE)
       NUMI=2
       CALL AZISORT2(NUMI,NUM_RAYS,AZ_EL,AZEL)
       NUMI=MAX_GATES
c       CALL AZISORT2(NUMI,NUM_RAYS,AZ_EL,TMP1)
c       CALL AZISORT2(NUMI,NUM_RAYS,AZ_EL,TMP2)
c       WRITE(6,*)'SORT SWEEP'
       CALL AZISORT2(NUMI,NUM_RAYS,AZ_EL,SWEEP)
c       WRITE(6,*)'END SORT SWEEP'
       CALL AZISORT2(NUMI,NUM_RAYS,AZ_EL,SWEEPSAVE)
       CALL AZISORT2(NUMI,NUM_RAYS,AZ_EL,VRRAD)
       CALL AZISORT2(NUMI,NUM_RAYS,AZ_EL,NYQ)
       CALL AZISORT2(NUMI,NUM_RAYS,AZ_EL,VROUT)
       CALL AZISORT2(NUMI,NUM_RAYS,AZ_EL,XRSWEEP)
       CALL AZISORT2(NUMI,NUM_RAYS,AZ_EL,YRSWEEP)
       CALL AZISORT2(NUMI,NUM_RAYS,AZ_EL,ZRSWEEP)
C       CALL AZISORT2(NUMI,NUM_RAYS,AZ_EL,XRMIN)
C       CALL AZISORT2(NUMI,NUM_RAYS,AZ_EL,YRMIN)
C       CALL AZISORT2(NUMI,NUM_RAYS,AZ_EL,ZRMIN)
C       CALL AZISORT2(NUMI,NUM_RAYS,AZ_EL,XRMAX)
C       CALL AZISORT2(NUMI,NUM_RAYS,AZ_EL,YRMAX)
C       CALL AZISORT2(NUMI,NUM_RAYS,AZ_EL,ZRMAX)
C       CALL AZISORT2(NUMI,NUM_RAYS,AZ_EL,AZMIN)
C       CALL AZISORT2(NUMI,NUM_RAYS,AZ_EL,AZMAX)
C       CALL AZISORT2(NUMI,NUM_RAYS,AZ_EL,ZDIFF)
c       WRITE(6,*)'B I150 = ',I150
c       WRITE(6,*)'CALLING AZISORT2 FOR SWEEPZ'
       CALL AZISORT2(NUMI,NUM_RAYS,AZ_EL,SWEEPZ)
c       WRITE(6,*)'RETURNED FROM CALLING AZISORT2 FOR SWEEPZ'
c       CALL IAZISORT2(NUMI,NUM_RAYS,AZ_EL,JINDEX)
c       CALL IAZISORT2(NUMI,NUM_RAYS,AZ_EL,JIINDEX)
       CALL IAZISORT2(NUMI,NUM_RAYS,AZ_EL,ISEG)
       CALL IAZISORT2(NUMI,NUM_RAYS,AZ_EL,ISEGB)
       CALL IAZISORT2(NUMI,NUM_RAYS,AZ_EL,ISEGE)
       CALL IAZISORT2(NUMI,NUM_RAYS,AZ_EL,IKEEP)
c       WRITE(6,*)'JUST AFTER RAY SORTING'
c       DO J=1,NUM_RAYS
c        WRITE(6,*)'J AZI TIME SWEEP = ',J,AZEL(1,J),TMSWEEP(J)
c        WRITE(6,7777)(SWEEP(I,J),I=1,NBINS)
c        WRITE(6,*)'J AZI TIME SWEEPZ = ',J,AZEL(1,J),TMSWEEP(J)
c        WRITE(6,7777)(SWEEPZ(I,J),I=1,NBINS)
c       ENDDO
 7777  FORMAT(10F8.2)
C
C THIS IS A NEW TEST FOR RADAR ALTITUDE RING
C
      IF(IALTRINGREMOVE.EQ.1)THEN
C         WRITE(6,*)'REMOVING ALTITUDE RING'
         DO I=NBINS,1,-1
            RARATIO=RDTAIIN(I)*1000./RA
            IF(RARATIO.GT.2.0.AND.RDTAIIN(I).LT.999.)NBINSUSE=I
         ENDDO
         IF(IAFTFORE.EQ.1)THEN
            RARATIO1=.3
            RARATIO2=.8
            RARATIO3=1.5
            RARATIO4=2.0
         ELSE
            RARATIO1=.5
            RARATIO2=1.0
            RARATIO3=1.5
            RARATIO4=2.0
         ENDIF
         DO J=1,NUM_RAYS
            SUMDBZIN=0.
            NSUMDBZIN=0
            SUMDBZAT=0.
            NSUMDBZAT=0
            SUMDBZOUT=0.
            NSUMDBZOUT=0.
            DO I=1,NBINSUSE
               RARATIO=RDTAIIN(I)*1000./RA
C          WRITE(6,*)'I,RALT,RDTAIIN,RARATIO = ',
C     +               I,RALT,RDTAIIN(I),RARATIO
               IF(RARATIO.GT.RARATIO1.AND.RARATIO.LT.RARATIO2)THEN
                  SUMDBZIN=SUMDBZIN+SWEEPZ(I,J)
                  NSUMDBZIN=NSUMDBZIN+1
               ELSEIF(RARATIO.GE.RARATIO2.AND.RARATIO.LE.RARATIO3)THEN
                  SUMDBZAT=SUMDBZAT+SWEEPZ(I,J)
                  NSUMDBZAT=NSUMDBZAT+1
               ELSEIF(RARATIO.GT.RARATIO3.AND.RARATIO.LT.RARATIO4)THEN
                  IF(ZRSWEEP(I,J).LT..5)THEN
                     NSUMDBZOUT=NSUMDBZOUT+1
                     SUMDBZOUT=SUMDBZOUT+100.
                  ELSE
                     SUMDBZOUT=SUMDBZOUT+SWEEPZ(I,J)
                     NSUMDBZOUT=NSUMDBZOUT+1
                  ENDIF
               ENDIF
            ENDDO
            DBZIN=SUMDBZIN/NSUMDBZIN
            DBZOUT=SUMDBZOUT/NSUMDBZOUT
            DBZAT=SUMDBZAT/NSUMDBZAT
C         WRITE(6,*)'DBZIN,DBZAT,DBZOUT = ',DBZIN,DBZAT,DBZOUT
            IF(DBZAT.GT.DBZIN+4..AND.DBZAT.GT.DBZOUT+4.)THEN
               DO I=1,NBINSUSE
                  RARATIO=RDTAIIN(I)*1000./RA
                  IF(RARATIO.GE.RARATIO2.AND.RARATIO.LE.RARATIO3)THEN
                     SWEEP(I,J)=-888.8
                     SWEEPZ(I,J)=-32.
                  ENDIF
               ENDDO
            ENDIF
         ENDDO
      ENDIF
C
C END OF RING ADDITION
C
       DO I=1,MAX_HRD_DIM
          DO J=1,NUM_RAYS
             IF(ABS(XRSWEEP(I,J)).GT.0..AND.
     1          ABS(XRSWEEP(I,J)).LT.500..AND.
     1          ABS(YRSWEEP(I,J)).GT.0..AND.
     1          ABS(YRSWEEP(I,J)).LT.500.)THEN
                RADSWEEP(I,J)=SQRT(XRSWEEP(I,J)*XRSWEEP(I,J)+
     1                             YRSWEEP(I,J)*YRSWEEP(I,J))
             ELSEIF(XRSWEEP(I,J).NE.0.OR.YRSWEEP(I,J).NE.0)THEN
                RADSWEEP(I,J)=SQRT(XRSWEEP(I,J)*XRSWEEP(I,J)+
     1                             YRSWEEP(I,J)*YRSWEEP(I,J))
             ELSE
                RADSWEEP(I,J)=2000.
             ENDIF
c             WRITE(6,*)'I,J,XRSWEEP,YRSWEEP,RADSWEEP = ',
c     1 I,J,XRSWEEP(I,J),YRSWEEP(I,J),RADSWEEP(I,J)
          ENDDO
       ENDDO
       DO I=1,2
        DO J=1,NUM_RAYS
         AZ_EL(I,J)=AZEL(I,J)
        ENDDO
c        WRITE(6,*)'AZEL1'
c        WRITE(6,7777)(AZEL(1,J),J=1,NUM_RAYS)
c        WRITE(6,*)'AZ_EL1'
c        WRITE(6,7777)(AZ_EL(1,J),J=1,NUM_RAYS)
c        WRITE(6,*)'AZEL2'
c        WRITE(6,7777)(AZEL(2,J),J=1,NUM_RAYS)
c        WRITE(6,*)'AZ_EL2'
c        WRITE(6,7777)(AZ_EL(2,J),J=1,NUM_RAYS)
       ENDDO
      ENDIF
c       WRITE(6,*)'AFTER AZISORT I150 = ',I150
c       WRITE(6,*)'PAZM = ',(PAZM(J),J=1,NUM_RAYS)
c       WRITE(6,*)'AZ_EL = ',(AZ_EL(1,J),J=1,NUM_RAYS)
c      write(6,*)'num_rays = ',num_rays
c      WRITE(6,*)'NBINS,NBINSMAX = ',NBINS,NBINSMAX
c      PAUSE
      if(num_rays.ge.1)then
       radvwmax=0.
       sumvw=0.
       do j=1,num_rays
c        if(rdvws(j).lt.-900.)rdvws(j)=0.
        radvwtest=abs(rdvws(j))
        sumvw=sumvw+rdvws(j)
c        write(6,*)'j,rdvws,radvwtest,radvwmax = ',j,rdvws(j),
c     1   radvwtest,radvwmax
        if(radvwtest.gt.radvwmax)radvwmax=radvwtest
       enddo
       radvwmean=sumvw/num_rays
c       write(6,*)'radvwmax,radvwmean = ',radvwmax,radvwmean
       radvwmean=abs(radvwmean)
       if(radvwmax.gt.30..or.radvwmean.gt.15.)then
        do j=1,num_rays
         do i=1,nbins
          sweep(i,j)=-888.8
         enddo
        enddo
       endif
      endif
c      DO JIK=1,NUM_RAYS
c       WRITE(6,*)'JIK = ',JIK
c       WRITE(6,8677)(SWEEP(I,JIK),I=1,100)
c 8677  FORMAT(10F8.2)
c      ENDDO
      RATEST=RA/1000.
      JSTART=0
c      write(6,*)'I GoT hErE'
C      DO J=1,NUM_RAYS
C       WRITE(6,*)'J,SWEEP ',J,(SWEEP(I,J),I=200,500)
C      ENDDO
      DO J=1,NUM_RAYS
       IF(AZ_EL(1,J).GT.90..AND.AZ_EL(1,J).LT.270.)THEN
c        WRITE(6,*)'J,AZ_EL = ',AZ_EL(1,J)
        JSTART=J
        GO TO 18187
       ENDIF
      ENDDO
      GO TO 19187
18187 JEND=0
      DO J=JSTART+1,NUM_RAYS
       IF(AZ_EL(1,J).GT.270.)THEN
        JEND=J-1
        GO TO 18181
       ENDIF
      ENDDO
C18181 WRITE(6,*)'JSTART,JEND SET TO ',JSTART,JEND
18181 CONTINUE
      IRINSIDE=0
      IROUTSIDE=513
      RADIFFTEST=RATEST/1.5
      RADIFFTEST=1.
c      WRITE(6,*)'RADIFFTEST,RATEST = ',RADIFFTEST,RATEST
      DO I=1,NBINS
       RALTDIFF=RDTAIIN(I)-RATEST/COS(PELEV(2)*3.14159/180.)
       IF(RDTAIIN(I).GT.200.)GO TO 18193
c       WRITE(6,*)'I,RALTDIFF,RDTAIIN(I) = ',I,RALTDIFF,RDTAIIN(I)
       IF(RALTDIFF.GT.-RADIFFTEST.AND.IRINSIDE.EQ.0)THEN
        IRINSIDE=I
       ENDIF
       IF(RALTDIFF.GT.RADIFFTEST)THEN
        IROUTSIDE=I-1
        GO TO 18182
       ENDIF
18193 ENDDO
18182 CONTINUE
      IF(ISIGMET.EQ.5.AND.IAPPLYMASK.EQ.1)THEN
         WRITE(6,*)'IRINSIDE,IROUTSIDE = ',IRINSIDE,IROUTSIDE
         SUMNDBZ=0.
         SUMRDBZ=0.
         ALT2=RATEST*2.
         RADIITEST1=RATEST*1.5
         RADIITEST2=RATEST*4.0
         DO J=1,NUM_RAYS       
            DO I=1,200
               IF(ZRSWEEP(I,J).GT.1.AND.ZRSWEEP(I,J).LE.ALT2.AND.
     1  RDTAIIN(I).GT.RADIITEST1.AND.RDTAIIN(I).LE.RADIITEST2)THEN
                  IF(SWEEPZ(I,J).GT.-32.)THEN
                     ZTEST=10.**(SWEEPZ(I,J)/10.)
                  ELSE
                     ZTEST=0.
                  ENDIF
                  SUMNDBZ=SUMNDBZ+1.
                  SUMRDBZ=SUMRDBZ+ZTEST
               ENDIF
            ENDDO
         ENDDO
         IF(SUMRDBZ.GT.0.0001.AND.SUMNDBZ.GT.0.00001)THEN
            ZTEST=SUMRDBZ/SUMNDBZ
         ELSE
            ZTEST=0.
         ENDIF
         WRITE(6,*)SUMNDBZ,SUMRDBZ,ZTEST
         WRITE(6,*)RATEST,RADIITEST1,RADIITEST2
         IF(ZTEST.LT.100.)THEN
C            IF(ZTEST.LT.5.)THEN
C               IF(ZTEST.LT.0.)THEN
            WRITE(6,*)'REMOVE DATA INSIDE ',IROUTSIDE
            IREMOVE=1
            DO J=1,NUM_RAYS
               DO I=1,200
                  IF(RDTAIIN(I).LE.RADIITEST2.AND.ZRSWEEP(I,J).LE.ALT2)
     1              THEN
                     SWEEP(I,J)=-999.9
                     SWEEPZ(I,J)=-32.0
                  ENDIF
               ENDDO
            ENDDO
         ELSE
            WRITE(6,*)'KEEP DATA'
            IREMOVE=0
         ENDIF
      ENDIF
c      pause
c ****REMOVED DEC 17 2015
      IF(IRINSIDE.GE.1.AND.IROUTSIDE.LE.NBINS.AND.IYEARTEST.LT.2017.
     1 AND.IAPPLYMASK.EQ.1)THEN
       DO I=IRINSIDE,IROUTSIDE
        DO J=1,NUM_RAYS
         IF(SWEEPZ(I,J).LT.20..AND.(IPLANE.EQ.2.OR.ISIGMET.EQ.5))THEN
          SWEEPZ(I,J)=-32.0
          SWEEP(I,J)=-999.9
         ENDIF
C         IF(SWEEPZ(I,J).LT.20..OR.ZRSWEEP(I,J).LE.0.5)THEN
C          SWEEP(I,J)=-999.9
C          SWEEPZ(I,J)=-32.0
CC       IF(SWEEPZ(I,J).GT.64)THEN
CC        WRITE(6,*)'THREE'
CC        WRITE(6,*)'I,J,SWEEPZ = ',I,NUM_RAYS,SWEEPZ(I,J)
CC        PAUSE
CC       ENDIF
C         ENDIF
        ENDDO
       ENDDO
      ENDIF
c ******REMOVED DEC 17 2015
c      WRITE(6,*)'NBINS = ',NBINS
c      DO J=1,NUM_RAYS
c       WRITE(6,*)'J,AZEL = ',J,AZ_EL(1,J)
c       WRITE(6,7777)(SWEEPZ(I,J),I=1,NBINS)
c      ENDDO
      DO I=1,NBINS
       IF(RDTAIIN(I).GT.RATEST)THEN
        IGTEST=0
        J=NUM_RAYS+1
        JSTART=1
        JJ=JSTART
        DO WHILE(JJ.LE.NUM_RAYS.AND.AZ_EL(1,JJ).LT.180.)
c        DO WHILE(JJ.LE.NUM_RAYS.AND.AZ_EL(1,JJ).GT.180.)
         IF(SWEEPZ(I,JJ).GT.-32.)THEN
          J=JJ+1
C         ELSE
C          GO TO 6498
         ENDIF
         JJ=JJ+1
        ENDDO
6498    IF(J.LE.NUM_RAYS.AND.AZ_EL(1,J).LT.180.)THEN
c6498    IF(J.LE.NUM_RAYS.AND.AZ_EL(1,J).GT.180.)THEN
         ICHECK=1
c         write(6,*)'i,icheck,j,azel = ',i,icheck,j,az_el(1,j)
         CALL GROUNDCHECK(SWEEP,SWEEPZ,NUM_RAYS,I,J,ICHECK)
C       IF(SWEEPZ(I,NUM_RAYS).GT.64)THEN
C        WRITE(6,*)'FOUR'
C        WRITE(6,*)'I,NUM_RAYS,SWEEPZ = ',I,NUM_RAYS,SWEEPZ(I,NUM_RAYS)
C        PAUSE
C       ENDIF
        ENDIF
        J=0
        JJ=JEND
c        write(6,*)'i,j,jend = ',i,j,jend
        JAZTEST=1
        DO WHILE(JJ.GE.1.AND.JAZTEST.EQ.1)
         IF(AZ_EL(1,JJ).GT.180.)THEN
c         IF(AZ_EL(1,JJ).LT.180.)THEN
C         write(6,*)'i,j,sweep(i,j) = ',i,j,sweep(i,j)
          IF(SWEEPZ(I,JJ).GT.-32.)THEN
           J=JJ-1
C         ELSE
C          GO TO 6499
          ENDIF
          JJ=JJ-1
          JAZTEST=1
         ELSE
          JAZTEST=0
         ENDIF
        ENDDO
c        WRITE(6,*)'J,JEND = ',J,JEND
6499   IF(J.GE.1)THEN
        IF(AZ_EL(1,J).GT.180.)THEN
c        IF(AZ_EL(1,J).LT.180.)THEN
         ICHECK=2
c         write(6,*)'i,icheck,j,azel = ',i,icheck,j,az_el(1,j)
         CALL GROUNDCHECK(SWEEP,SWEEPZ,NUM_RAYS,I,J,ICHECK)
C        IF(SWEEPZ(I,NUM_RAYS).GT.64)THEN
C        WRITE(6,*)'FIVE'
C        WRITE(6,*)'I,NUM_RAYS,SWEEPZ = ',I,NUM_RAYS,SWEEPZ(I,NUM_RAYS)
C        PAUSE
C        ENDIF
         ENDIF
        ENDIF
       ENDIF
      ENDDO
19187 IF(IDESPECKLE.EQ.1)
     + CALL DESPECKLE(MAX_GATES,MAX_RAYS,NBINS,NUM_RAYS,NUMTIMES,
     +                  NUMCONTIG,SWEEP,SWEEPZ,IKEEP,IOLDDESPECKLE,
     +                  ZRSWEEP,ZRDIFFMAX,RA,ZSPECKLEMAX)
      IF(IDESPECKLE.EQ.2)THEN
       DO ICHECKSWEEP=1,3
        DO I=1,NBINS
         DO J=1,NUM_RAYS
          IKEEP(I,J)=1
          IF(SWEEPZ(I,J).GT.-31.95)THEN
           DO I1=1,5
            II=I+I1-3
            IF(II.GT.0.AND.II.LE.MAX_GATES)THEN
             IF(SWEEPZ(II,J).GT.-31.95)THEN
              IITEST(I1)=1
             ELSE
              IITEST(I1)=0
             ENDIF
            ELSE
             IITEST(I1)=0
            ENDIF
           ENDDO
           DO J1=1,5
            JJ=J+J1-3
            IF(JJ.GT.0.AND.JJ.LE.NUM_RAYS)THEN
             IF(SWEEPZ(I,JJ).GT.-31.95)THEN
              JJTEST(J1)=1
             ELSE
              JJTEST(J1)=0
             ENDIF
            ELSE
             JJTEST(J1)=0
            ENDIF
           ENDDO
           IKEEPER=0
           IF(IITEST(2).EQ.1.AND.IITEST(4).EQ.1)THEN
            IKEEPER=1
           ELSEIF(IITEST(1).EQ.1.AND.IITEST(2).EQ.1)THEN
            IKEEPER=1
           ELSEIF(IITEST(4).EQ.1.AND.IITEST(5).EQ.1)THEN
            IKEEPER=1
           ENDIF
           JKEEPER=0
           IF(JJTEST(2).EQ.1.AND.JJTEST(4).EQ.1)THEN
            JKEEPER=1
           ELSEIF(JJTEST(1).EQ.1.AND.JJTEST(2).EQ.1)THEN
            JKEEPER=1
           ELSEIF(JJTEST(4).EQ.1.AND.JJTEST(5).EQ.1)THEN
            JKEEPER=1
           ENDIF
           IF(IKEEPER.EQ.0.OR.JKEEPER.EQ.0)THEN
            IKEEP(I,J)=0
           ENDIF
          ENDIF
         ENDDO
        ENDDO
        DO I=1,MAX_GATES
         DO J=1,NUM_RAYS
          IF(IKEEP(I,J).EQ.0)SWEEP(I,J)=-999.9
          IF(IKEEP(I,J).EQ.0)SWEEPZ(I,J)=-32.0
         ENDDO
        ENDDO
       ENDDO
      ENDIF
c      DO J=1,NUM_RAYS
c       WRITE(6,*)'J = ',J
c       WRITE(6,'(10F8.2)')(SWEEP(I,J),I=200,500)
c      ENDDO      
c      WRITE(6,*)'IUSEWIND,ICONSERVE = ',IUSEWIND,ICONSERVE
c      WRITE(6,*)'NBINS,IBST,NUM_RAYS = ',NBINS,IBST(1),NUM_RAYS
c      PAUSE
      IF(ICONSERVE.EQ.1)THEN
       WRITE(6,*)'NUM_RAYS INSIDE ICONSERVE IS ',NUM_RAYS
       RALTTIMES2=1.+RA*.002
       IF(RALTIMES2.LT.10.)RALTTIMES2=10.
c       WRITE(6,*)'CHECKING RAYS FOR VR'
       DO J=1,NUM_RAYS
        V00=V0SAVE(J)
c      RDWD(NUM_RAYS)=RADWD
c      RDWS(NUM_RAYS)=RADWS
c      RDVWS(NUM_RAYS)=RADVWS
C        DO I=1,NBINS
C         IF(RDTAIIN(I).LT.10..AND.ABS(EEV).LT.5.)THEN
C         WRITE(6,*)'EEV(J) = ',EEV(J)
        PIDIV=.01745329
        IF(ABS(EEV(J)).LT.90.)THEN
         RADWD=RDWD(J)
         RADWS=RDWS(J)
         GSE=RDGSE(J)
         GSN=RDGSN(J)
c          IF(PELEV(J).GT.0.)THEN
c           RADWD=RADWD+DCORS(2)
c          ELSE
c           RADWD=RADWD+DCORS(1)
c          ENDIF
c          WRITE(6,*)'BEFORE UCOM,VCOM = ',UCOM,VCOM
         UCOM=-SIN(RADWD*PIDIV)*RADWS
         VCOM=-COS(RADWD*PIDIV)*RADWS
c          WRITE(6,*)'UCOM,VCOM,RADWD,RADWS = ',UCOM,VCOM,RADWD,RADWS
c          WRITE(6,*)'EAZM,EEV = ',EAZM(J),EEV(J)
c         WRITE(6,*)'PAZM,PELEV,GSE,GSN,RDVGS(J) = ',
c     1               PAZM(J),PELEV(J),GSE,GSN,RDVGS(J)
         V0FLIGHT=(UCOM*COS(EAZM(J)*PIDIV)
     1             +VCOM*SIN(EAZM(J)*PIDIV))
     1             *COS(EEV(J)*PIDIV)
C
C SEE DISCUSSION ABOVE CONCERNING DV0
C
C         V0G1=-(GSE*COS((EAZM(J)+2.)*PIDIV)+GSN*SIN((EAZM(J)+2.)*PIDIV))
C     1         *COS(EEV(J)*PIDIV)+RDVGS(J)*SIN(EEV(J)*PIDIV)
C         V0G2=-(GSE*COS((EAZM(J)+1.)*PIDIV)+GSN*SIN((EAZM(J)+1.)*PIDIV))
C     1         *COS(EEV(J)*PIDIV)+RDVGS(J)*SIN(EEV(J)*PIDIV)
C         V0G3=-(GSE*COS(EAZM(J)*PIDIV)+GSN*SIN(EAZM(J)*PIDIV))
C     1         *COS(EEV(J)*PIDIV)+RDVGS(J)*SIN(EEV(J)*PIDIV)
C         V0G4=-(GSE*COS((EAZM(J)-1.)*PIDIV)+GSN*SIN((EAZM(J)-1.)*PIDIV))
C     1         *COS(EEV(J)*PIDIV)+RDVGS(J)*SIN(EEV(J)*PIDIV)
C         V0G5=-(GSE*COS((EAZM(J)-2.)*PIDIV)+GSN*SIN((EAZM(J)-2.)*PIDIV))
C     1         *COS(EEV(J)*PIDIV)+RDVGS(J)*SIN(EEV(J)*PIDIV)
c         WRITE(6,*)V00,V0FLIGHT,DV0(J),V0G1,V0G2,V0G3,V0G4,V0G5
         DO I=1,100
          IF(SWEEP(I,J).GT.-800..AND.RDTAIIN(I).LE.10.)THEN
           VDIFF=SWEEP(I,J)-V0FLIGHT
           IF(VDIFF.GT.XNIQTA)THEN
            NDIFF=INT((VDIFF+XNIQTA)/(2.*XNIQTA))
           ELSEIF(VDIFF.LT.-XNIQTA)THEN
            NDIFF=INT((VDIFF-XNIQTA)/(2.*XNIQTA))
           ELSE
            NDIFF=0
           ENDIF
           SWEEPLOOK=SWEEP(I,J)-2.*NDIFF*XNIQTA
           VDIFF=SWEEPLOOK-V0FLIGHT
c            WRITE(6,*)'N,V0FLIGHT,SWEEP,VDIFF,SWEEPLOOK = ',
c     1                 NDIFF,V0FLIGHT,SWEEP(I,J),VDIFF,SWEEPLOOK
           IF(PAZM(J).GT.0.AND.PAZM(J).LT.180.)THEN
            SUMRIGHT=SUMRIGHT+VDIFF
            NSUMRIGHT=NSUMRIGHT+1
            RIGHTDIFF=SUMRIGHT/NSUMRIGHT
           ELSE
            RSUMLEFT=RSUMLEFT+VDIFF
            NSUMLEFT=NSUMLEFT+1
            RLEFTDIFF=RSUMLEFT/NSUMLEFT
           ENDIF
c            WRITE(6,*)'PAZM,RIGHTDIFF,LEFTDIFF = ',
c     1                 PAZM(J),RIGHTDIFF,RLEFTDIFF
          ENDIF
         ENDDO
        ENDIF
C        ENDDO
        IF(V00.GT.XNIQTA)THEN
         N=INT((V00+XNIQTA)/(2*XNIQTA))
        ELSEIF(V00.LT.-XNIQTA)THEN
         N=INT((V00-XNIQTA)/(2*XNIQTA))
c         WRITE(6,*)'NEGATIVE,N,V00'
        ELSE
         N=0
        ENDIF
        V00LOOK=V00-2*N*XNIQTA
c        WRITE(6,*)'J,V00,N,V00LOOK = ',J,V00,N,V00LOOK
        I=1
        NCHECK=0
        DO WHILE(NCHECK.LE.5.AND.I.LE.NBINS)
c         WRITE(6,*)'I GOT HERE I,J,ICONSERVE = ',I,J,ICONSERVE
         IF(SWEEP(I,J).GT.-888.)THEN
          VRDIFF=V00LOOK-SWEEP(I,J)
          IF(VRDIFF.GT.XNIQTA)VRDIFF=VRDIFF-2.*XNIQTA
          IF(VRDIFF.LT.-XNIQTA)VRDIFF=VRDIFF+2.*XNIQTA
C JUNE 1 2020 TEST
C          VRTESTVALUE=100000.
          VRTESTVALUE=.65*XNIQTA
          IF(VRTESTVALUE.LT.8.)VRTESTVALUE=8.
          IF(ABS(VRDIFF).GT.VRTESTVALUE)THEN
C           WRITE(6,*)'IBST,I,J,SWEEP,V00LOOK,VRDIFF = ',
C     +          I,J,SWEEP(I,J),V00LOOK,VRDIFF
           SWEEP(I,J)=-888.8
          ELSE
           NCHECK=NCHECK+1
          ENDIF
         ENDIF
         I=I+1
        ENDDO         
        RADSAVER=0.
        I=2
        ILAST=1
        ILASTLOOK=ILAST
c        WRITE(6,*)'J,SWEEP(300,J) = ',J,SWEEP(300,J)
c        WRITE(6,*)'ILAST = ',ILAST
        DO WHILE(I.LT.NBINS)
         IF(SWEEP(I,J).GT.-800..AND.SWEEP(ILAST,J).GT.-800.)THEN
          VRDIFF=SWEEP(I,J)-SWEEP(ILAST,J)
         IF(ABS(VRDIFF).GT.XNIQTA)THEN
c          WRITE(6,*)'VRDIFF,XNIQTA = ',VRDIFF,XNIQTA
c          WRITE(6,*)'ILAST,I,SWEEPILAST,SWEEPI = ',
c     +    ILAST,I,SWEEP(ILAST,J),SWEEP(I,J)
          IF(VRDIFF.GT.XNIQTA)THEN
           VRDIFF=VRDIFF-2*XNIQTA
          ELSE
           VRDIFF=VRDIFF+2*XNIQTA
          ENDIF
          IF(VRDIFF.GT.XNIQTA)THEN
           VRDIFF=VRDIFF-2*XNIQTA
          ELSE
           VRDIFF=VRDIFF+2*XNIQTA
          ENDIF
          IF(VRDIFF.GT.XNIQTA)THEN
           VRDIFF=VRDIFF-2*XNIQTA
          ELSE
           VRDIFF=VRDIFF+2*XNIQTA
          ENDIF
         ENDIF
C          WRITE(6,*)'VRDIFF,XNIQTA = ',VRDIFF,XNIQTA
C          IF(I-ILAST.EQ.1)VRDIFF=0.
          ILASTLOOK=ILAST
          ILAST=I
         ELSEIF(SWEEP(I,J).GT.-800.)THEN
          ILAST=I
          VRDIFF=0
          ILASTLOOK=ILAST
         ELSE
          VRDIFF=0
         ENDIF
c         WRITE(6,*)'ILAST,J = ',ILAST,J
C         WRITE(6,*)'SWEEP,SWEEPLAST,I,ILAST,J,VRDIFF = ',
C     + SWEEP(I,J),SWEEP(ILASTLOOK,J),I,ILASTLOOK,J,VRDIFF
         IBEFORE=I
         IF(ABS(VRDIFF).GT.VRTESTVALUE)THEN
C           WRITE(6,*)'SETTING BINS TO FLAG FROM ',ILASTLOOK,' TO',NBINS
          DO L=ILASTLOOK,NBINS
C            WRITE(6,*)'L,ILAST,NBINS = ',L,ILAST,NBINS
           SWEEP(L,J)=-888.8
          ENDDO
C           WRITE(6,*)'J,V0SAVE(J)'
C           WRITE(6,5320)(SWEEP(NNN,J),NNN=1,NBINS)
          ILAST=ILASTLOOK
C*****ADDED FOR SAME REASON
          I=ILAST
         ENDIF
C*****LINES BELOW ADDED TO DO VRDIFF CHECK ALWAYS ALONG RAY
C*****BUT RADIAL GAP ONLY WHEN ICONSERVE EQ 1
         I=I+1
        ENDDO
       ENDDO
c      IF(ICONSERVE.EQ.1)THEN
c4444   WRITE(6,*)'CHECKING RAYS FOR GAP'
 4444  DO J=1,NUM_RAYS
c        write(6,*)'nbins = ',nbins
        V00=V0SAVE(J)
        IF(V00.GT.XNIQTA)THEN
         N=INT((V00+XNIQTA)/(2*XNIQTA))
        ELSEIF(V00.LT.-XNIQTA)THEN
         N=INT((V00-XNIQTA)/(2*XNIQTA))
c         WRITE(6,*)'NEGATIVE,N,V00'
        ELSE
         N=0
        ENDIF
        V00LOOK=V00-2*N*XNIQTA
        VRBEFORE=V00LOOK
        RADSAVER=0
        DO I=1,NBINS
C*****THIS LINE REMOVED FOR ABOVE REASON         I=IBEFORE
C*****END OF ADDED LINES
C         WRITE(6,*)'I,J,SWEEP,RDTAIIN,VRBEFORE,RADSAVER = ',
C     +     I,J,SWEEP(I,J),RDTAIIN(I),VRBEFORE,RADSAVER
C TESTING A CHANGE HERE JULY 2 2018 FROM 3.5 TO 10.O DIRECTLY BELOW
C WAVE RDTAIIN.LT.3.5
         IF(SWEEP(I,J).GT.-200..OR.RDTAIIN(I).LT.5.
     +     .OR.RDTAIIN(I).GT.999.9)THEN
c     +    RDTAIIN(I).GT.999.9.OR.I.LT.IBST(1)+512)THEN
          IF(RDTAIIN(I)-RADSAVER.GT.5.AND.RDTAIIN(I).GE.3.5.AND.
     +      VRBEFORE.GT.-200..AND.RDTAIIN(I)-RADSAVER.LT.RADSAVERTEST2.
     +      AND.RDTAIIN(I).LT.900.)THEN
           VRDIFF=VRBEFORE-SWEEP(I,J)
           IF(VRDIFF.GT.XNIQTA)VRDIFF=VRDIFF-2.*XNIQTA
           IF(VRDIFF.LT.-XNIQTA)VRDIFF=VRDIFF+2.*XNIQTA
           VRTESTVALUE=.5*XNIQTA
           IF(VRTESTVALUE.LT.8.)VRTESTVALUE=8.
           IF(ABS(VRDIFF).GT.VRTESTVALUE.AND.
     +       RDTAIIN(I)-RADSAVER.GT.RADSAVERTEST.
     +       AND.SWEEP(L,J).GT.-200.)THEN
c             WRITE(6,*)'I,J,VRDIFF,VRTESTVALUE,RDTAIIN(I) = ',
c     +       I,J,VRDIFF,VRTESTVALUE,RDTAIIN(I) 
            DO L=I,NBINS
             SWEEP(L,J)=-888.8
            ENDDO
            GO TO 6305
           ELSE
            VRBEFORE=SWEEP(I,J)
           ENDIF
C MOVED THE LINE BELOW OUTSIDE IF 
           RADSAVER=RDTAIIN(I)
C           IF(SWEEP(I,J).GT.-200.)VRBEFORE=SWEEP(I,J)
c          WRITE(6,*)'ONE,I,RADSAVER,SWEEP = ',I,RADSAVER,SWEEP(I,J)
          ENDIF
C          RADSAVER=RDTAIIN(I)
         ELSEIF(RDTAIIN(I)-RADSAVER.GE.RADSAVERTEST2
     +     .AND.RDTAIIN(I).LT.1000.)THEN
          DO L=I,NBINS
           SWEEP(L,J)=-888.8
          ENDDO
          GO TO 6305
         ENDIF
         IF(SWEEP(I,J).GT.-200.)THEN
          VRBEFORE=SWEEP(I,J)
          RADSAVER=RDTAIIN(I)
         ENDIF
C         WRITE(6,*)'I,J,RDTAIIN,SWEEP,RADSAVER,VRBEFORE = ',
C     1    I,J,RDTAIIN(I),SWEEP(I,J),RADSAVER,VRBEFORE
c***REMOVED FOR ABOVE REASON        ENDDO
c 6305   WRITE(6,*)'J,V00SAVE,PAZM = ',J,V0SAVE(J),PAZM(J)
c        WRITE(6,5320)(SWEEP(I,J),I=1,NBINS)
 5320   FORMAT(10F8.1)
        ENDDO
 6305  ENDDO
      ENDIF
c      WRITE(6,*)'END GAP CHECK'
      XNIQTA1=XNIQTA
c      CALL DEFRECKLE(IMAXBINS,JMAXRAYS,
c     1 NBINS,NUM_RAYS,PAZM,SWEEP,VROUT,XNIQTA1)
      CALL DEFRECKLEBOTH(IMAXBINS,JMAXRAYS,
     1 NBINS,NUM_RAYS,PAZM,SWEEP,VROUT,XNIQTA1,SWEEPZ,ZOUT)
c      WRITE(6,*)'RETURNED FROM DEFRECKLE'
c      DO J=1,NUM_RAYS
c       WRITE(6,*)'AFTER DEFRECKLE AND J = ',J
c       WRITE(6,'(10F8.2)')(SWEEP(I,J),I=200,500)
c      ENDDO
c      PAUSE
C      IF(IGUESS.EQ.1) GO TO 66666
c      WRITE(6,*)'STARTING UNFLD LOOP'
      DO J=1,NUM_RAYS
       V00=V0SAVE(J)
       v00eev=eev(j)
       v00azm=eazm(j)
c       WRITE(6,*)'J,XNIQTA,EEV,EAZM,V00,PELEV,PAZM = ',
c     1   J,XNIQTA,V00EEV,V00AZM,V00,PELEV(J),PAZM(J)
       M=INOB(1)
       IRS=1
       NB=NBINS
       VN=XNIQTA
C       WRITE(6,*)'VN,XNIQTA = ',VN,XNIQTA
c       WRITE(6,*)'NB,HEADSTORE(J),TRACKSTORE(J) = ',
c     1 NB,HEADSTORE(J),TRACKSTORE(J)
       DO I=1,NBINS
        RAY(I)=SWEEP(I,J)
c        IF(ABS(RAY(I)).GT.20.AND.ABS(RAY(I)).LT.100)THEN
c           WRITE(6,*)'I,RAY(I) = ',I,RAY(I)
c        ENDIF
        IF(ABS(HEADSTORE(J)).LT..1)RAY(I)=-888.8
        DIFFHDTRK=HEADSTORE(J)-TRACKSTORE(J)
        IF(ABS(DIFFHDTRK).LT..1)RAY(I)=-888.8
        IF(IUSEWIND.NE.1)THEN
         VRRAD(I,J)=-888.8
         IF(RADSWEEP(I,J).LT.G4P3RADMIN)THEN
          RAY(I)=-888.8
         ENDIF
c         write(6,*)'iusewind,vrrad,ray = ',iusewind,vrrad(i,j),ray(i)
c         WRITE(6,*)'I,J,RADSWEEP,G4P3RADMIN = ',
c     1              I,J,RADSWEEP(I,J),G4P3RADMIN
        ELSEIF(IUSEWIND.EQ.1.AND.IVARIATIONAL.NE.1)THEN
c         write(6,*)'iusewind,vrrad,ray = ',iusewind,vrrad(i,j),ray(i)
c         WRITE(6,*)'I,J,RADSWEEP,G4P3RADMIN = ',
c     1              I,J,RADSWEEP(I,J),G4P3RADMIN
         IF(VRRAD(I,J).LT.-800..OR.RADSWEEP(I,J).LT.G4P3RADMIN)THEN
          RAY(I)=-888.8
         ENDIF
        ENDIF
        URAY(I)=VRRAD(I,J)
       ENDDO
c       WRITE(6,*)'I GOT HERE MARCH'
c         WRITE(6,*)'RAY AT J = '
c         WRITE(6,'(10F8.2)')(RAY(I),I=1,44)
c         WRITE(6,*)'URAY AT J = '
c         WRITE(6,'(10F8.2)')(URAY(I),I=1,44)
c       write(6,*)'V00,AZM = ',V00,az_el(1,j)
c       write(6,*)'calling unfolder'
c       WRITE(6,*)'RAY'
c       WRITE(6,1754)(RAY(I),I=1,800)
c       WRITE(6,*)'URAY'
c       WRITE(6,1754)(URAY(I),I=1,800)
c       WRITE(6,*)'UNFLD1,IAFTFORE,VN = ',IAFTFORE,VN
       CALL UNFLD1(V00,VN,M,IRS,NB,RAY,URAY,NB)
c         WRITE(6,*)'AFTER UNFLD1 AND VN, AND J = ',VN,J
c         WRITE(6,'(10F8.2)')(URAY(I),I=1,44)
c       WRITE(6,*)'UNFLD1,J = ',J
c       WRITE(6,5445)(URAY(I),I=1,200)
 5445  FORMAT(10F8.1)
c       WRITE(6,*)'VN,V00,AZM = ',VN,V00,AZ_EL(1,J)
c       WRITE(6,*)'BETWEEN UNFOLDS'
c       WRITE(6,*)'RAY'
c       WRITE(6,1754)(RAY(I),I=1,800)
c       WRITE(6,*)'URAY'
c       WRITE(6,1754)(URAY(I),I=1,800)
       V00BEFORE=V00
       CALL UNFLDNEW(V00,VN,M,IRS,NB,RAY,URAY,NB)
       V00=V00BEFORE
       IF(IUSEWIND.NE.1)THEN
       NBINTEST=0
       VELSUMAVG=0.
       I=0
       DO WHILE(NBINTEST.LT.M.AND.I.LT.NB)
          I=I+1
          IF(URAY(I).GT.-800.)THEN
             VELSUMAVG=VELSUMAVG+ABS(URAY(I)-V00)
             NBINTEST=NBINTEST+1
          ENDIF
       ENDDO
       IF(NBINTEST.GE.M)THEN
          VELSUMAVG=VELSUMAVG/NBINTEST
       ELSE
          VELSUMAVG=-888.88
       ENDIF
c       WRITE(6,*)'NBINTEST,VELSUMAVG,V00 = ',NBINTEST,VELSUMAVG,V00
       IF(ABS(VELSUMAVG).GT.VNFRACTION*VN)THEN
c          WRITE(6,*)'BLANKING RAY BECAUSE OF BAD FIRST GATES'
          DO I=1,NB
             URAY(I)=-888.88
          ENDDO
       ENDIF
       ENDIF
C         WRITE(6,*)'AFTER UNFLDNEW AND VN AND J = ',VN,J
c         WRITE(6,'(10F8.2)')(URAY(I),I=1,44)
c       WRITE(6,*)'UNFLDNEW,J = ',J
c       WRITE(6,5445)(URAY(I),I=1,200)
cc       WRITE(6,*)'AFTER UNFLD'
c       WRITE(6,*)'RAY'
c       WRITE(6,1754)(RAY(I),I=1,800)
c       WRITE(6,*)'URAY'
c       WRITE(6,1754)(URAY(I),I=1,800)
 1754  FORMAT(10F8.2)
c       write(6,*)'j,v00,gse,gsn,radvgs,ucom,vcom,vws = ',
c     1            j,v00,gse,gsn,radvgs,ucom,vcom,radvws
c       WRITE(6,'(5F7.1)')PAZM(J),HEADSTORE(J),TRACKSTORE(J),
c     1                   EEV(J),EAZM(J),AZ_EL(1,J),AZ_EL(2,J)
c       WRITE(6,'(11F7.1)')v00,(ray(i),i=1,10)
c       WRITE(6,'(11F7.1)')v00,(uray(i),i=1,10)
       DO I=1,NBINS
        SWEEP(I,J)=URAY(I)
       ENDDO
c       write(6,*)'finished calling unfolder'
c      WRITE(6,*)'SWEEP AT = ',J
c      WRITE(6,'(10F8.2)')(SWEEP(I,J),I= 1,44)
      ENDDO
c      WRITE(6,*)'I GOT HERE MARCH 2'
      XXNIQTA=XNIQTA*.7
      XXNIQ=XNIQTA
c      write(6,*)'setting nyq to ',xxniq
      DO I=1,NBINS
       DO J=1,NUM_RAYS
        NYQ(I,J)=XXNIQ
       ENDDO
      ENDDO
c      write(6,*)'finished setting nyq'
c      write(6,*)'calling aziunfld'
      DO J=1,NUM_RAYS
       DO I=1,MAX_GATES
        SWEEPSAVE(I,J)=SWEEP(I,J)
       ENDDO
      ENDDO
c      WRITE(6,*)'I GOT HERE MARCH 4'
c      WRITE(6,*)'I GOT HERE MARCH 4, AND I8 = ',I8
      NB=NBINS
      IF(I8.EQ.1)THEN
c       WRITE(6,*)'NUM_RAYS INSIDE ICONSERVE IS ',NUM_RAYS
       DO J=1,NUM_RAYS
        CALL VRLOCATER(TIMES,OLAT,OLON,
     + RLAT,RLON,RA,EV,AZM,RDTAIIN,XR,YR,ZR,
     + ISCANDIM,SMOTIONU,SMOTIONV,CENTIME)
        RADSAVER=0.
        I=1
c        WRITE(6,*)'J,SWEEP(300,J) = ',J,SWEEP(300,J)
        DO WHILE(I.LT.NBINS)
         IF(SWEEP(I,J).GT.-98..OR.RDTAIIN(I).LT.2.
     +     .OR.RDTAIIN(I).GT.999.9)THEN
c     +    RDTAIIN(I).GT.999.9.OR.I.LT.IBST(1)+512)THEN
          RADSAVER=RDTAIIN(I)
          I=I+1
c          WRITE(6,*)'ONE,I,RADSAVER,SWEEP = ',I,RADSAVER,SWEEP(I,J)
         ELSEIF(RDTAIIN(I)-RADSAVER.GT.1.)THEN
c          WRITE(6,*)'TWO,I,RDTAIIN(I),RADSAVER,SWEEP(I,J) = ',

c     +       I,RDTAIIN(I),RADSAVER,SWEEP(I,J)
          IF(I8.NE.1)THEN
           DO L=I,NBINS
            SWEEP(L,J)=-888.88
           ENDDO
           GO TO 6306
          ELSEIF(I8.EQ.1)THEN
           DO L=I,NBINS
            XG=XR(L)
            YG=YR(L)
            RRADIUS=SQRT(XG*XG+YG*YG)
c           WRITE(6,*)'L,J,XG,YG,RRADIUS,OLAT,RLAT,OLON,RLON = ',
c     1        L,J,XG,YG,RRADIUS,OLAT,RLAT,OLON,RLON
            IF(RRADIUS.LT.30.)VRRAD(L,J)=-888.88
           ENDDO
           GO TO 6306
          ENDIF
         ELSE
          I=I+1
         ENDIF
        ENDDO
 6306  ENDDO
      ENDIF
c      WRITE(6,*)'I GOT HERE MARCH 3'
      ALLOWEDDIFF=XNIQTA*.4
      IF(ALLOWEDDIFF.LT.8.)ALLOWEDDIFF=8.
      IF(IUSEWIND.EQ.1.AND.NUM_RAYS.GT.0.)THEN
       ALLOWEDDIFF=20.
       XNIQTAHALF=XNIQTA*.5
       IF(ALLOWEDDIFF.GT.XNIQTA)ALLOWEDDIFF=XNIQTA
       IF(ALLOWEDDIFF.LT.8.)ALLOWEDDIFF=8.
       IF(I8.EQ.1)ALLOWEDDIFF=8.
c       ALLOWEDDIFF=8.
       WRITE(6,*)'XXNIQ,XNIQTA = ',XXNIQ,XNIQTA
c       IF(IWAVE.GT.0)ALLOWEDDIFF=8.
C       WRITE(6,*)XNIQTAHALF,ALLOWEDDIFF
c       WRITE(6,*)'IVARIATIONAL = ',IVARIATIONAL
c       PAUSE
       IF(IVARIATIONAL.EQ.1)THEN
        VTOL=ALLOWEDDIFF
        VTOL1=ALLOWEDDIFF*.5
c        WRITE(6,*)XNIQTA,ALLOWEDDIFF
C       CALL AZIUNFLDG(SWEEP,ISEG,ISEGE,MAX_GATES,NB,MAX_RAYS,XXNIQTA,
C     1 RDTAIIN,AZ_EL,XXNIQ,NUM_RAYS,VRRAD,IUSEWIND,PAZM,ALLOWEDDIFF)
        VFLAG=-888.8
        INDEXCALL=1
        CALL CONTIG(SWEEP,ICOL,JCOL,MAX_HRD_DIM,MAX_RAYS,VFLAG,
     1              NB,NUM_RAYS,PAZM,PELEV,VTOL1,XXNIQ)
        CALL VARUNFLD(SWEEP,MAX_GATES,NB,MAX_RAYS,RDTAIIN,AZ_EL,
     1                NUM_RAYS,VRRAD,PAZM,XXNIQ,JCOL,ALLOWEDDIFF,
     1                INDEXCALL,VTOL1)
       ELSEIF(NUM_RAYS.GT.0)THEN
        CALL AZIUNFLDG(SWEEP,ISEG,ISEGE,MAX_GATES,NB,MAX_RAYS,XXNIQTA,
     1 RDTAIIN,AZ_EL,XXNIQ,NUM_RAYS,VRRAD,IUSEWIND,PAZM,ALLOWEDDIFF)
       ENDIF
      ELSE
       CALL AZIUNFLD(SWEEP,ISEG,ISEGE,MAX_GATES,NB,MAX_RAYS,XXNIQTA,
     1 RDTAIIN,AZ_EL,XXNIQ,NUM_RAYS,VRRAD,IUSEWIND,PAZM,ALLOWEDDIFF)
c        DO J=1,NUM_RAYS
c         WRITE(6,*)'AZIUNFLD J = ',J
c         WRITE(6,5445)(SWEEP(I,J),I=1,200)
c        ENDDO
      ENDIF
      DO J=1,NUM_RAYS
       DO I=1,MAX_GATES
        IF(ZRSWEEP(I,J).LT.0.)THEN
         SWEEP(I,J)=-888.88
         SWEEPZ(I,J)=-32.0
        ENDIF
       ENDDO
      ENDDO
c      DO J=1,NUM_RAYS
c         WRITE(68,'(3I2)')IIHH,IIMM,IISS
c         WRITE(68,'(2F8.1)')AZ_EL(1,J),AZ_EL(2,J)
c         WRITE(68,'(10F8.1)')(SWEEPSAVE(IL,J),IL=1,80)
c         WRITE(68,'(10F8.1)')(SWEEP(IL,J),IL=1,80)
c      ENDDO
c      write(6,*)'returned from aziunfld'
      FLAGVAL=-888.8
      IVADFLAG=10
      IMINRNG=1
      NRANG=NBINS
      NSWEEPSUM=0
      YVRSUM=0
      XVRSUM=0
      VVRSUM=0
      DO J=1,NUM_RAYS
c       write(6,*)'pazm,sweep = ',pazm(j),sweep(300,j)
       IF(SWEEP(5,J).GT.-800.)THEN
        NSWEEPSUM=NSWEEPSUM+1
        YVRSUM=COS(PAZM(J))+YVRSUM
        XVRSUM=SIN(PAZM(J))+XVRSUM
        VVRSUM=VVRSUM+SWEEP(5,J)
       ENDIF
      ENDDO
      IF(NSWEEPSUM.GT.0)THEN
       YTEST=YVRSUM/NSWEEPSUM
       XTEST=XVRSUM/NSWEEPSUM
       VRTEST=VVRSUM/NSWEEPSUM
c       WRITE(6,*)'NSWEEPSUM,YVRSUM,XVRSUM,VVRSUM = ',
c     1            NSWEEPSUM,YVRSUM,XVRSUM,VVRSUM
c       WRITE(6,*)'NSWEEPSUM,YTEST,XTEST,VRTEST = ',
c     1            NSWEEPSUM,YTEST,XTEST,VRTEST
c       PAUSE
      ENDIF
44444 DO J=1,NUM_RAYS
       DO I=1,NBINS
        SWEEPSAVE(I,J)=SWEEP(I,J)
       ENDDO
      ENDDO
      ILATERSWEEP=1
c      WRITE(6,*)'I150 = ',I150
c      WRITE(6,*)'ICALLSWEEPIN = ',ICALLSWEEPIN
c      WRITE(6,*)'INEWRAD = ',INEWRAD
      IF(ICALLSWEEPIN.EQ.0.OR.INEWRAD.EQ.1)THEN
       RADRES=RADIITA(3)-RADIITA(2)
       SXBIBINAVG=SX
       IF(SXBIBINAVG.GT.1.2)SXBIBINAVG=1.2
       IBINAVG=INT((SXBIBINAVG+.001)/RADRES/2)*2
       IF(IBINAVG.LT.1)IBINAVG=1
      WRITE(6,*)'SX = ',SX
      WRITE(6,*)'IBINAVG,RADRES,SXBIBINAVG = ',IBINAVG,RADRES,SXBIBINAVG
c       IF(RADRES.LT..100)THEN
c        IBINAVG=2
c       ELSE
c        IBINAVG=1
c       ENDIF
       MAXISET=60./RADRES/IBINAVG
       IF(I150.EQ.0)MAXISET=64
c       WRITE(6,*)'MAXISET,RADRES,IBINAVG = ',MAXISET,RADRES,IBINAVG
c       write(6,*)'isweepset = ',isweepset
c       pause
       DO I=1,MAX_HRD_DIM
        RDTAI(I)=1000.
       ENDDO
      ENDIF
      WRITE(6,*)'END I150 = ',I150
c      PAUSE
      IF(I150.EQ.1)THEN
c       ITEST1=MAX_HRD_DIM/IBINAVG
       ITESTALL=MAXISET
       ITEST1=MAXISET
       ITEST2=-1
       ITEST3=-1
       ITEST4=-1
       MULT1=IBINAVG
       MULT2=-1
       MULT3=-1
       MULT4=-1
       KSTART1=1
       KSTART2=-1000
       KSTART3=-1000
       IF(ISIGMET.EQ.5)THEN
          ITEST1=64
          MULT1=8
          MAXISET=64
          ITESTALL=64
       ENDIF
      ELSE
       MULT1=16
       MULT2=8
       MULT3=4
       KSTART1=1
       KSTART2=257
       KSTART3=385
       ITEST1=16
       ITEST2=17
       ITEST3=32
       ITEST4=33
       ITESTALL=64
      ENDIF
c      WRITE(6,*)'RDTAIIN = '
c      WRITE(6,652)RDTAIIN
c 652  FORMAT(10F8.2)
c      PAUSE
      DO J=1,NUM_RAYS
       DO I=1,ITESTALL
        IF(I.LE.ITEST1)THEN
         K=KSTART1+(I-1)*MULT1
         M=I*MULT1
        ELSEIF(I.GE.ITEST2.AND.I.LE.ITEST3)THEN
         K=KSTART2+(I-ITEST2)*MULT2
         M=K+MULT2-1
        ELSEIF(I.GE.ITEST4)THEN
         K=KSTART3+(I-ITEST4)*MULT3
         M=K+MULT3-1
        ENDIF
c        IF(J.EQ.10)THEN
c         WRITE(6,*)'KSTART1,ITEST1,MULT1 = ',KSTART1,ITEST1,MULT1
c         WRITE(6,*)'KSTART2,ITEST2,MULT2 = ',KSTART2,ITEST2,MULT2
c         WRITE(6,*)'KSTART2,ITEST2,MULT3 = ',KSTART3,ITEST3,MULT3
c         WRITE(6,*)'K,M = ',K,M
c        ENDIF
        SUM=0.
        SUMD=0.
        SUMND=0.
        SUMN=0.
        RADSUM=0.
        RADSUMN=0.
c        PAUSE
        DO L=K,M
c         IF(J.EQ.10)WRITE(6,*)'L,RDTAIIN(L) = ',L,RDTAIIN(L)
c         IF((ICALLSWEEPIN.EQ.0..OR.INEWRAD.EQ.1).AND.J.EQ.1)THEN
C         IF(ICALLSWEEPIN.EQ.0..OR.INEWRAD.EQ.1)THEN
          IF(RDTAIIN(L).LT.200..AND.L.LE.MAX_HRD_DIM)THEN
           RADSUMN=RADSUMN+1
           RADSUM=RADSUM+RDTAIIN(L)
          ENDIF
C         ENDIF
c         if(j.eq.1)
c     1   write(6,*)'i,l,radsumn,radsum,RDTAIIN,icallsweepin = ',
c     1 i,l,radsum,radsumn,RDTAIIN(l),icallsweepin
         IF(SWEEP(L,J).GT.-888.8.AND.L.LE.NBINS)THEN
          SUM=SUM+SWEEP(L,J)
          SUMN=SUMN+1.
         ENDIF
         IF(SWEEPZ(L,J).GT.-20..AND.L.LE.NBINS)THEN
          SUMD=SUMD+SWEEPZ(L,J)
          SUMND=SUMND+1.
c          WRITE(6,*)'L,J,SUMD,SUMND = ',L,J,SUMD,SUMND
         ENDIF
        ENDDO
        IF(SUMN.GT.0.)THEN
         SWEEP(I,J)=SUM/SUMN
        ELSE
         SWEEP(I,J)=-888.8
        ENDIF
        IF((ICALLSWEEPIN.EQ.0..OR.INEWRAD.EQ.1).AND.J.LT.801)THEN
         IF(RADSUMN.GT.0.)THEN
          RDTAI(I)=RADSUM/RADSUMN
c         ELSE
c          RDTAI(I)=1000.
         ENDIF
c         WRITE(6,*)'I,RADSUM,RADSUMN,RDTAI = ',
c     +              I,RADSUM,RADSUMN,RDTAI(I)      
        ENDIF
        IF(SUMND.GT.0.)THEN
         SWEEPZ(I,J)=SUMD/SUMND
        ELSE
         SWEEPZ(I,J)=-32.
        ENDIF
c        WRITE(6,*)'I,J,K,M,SUMD,SUMND,SWEEPZ(I,J) = ',I,J,K,M,
c     1 SUMD,SUMND,SWEEPZ(I,J)
C        IF(SWEEPZ(I,J).GT.64.)THEN
C         WRITE(6,*)'I,J,SWEEPZ = ',I,J,SWEEPZ(I,J)
C         WRITE(6,*)'K,M,SWEEPZ = ',K,M,(SWEEPZ(L,J),L=K,M)
C         WRITE(6,*)'SUMD,SUMND = ',SUMD,SUMND
C         WRITE(6,*)'NBINS = ',NBINS
C         PAUSE
C        ENDIF
c        if(j.eq.1)then
c         write(6,*)'sum,sumn,sumnd,sumd,radsum,radsumn = ',
c     1             sum,sumn,sumnd,sumd,radsum,radsumn
c         write(6,*)'i,rdtai,sweep,sweepz = ',
c     1             i,rdtai(i),sweep(i,j),sweepz(i,j)
c        endif
       ENDDO
      ENDDO
      NBINSPARM=MAX_HRD_DIM
c      WRITE(6,*)'NBINSPARM = ',NBINSPARM
c      WRITE(6,*)'RDTAI = ',(RDTAI(I),I=1,NBINSPARM)
      DO I=MAX_HRD_DIM,1,-1
c       WRITE(6,*)'NBINSPARM = ',NBINSPARM
c       WRITE(6,*)'I,RDTAI = ',I,RDTAI(I)
       IF(RDTAI(I).GT.0..AND.RDTAI(I).LT.1000.)THEN
        IF(I.GT.NBINSPARM)NBINSPARM=I
        GO TO 76383
       ENDIF
      ENDDO
76383 IF(NBINSPARM.GT.1)NBINSPARM=NBINSPARM-2
c      WRITE(6,*)'NBINSPARM = ',NBINSPARM
c      DO J=1,NUM_RAYS
c       WRITE(6,*)'J = ',J
c       WRITE(6,8683)(SWEEP(I,J),I=1,NBINSPARM)
c 8683  FORMAT(10F8.2)
c      ENDDO
c      PAUSE
c      write(6,*)'tmsweep = ',(tmsweep(nr),nr=1,num_rays)
c      DO I=1,ITEST1
c       WRITE(6,*)'NEWSWEEP,I,RDTAI = ',I,RDTAI(I)
c      ENDDO
c      WRITE(6,*)'NBINSPARM = ',NBINSPARM
c      WRITE(6,*)'RDTAI = ',(RDTAI(I),I=1,NBINSPARM)
       NBINSEND=MAXISET
c      DO J=1,NUM_RAYS
c       WRITE(6,*)'SENDING SWEEP TO ABCD HERE AND J = ',J
c       WRITE(6,'(10F8.2)')(SWEEP(I,J),I=1,44)
c      ENDDO
c      IF(DRIFTCORSUMAVG.GT.-100.)THEN
c       WRITE(64,'(3I2.2,2F10.3)')IH,IM,IS,DRIFTCORSUMAVG,
c     1 NDRIFTCORSUM
c      ENDIF
      IF(ICALLSWEEPIN.EQ.0)THEN
       ICALLSWEEPIN=1
       GO TO 4275
      ENDIF
      WRITE(6,*)'XNIQTA = ',XNIQTA
      RETURN
      END 
      SUBROUTINE GROUNDCHECK(SWEEP,SWEEPZ,NUM_RAYS,I,JSTART,ICHECK)
      INCLUDE "hrd_radar_settings.f"
      PARAMETER(MAX_RAYS=800)
      PARAMETER(MAX_GATES=MAX_HRD_DIM)
      REAL SWEEP(MAX_GATES,MAX_RAYS),SWEEPZ(MAX_GATES,MAX_RAYS)
      IF(ICHECK.LT.1.OR.ICHECK.GT.2)THEN
       WRITE(6,*)'PROBLEM WITH ICHECK IN GROUNDCHECK'
       STOP
      ENDIF
c      IF(JSTART.GT.2.AND.JSTART.LT.NUM_RAYS-1)THEN
c       WRITE(6,*)'I,JSTART,SWEEPZ = ',I,JSTART,
c     + (SWEEPZ(I,J),J=JSTART-2,JSTART)
c      ENDIF
c      PAUSE
      IF(SWEEPZ(I,JSTART).GT.-32.)THEN
       WRITE(6,*)'SWEEP(I,JSTART) GT -999.'
       WRITE(6,*)'ICHECK,I,JSTART,SWEEP,SWEEPZ = ',
     +  ICHECK,I,JSTART,SWEEP(I,JSTART),SWEEPZ(I,JSTART)
       STOP
      ENDIF
      IDBZTEST=0
c      WRITE(6,*)'GROUNDCHECK STARTING AND JSTART = ',JSTART
c      IF(ICHECK.EQ.1.AND.JSTART.GE.5)THEN
c       JSTARTCHECK1=0
c       DO J=JSTART,JSTART-4
c        IF(SWEEPZ(I,J).GT.48.)JSTARTCHECK1=1
c       ENDDO
c       IF(JSTARTCHECK1.EQ.1)THEN
c         J=JSTART
c         WRITE(6,6296)J,(SWEEPZ(I,J),J=JSTART,JSTART-4,-1)
c 6296    FORMAT(I5,6F10.2)
c       ENDIF
c      ELSEIF(ICHECK.EQ.2.AND.JSTART+4.LE.NUM_RAYS)THEN
c       JSTARTCHECK2=0
c       DO J=JSTART,JSTART+4
c        IF(SWEEPZ(I,J).GT.48.)JSTARTCHECK2=1
c       ENDDO
c       IF(JSTARTCHECK2.EQ.1)THEN
c         J=JSTART
c         WRITE(6,6296)J,(SWEEPZ(I,J),J=JSTART,JSTART+4)
c       ENDIF
c      ENDIF
      IF(ICHECK.EQ.1)THEN
       IF(JSTART.LT.5)THEN
        DO J=JSTART,1,-1
         SWEEPZ(I,J)=-32.
         SWEEP(I,J)=-888.8
        ENDDO
        RETURN
       ELSE
        IF(SWEEPZ(I,JSTART-1).GT.40..OR.
     +     SWEEPZ(I,JSTART-4).GT.40.)IDBZTEST=1
c        IF(IDBZTEST.GT.0)WRITE(6,*)'BEFORE RIGHT,JSTART,SWEEPZ = ',
c     +    JSTART,(SWEEPZ(I,J),J=JSTART-9,JSTART)
       ENDIF
c       WRITE(6,*)'I,JSTART,SWEEPZ = ',
c     +  I,J,(SWEEPZ(I,J),J=JSTART-2,JSTART)
       IF(SWEEPZ(I,JSTART).LE.-32..AND.SWEEPZ(I,JSTART-1).GT.-32..AND.
     +    SWEEPZ(I,JSTART-2).LE.-32.)THEN
        SWEEPZ(I,JSTART-1)=-32.
        SWEEP(I,JSTART-1)=-888.8
c        write(6,*)'removed'
       ENDIF
       IF(SWEEPZ(I,JSTART).LE.-32..AND.SWEEPZ(I,JSTART-1).GT.-32..AND.
     +    SWEEPZ(I,JSTART-3).LE.-32.)THEN
        SWEEPZ(I,JSTART-1)=-32.
        SWEEP(I,JSTART-1)=-888.8
        SWEEPZ(I,JSTART-2)=-32.
        SWEEP(I,JSTART-2)=-888.8
c        write(6,*)'removed 2'
       ENDIF
       IF(SWEEPZ(I,JSTART).LE.-32..AND.SWEEPZ(I,JSTART-1).GT.-32..AND.
     +    SWEEPZ(I,JSTART-4).LE.-32.)THEN
        SWEEPZ(I,JSTART-1)=-32.
        SWEEP(I,JSTART-1)=-888.8
        SWEEPZ(I,JSTART-2)=-32.
        SWEEP(I,JSTART-2)=-888.8
        SWEEPZ(I,JSTART-3)=-32.
        SWEEP(I,JSTART-3)=-888.8
c        write(6,*)'removed 3'
       ENDIF
       DO J=JSTART-1,JSTART-3,-1
        IF(SWEEPZ(I,J).GT.-32..AND.SWEEPZ(I,J-1).GT.-32.AND.
     +      SWEEPZ(I,J)-SWEEPZ(I,J-1).GT.3.)THEN
c        IF(SWEEPZ(I,J)-SWEEPZ(I,J-1).GT.10.)THEN
         DO JJ=J,JSTART
          SWEEPZ(I,JJ)=-32.
          SWEEP(I,JJ)=-888.8
         ENDDO
        ENDIF
       ENDDO
c       IF(IDBZTEST.GT.0)WRITE(6,*)'AFTER RIGHT,JSTART,SWEEPZ = ',
c     +   JSTART,(SWEEPZ(I,J),J=JSTART-9,JSTART)
c       IF(IDBZTEST.GT.0)WRITE(6,*)'ZR AFTER RIGHT,JSTART,SWEEPZ = ',
c     +   JSTART,(ZRSWEEP(I,J),J=JSTART-9,JSTART)
c       IF(IDBZTEST.GT.0)WRITE(6,*)'RADIUS = ',RD(I)
c       IF(SWEEPZ(I,JSTART-9).GT.20.)THEN
c        WRITE(6,*)'SWEEPZ(I,JSTART-9) = ',SWEEPZ(I,JSTART-9)
c        WRITE(6,*)'ZRSWEEP(I,JSTART-9) = ',ZRSWEEP(I,JSTART-9)
c       WRITE(6,*)'RADIUS = ',RD(I)
c        PAUSE
c       ENDIF
      ELSE
       IF(NUM_RAYS-JSTART.LT.4)THEN
        DO J=JSTART,NUM_RAYS
         SWEEPZ(I,J)=-32.
         SWEEP(I,J)=-888.8
        ENDDO
        RETURN
       ELSE
        IF(SWEEPZ(I,JSTART+1).GT.40..OR.
     +     SWEEPZ(I,JSTART+4).GT.40.)IDBZTEST=1
c        IF(IDBZTEST.GT.0)WRITE(6,*)'BEFORE LEFT,JSTART,SWEEPZ = ',
c     +   JSTART,(SWEEPZ(I,J),J=JSTART,JSTART+9)
       ENDIF
c       WRITE(6,*)'I,JSTART,SWEEPZ = ',
c     +  I,J,(SWEEPZ(I,J),J=JSTART+1,JSTART+2)
       IF(SWEEPZ(I,JSTART).LE.-32..AND.SWEEPZ(I,JSTART+1).GT.-32..AND.
     +    SWEEPZ(I,JSTART+2).LE.-32.)THEN
        SWEEPZ(I,JSTART+1)=-32.
        SWEEP(I,JSTART+1)=-888.8
c        write(6,*)'removed'
       ENDIF
       IF(SWEEPZ(I,JSTART).LE.-32..AND.SWEEPZ(I,JSTART+1).GT.-32..AND.
     +    SWEEPZ(I,JSTART+3).LE.-32.)THEN
        SWEEPZ(I,JSTART+1)=-32.
        SWEEP(I,JSTART+1)=-888.8
        SWEEPZ(I,JSTART+2)=-32.
        SWEEP(I,JSTART+2)=-888.8
c        write(6,*)'removed 2'
       ENDIF
       IF(SWEEPZ(I,JSTART).LE.-32..AND.SWEEPZ(I,JSTART+1).GT.-32..AND.
     +    SWEEPZ(I,JSTART+4).LE.-32.)THEN
        SWEEPZ(I,JSTART+1)=-32.
        SWEEP(I,JSTART+1)=-888.8
        SWEEPZ(I,JSTART+2)=-32.
        SWEEP(I,JSTART+2)=-888.8
        SWEEPZ(I,JSTART+3)=-32.
        SWEEP(I,JSTART+3)=-888.8
c        write(6,*)'removed 3'
       ENDIF
       DO J=JSTART+1,JSTART+3
c        IF(SWEEPZ(I,J)-SWEEPZ(I,J+1).GT.10.)THEN
        IF(SWEEPZ(I,J).GT.-32..AND.SWEEPZ(I,J+1).GT.-32.AND.
     +      SWEEPZ(I,J)-SWEEPZ(I,J+1).GT.3.)THEN
         DO JJ=J,JSTART,-1
          SWEEPZ(I,JJ)=-32.
          SWEEP(I,JJ)=-888.8
         ENDDO
        ENDIF
       ENDDO
c       IF(IDBZTEST.GT.0)WRITE(6,*)'AFTERLEFT,JSTART,SWEEPZ = ',
c     +            JSTART,(SWEEPZ(I,J),J=JSTART,JSTART+9)
c       IF(IDBZTEST.GT.0)WRITE(6,*)'ZR AFTERLEFT,JSTART,SWEEPZ = ',
c     +            JSTART,(ZRSWEEP(I,J),J=JSTART,JSTART+9)
c       IF(IDBZTEST.GT.0)WRITE(6,*)'RADIUS = ',RD(I)
c       IF(SWEEPZ(I,JSTART+4).GT.20.)THEN
c        WRITE(6,*)'SWEEPZ(I,JSTART+9) = ',SWEEPZ(I,JSTART+9)
c        WRITE(6,*)'ZRSWEEP(I,JSTART+9) = ',ZRSWEEP(I,JSTART+9)
c        WRITE(6,*)'RADIUS = ',RD(I)
c        PAUSE
c       ENDIF
      ENDIF
c      WRITE(6,*)'GROUNDCHECK RETURNING'
c      IF(ICHECK.EQ.1.AND.JSTART.GE.5)THEN
c       JSTARTCHECK1=0
c       DO J=JSTART,JSTART-4
c        IF(SWEEPZ(I,J).GT.48.)JSTARTCHECK1=1
c       ENDDO
c       IF(JSTARTCHECK1.EQ.1)THEN
c         J=JSTART
c         WRITE(6,6296)J,(SWEEPZ(I,J),J=JSTART,JSTART-4,-1)
c         PAUSE
c       ENDIF
c      ELSEIF(ICHECK.EQ.2.AND.JSTART+4.LE.NUM_RAYS)THEN
c       JSTARTCHECK2=0
c       DO J=JSTART,JSTART+4
c        IF(SWEEPZ(I,J).GT.48.)JSTARTCHECK2=1
c       ENDDO
c       IF(JSTARTCHECK2.EQ.1)THEN
c         J=JSTART
c         WRITE(6,6296)J,(SWEEPZ(I,J),J=JSTART,JSTART+4)
c         PAUSE
c       ENDIF
c      ENDIF
      RETURN
      END
C ********************
      SUBROUTINE READTAPE(TIME,RLAT,RLON,RA,AZM,EV,BIN,REF,BIN1,REF1,
     +                    RCAZM,ITAPEOPEN,RADARFILE,NUMREC,
     +                    PCORS,DCORS,RCORS,AZMCORS,
     +                    RDELCORTAS,ELCORS,ISIGMET,NDO)
      INCLUDE "hrd_radar_common_blocks_johns.f"
c      common/rvp8_files/sweep_open,current_fptr,current_fn
      COMMON /AREA1/ INM,IFLT,STIME,ETIME,WD,WS,NIX,NGATE1,LP,LUNR,
     +               IVT,RAMFL
      COMMON /PARAMS/ trakazm,trakelev,driftnew,
     +                rot,track,htbb,dbb,thresh,swthresh,dbzrs,ibst(2),
     +                inob(2),ileg,xniq,irsw,maxnbins,v0,
     +                pcor,dcor,rcor,azmcor,elcor,dbzcor,dbzslope,
     +                iunfoldflag,iattenflag,
     +                badstabflag,surfelimflag,echoflag,atmflag
      LOGICAL badstabflag, surfelimflag, echoflag, atmflag
c      logical*8 sweep_open
c      character*132 current_fn
c      integer*8 current_fptr
      
      INTEGER RTYPE
      REAL PCORS(2),DCORS(2),RCORS(2),AZMCORS(2)
      REAL RDELCORTAS(2),ELCORS(2)
      CHARACTER IFLT*8, INM*12
      CHARACTER *1 RAMFL, IVT
      CHARACTER*80 RADARFILE
      DIMENSION BIN(MAX_HRD_DIM),REF(MAX_HRD_DIM)
      DIMENSION BIN1(MAX_HRD_DIM),REF1(MAX_HRD_DIM)
      DATA RTYPE/6/
C Subroutine to read doppler and Reflectivity data from the new 1988
C format radar tapes.  Reads refl/doppler when rtype=6 and dop/ref/sw when
C rtype=7.  It returns one ray per call.
C NIX = -100 determines an end-of-file
C Read data from tape:
      NIX=0
      IHEADERFLAG=1
c      WRITE(6,*)'ITAPEOPEN,ISIGMET = ',ITAPEOPEN,ISIGMET
c      WRITE(6,*)'ENTERED READTAPE'
      DO I=1,MAX_HRD_DIM
       BIN(I)=-888.8
       REF(I)=-32.
       BIN1(I)=-888.8
       REF1(I)=-32.
      ENDDO
      IF (SWTHRESH.GT.0.0 .AND. SWTHRESH.LE.13.0) RTYPE=7
      RTYPE=7
c50    write(6,*)'calling radartaperead1'
c      write(6,*)'itapeopen,numrec = ',itapeopen,numrec
c      write(6,'(A80)')radarfile
50    IF(ITAPEOPEN.EQ.0.AND.ISIGMET.EQ.5)THEN
c       write(6,*)'calling radardiscread,iheaderflag = ',iheaderflag
c       pause
c       write(6,*)'time is ',time
       LUNRNC=LUNR
       CALL RADARDISCREAD1(LUNRNC,2,IHEADERFLAG,RTYPE,IERR)
       LUNR=LUNRNC
c       write(6,*)'returned from radardiscread'
c       write(6,*)'time after rvp8 is ',time
c       write(6,*)'nbins,nbinsta = ',nbins,nbinsta
c       WRITE(6,*)'CALLED RADAR_RVP8_READ AND IERR = ',IERR
      ELSEIF(ITAPEOPEN.EQ.0)THEN
 6664   LUNRNC=LUNR
c        WRITE(6,*)'CALLING RADAR_RVP8_READ'
        call radar_rvp8_read(LUNRNC,2,0,RTYPE,IERR)
        IF(NDO.NE.0)RETURN
c        WRITE(6,*)'RETURNED FROM RADAR_RVP8_READ'
        LUNR=LUNRNC
C       CALL RADARFILEREAD(LUNR,2,0,RTYPE,IERR,ITAPEOPEN,RADARFILE,
C     + NUMREC)
       IF(NBINS.LT.1.OR.NBINS.GT.MAX_HRD_DIM)GO TO 6664
      ELSE
       LUNRNC=LUNR
       CALL RADARTAPEREAD(LUNRNC,2,0,RTYPE,IERR)
       LUNR=LUNRNC
c       write(6,*)'should not get here 2'
c       stop
       IF(IERR.NE.0)THEN
        write(6,*)'returned from radartaperead ierr = ',ierr
       ENDIF
      ENDIF
c      IF(NBINS.LT.MAX_HRD_DIM)THEN
c       DO I=NBINS+1,MAX_HRD_DIM
c        RADIITA(I)=0.
c       ENDDO
c      ENDIF
      IF (IERR .LT. 0.AND.ISIGMET.EQ.5) THEN
         IF(IERR.EQ.-4)THEN
          NIX=-200
         ELSE
          NIX= -100
         ENDIF
         RETURN
      ELSE
       NIX=0
      ENDIF
      IF(ELEV.LT.0.)THEN
       PCOR=PCORS(1)
       DCOR=DCORS(1)
       RCOR=RCORS(1)
       AZMCOR=AZMCORS(1)
       ELCOR=ELCORS(1)
      ELSE
       PCOR=PCORS(2)
       DCOR=DCORS(2)
       RCOR=RCORS(2)
       AZMCOR=AZMCORS(2)
       ELCOR=ELCORS(2)
      ENDIF
C    clear nix variable
      NIX= 0
C    time in seconds  
      TIME=RADTIME
C    raw azimuth
      TRAKAZM=RADAZM
c    roll corrected azimuth but in heading rather than track
      RCAZM=RADAZM+RCOR+ROLL
C    raw elevation
      TRAKELEV=ELEV
C    raw drift
      DRIFTNEW=DRIFT
C    nyquist velocity
      XNIQ=XNIQTA
      track = AMOD(heading + driftnew + 360.0, 360.0)
C ANGLECOR corrects the aircraft pitch,drift,roll,azimuth,elevation and
C adds the roll to the azimuth.
c      write(6,*)'roll,rcor,radazm,rcazm = ',roll,rcor,radazm,rcazm
c      write(6,*)'driftnew,trakazm,trakelev = ',
c     1           driftnew,trakazm,trakelev
      TRAKAZMTEMP=TRAKAZM
      TRAKELEVTEMP=TRAKELEV
      PITCHTEMP=PITCH
      ROLLTEMP=ROLL
      PCORTEMP=PCOR
      DCORTEMP=DCOR
      RCORTEMP=RCOR
      AZMCORTEMP=AZMCOR
      ELCORTEMP=ELCOR
      DRIFTNEWTEMP=DRIFTNEW
      CALL ANGLECOR(PITCHTEMP,DRIFTNEWTEMP,ROLLTEMP,TRAKAZMTEMP,
     +              TRAKELEVTEMP,2,PCORTEMP,
     +              DCORTEMP,RCORTEMP,AZMCORTEMP,ELCORTEMP)
      PCOR=PCORTEMP
      TRAKAZM=TRAKAZMTEMP
      TRAKELEV=TRAKELEVTEMP
      PITCH=PITCHTEMP
      ROLL=ROLLTEMP
      DCOR=DCORTEMP
      RCOR=RCORTEMP
      AZMCOR=AZMCORTEMP
      ELCOR=ELCORTEMP
      DRIFTNEW=DRIFTNEWTEMP
c      write(6,*)'after roll,trakazm,track = ',roll,trakazm,track
C Convert aircraft angles to earth relative shperical coordinates
      IUNFOLDFLAG=0
      CALL RAYCOR1(BIN1,REF1)
      IUNFOLDFLAG=0
      CALL RAYCOR1(BIN,REF)
      IUNFOLDFLAG=0
      TRAKAZMTEMP=TRAKAZM
      TRAKELEVTEMP=TRAKELEV
      TRACKTEMP=TRACK
       CALL CONVERTANGLES(TRACKTEMP,TRAKAZMTEMP,TRAKELEVTEMP,
     1                    HORAZM,HORELEV)
      TRAKAZM=TRAKAZMTEMP
      TRAKELEV=TRAKELEVTEMP
      TRACK=TRACKTEMP
C       WRITE(6,*)'TRAKAZM,TRAKELEV = ',TRAKAZM,TRAKELEV
c      write(6,*)'after convertangles = ',trakazm,horazm
C    azimuth earth relative
      AZM=HORAZM
C    elevation earth relative
      EV=HORELEV
C get information from the ram files.
c      IF (RAMFL .EQ. 'Y')
c     *   CALL READRAMFILE(TIME,TIMERAM,RADLAT,RADLON,RADALT,
c     *                    RADWD,RADWS,UCOM,VCOM,RADVWS,RADVGS,IOS)
C get information from the radar tape or the standard tape
      GS=RADGS                       !ground speed
      VGS=RADVGS                     !vertical ground speed
      VWS=RADVWS                     !vertical wind speed
      RLAT=RADLAT                    !latitude(deg)
      RLON=RADLON                    !longitude(deg)
      RA=RADALT                      !radar altitude(meters) 
      WD=RADWD                       !wind direction
      WS=RADWS                       !wind speed
C RAYCOR corrects the velocities one ray at a time.  It returns the airplane
C track, the first guess wind, the stabilized, vt corrected and unfolded
c velocities as well as the dbz values from the tail radar.
c      IUNFOLDFLAG=0
c      CALL RAYCOR1(BIN1,REF1)
c      IUNFOLDFLAG=0
c      CALL RAYCOR1(BIN,REF)
c      IUNFOLDFLAG=0
      RETURN
      END 
C ********************
      BLOCK DATA
      INCLUDE "hrd_radar_settings.f"
      COMMON /AREA1/ INM,IFLT,STIME,ETIME,WD,WS,NIX,NGATE1,LP,LUNR,
     +               IVT,RAMFL
      COMMON /PARAMS/ trakazm,trakelev,driftnew,
     +                rot,track,htbb,dbb,thresh,swthresh,dbzrs,ibst(2),
     +                inob(2),ileg,xniq,irsw,maxnbins,v0,
     +                pcor,dcor,rcor,azmcor,elcor,dbzcor,dbzslope,
     +                iunfoldflag,iattenflag,
     +                badstabflag,surfelimflag,echoflag,atmflag
      LOGICAL badstabflag, surfelimflag, echoflag, atmflag
      CHARACTER IFLT*8, INM*12
      CHARACTER *1 RAMFL, IVT
      DATA NIX/0/, NGATE1/5/, IVT/'N'/, RAMFL/'N'/ 
      DATA rot/0.0/, htbb/-99./, dbb/2.0/, thresh/-99.0/, swthresh/99./,
     1     dbzrs/-99./, ibst/2*0/, inob/2*0/, ileg/1/, xniq/12.8/,
     2     irsw/0/, maxnbins/MAX_HRD_DIM/, 
     3     pcor,dcor,rcor,azmcor,elcor,dbzcor/6*0.0/, dbzslope/1.0/,
     4     iunfoldflag/0/, iattenflag/0/,
     5     badstabflag/.true./, surfelimflag/.false./,
     6     echoflag/.false./, atmflag/.true./
      END 
      SUBROUTINE VRLOCATER(TIMES,OLAT,OLON,
     + RLAT,RLON,ALT,ELEV,AZIM,RANGE,XR,YR,ZR,
     + ISCANDIM,SMOTIONU,SMOTIONV,CENTIME)
      include "hrd_radar_settings.f"
      REAL RANGE(ISCANDIM),XR(ISCANDIM),YR(ISCANDIM),ZR(ISCANDIM)
      REAL SUM(MAX_HRD_DIM),WSUM(MAX_HRD_DIM),WEIGHT(200)
      REAL VR(MAX_HRD_DIM)
      RALT=ALT/1000.
      PI=ASIN(1.0)*2.
      DTR=PI/180.
      REARTH=6366.
C      SMOTIONU=0.
C      SMOTIONV=0.
      TDIFF=TIMES-CENTIME
c      write(6,*)'olat,rlat,times,centime,tdiff,smotionu,smotionv = ',
c     + olat,rlat,times,centime,tdiff,smotionu,smotionv
C      TDIFF=0.
C      JBINS=IBINS*3
c      DO I=1,ISCANDIM
c       SUM(I)=0
c       WSUM(I)=0
c       ISTART=I-JBINS
c       IEND=I+JBINS
c       IF(ISTART.LT.1)ISTART=1
c       IF(IEND.GT.ISCANDIM)IEND=ISCANDIM
c       DO J=ISTART,IEND
c        IF(VR(J).GT.-900.)THEN
c         IDIFF=J-I
c         IDIFF=IABS(IDIFF)
c         WSUM(I)=WSUM(I)+WEIGHT(IDIFF)
c         SUM(I)=SUM(I)+WEIGHT(IDIFF)*VR(J)
c        ENDIF
c       ENDDO
c      ENDDO
c      DO I=1,ISCANDIM
c       IF(WSUM(I).LE.0..AND.VR(I).LE.-900.)THEN
c        VR(I)=-999.9
c       ELSE
c        VR(I)=SUM(I)/WSUM(I)
c       ENDIF
c      ENDDO
      XSHIFT=TDIFF*SMOTIONU/1000.
      YSHIFT=TDIFF*SMOTIONV/1000.     
c      write(6,*)'xshift,yshift = ',xshift,yshift
      RAZIM=AZIM*DTR
      RELEV=ELEV*DTR
      DO I=1,ISCANDIM
c xradar=horizontal distance from aircraft
c yradar=vertical distance from center of earth
       IF(RANGE(I).LT.200.)THEN
        XRADAR=RANGE(I)*COS(RELEV)
        YRADAR=REARTH+RALT+RANGE(I)*SIN(RELEV)
c radnew=distance of datum from center of earth
        RADNEW=SQRT(XRADAR*XRADAR+YRADAR*YRADAR)
c delangle=angle between vertical at aircraft and vertical at datum
        DELANGLE=ATAN(XRADAR/YRADAR)
c distance along great circle from radar to datum
        DISTANCE=.5*(RADNEW+REARTH+RALT)*DELANGLE
c height=altitude of datum
        HEIGHT=RADNEW-REARTH
c distance2=xradar
        DISTANCE2=RANGE(I)*COS(RELEV)
c height2=altitude of datum not accounting for earth's curvature
        HEIGHT2=RALT+RANGE(I)*SIN(RELEV)
c delx=distance (aircraft/datum) along great circle due to east west
        DELY=DISTANCE*SIN(RAZIM)
c dely=distance(aircraft/datum)along great circle due to north-south
        DELX=DISTANCE*COS(RAZIM)
c dx=east west distance from origin to aircraft
        XLAT=.5*(RLAT+OLAT)*DTR
        DX=(RLON-OLON)*DTR*REARTH*COS(XLAT)
c dy=north south distance from origin to aircraft
        DY=(RLAT-OLAT)*DTR*REARTH
c xshift=east-west distance from lower left corner to origin
c yshift=north-south distance from lower left corner to origin
c XR=distance of datum from lower left corner
c YR=distance of datum from lower left corner
        XR(I)=DELX+DX-XSHIFT
c yshift=distance from lower left corner to origin
        YR(I)=DELY+DY-YSHIFT
        ZR(I)=HEIGHT
       ELSE
        XR(I)=-1000.
        YR(I)=-1000.
        ZR(I)=-1000.
       ENDIF
c       WRITE(6,*)'I,RANGE,DISTANCE,HEIGHT,DELX,DELY,DX,DY,XSHIFT,'
c     +  'YSHIFT = ',
c     +  I,RANGE(I),DISTANCE,HEIGHT,DELX,DELY,DX,DY,XSHIFT,YSHIFT
      ENDDO
      CONTINUE
      RETURN
      END
	subroutine find_ground_old(rdtai,deg2rad, beam_wid, 
     +		rs_th, rs_m, dBz_max, ibeg, Ng2, ibst,bin,dv0,driftcor)
C Find the surface, as in Testud's memo.
        include "hrd_radar_common_blocks.f"
	real lambda
        real rdtai(MAX_HRD_DIM),bin(max_hrd_dim)
C
c        write(6,*)'ra = ',ra
	theta = elev * deg2rad ! tilt relative to plane perp to radar axis
	beta = pitch * deg2rad
C In Testud's form, 0 is down, -90 port, 90 starboard:
c	phi = (180 - (azm + roll) ) * deg2rad 
        phi = (azm + roll -180) * deg2rad
	epsilon = beam_wid * deg2rad
C Now get elevation of beam rel to horizontal plane through radar
	sn_lambda = sin(theta) * sin(beta) - 
     *			cos(theta) * cos(beta) * cos(phi)
	lambda = asin(sn_lambda)
C Find theoretical range of surface. - sign because lambda neg
	rs_th = -ra / sn_lambda ! ra in m, radiita in km
C Find # of gates intersecting surface at theoretical range
C This would be formula if dR was constant:
C	Ng = rs_th * epsilon / (dR * tan(lambda) )
C But we may have varying beamwidths, so
Cout	slant_depth = -rs_th * epsilon / tan(lambda) ! slight approximation
Cout	rs_th_in = ( rs_th - slant_depth * 0.5 ) * 0.001
Cout	rs_th_out = ( rs_th + slant_depth * 0.5 ) * 0.001
C mod dec 8 92:
	rs_th_in = -ra / sin(lambda - epsilon * 0.75) * 0.001
	rs_th_out = -ra / sin(lambda + epsilon * 0.75) * 0.001
	rs_km = rs_th * 0.001
c        write(6,*)'rs_th_in,rs_km,rs_th_out = ',
c     +             rs_th_in,rs_km,rs_th_out
c	in = nbins-100
c        iout = nbins
        Nr = nbins-50
        in=-1
        iout=-1
	do i = 1, nbins
	    if( radiita(i) .gt. 0.0 )then
		if(radiita(i) .lt. rs_th_in) in = i
		if(radiita(i) .le. rs_th_out) iout = i
		if(radiita(i) .le. rs_km) Nr = i
	    end if
	end do
	if(in .eq. -1.or.iout.eq.-1)then
c		WRITE(6,*)' find_ground failure!'
c		WRITE(6,*)' ra:',ra
c		WRITE(6,*)'azm, phi: ', azm, phi
c		WRITE(6,*)'pitch, drift, roll: ',pitch, drift, roll
c		WRITE(6,*)'el, sin(lambda), lambda:',elev, 
c     +			sn_lambda, lambda
c		WRITE(6,*)'rs_th_in, rs_th_out, rs_km:'
c		WRITE(6,*)rs_th_in, rs_th_out, rs_km
c		WRITE(6,*)' find_gs in, iout, Nr: ',in, iout, Nr
c		pause ' pausing for this mystery '
		ibeg = 0
		return
	end if
	Ng = iout - in + 1
        Ng = iout - Nr +1
        Ng2 = Ng
c	Ng2 =  0.5 * Ng
	if (Ng2 .eq. 0) Ng2 = 1
c        write(6,*)'in,iout,ng,ng2,nr = ',in,iout,ng,ng2,nr
C changed radius of check to 30 bins = 2.25 km, because of huge
C range delays in Andrew 8 dec 92
C Then search the gates within +- 30 of gate at theoretical
C range to find the swath Ng/2 wide with greatest Total Ze.
C Return bounding bins.
	dBz_max = -1.0
        vel_max = 0.
	ibeg = -1
        if(ng2.gt.30)then
         n30=ng2
        else
         n30=30
        endif
c        n30=ng2
c        write(6,*)'in,nbins,ng2,n30,nr = ',in,nbins,ng2,n30,nr
	ist = max(in, Nr - n30)
        i11=nbins-Ng2
        i22=Nr + n30 -Ng2
	ien = min(nbins-Ng2, Nr + n30 -Ng2)
c	WRITE(6,*)'find_gd i11,i22,ist, ien: ',i11,i22,ist, ien
        if(ist.lt.in-30)ist=in-30
        if(ist.lt.1)ist=1
c        ien = min(iout,ien)
c	WRITE(6,*)'find_gd ist, ien: ',ist, ien
	do i = ist, ien
	   dBzsum = 0.0
           velsum = 0.0
           ndbzsum = 0
           nvelsum =0
	   do j = i, i + Ng2
               if(j.gt.ibst.and.dbzbuffer(j).gt.-32.)then
		dBzsum = dBzsum + dbzbuffer(j)
                if(bin(j).gt.-800.)then
                 nvelsum=nvelsum+1
                 velsum=velsum+bin(j)
                endif
c                write(6,*)'bin ',bin(j)
                ndbzsum=ndbzsum+1
               endif
c                dbzsum = dbzbuffer(i+Ng2)-dbzbuffer(i)
	   end do
           if(ndbzsum.gt.0)then
            dbzsum=dbzsum/ndbzsum
           else
            dbzsum=-32.
           endif
           if(nvelsum.gt.0)then
            velsum=velsum/nvelsum
           else
            velsum=-888.88
           endif
	   if( dBzsum .gt. dBz_max.and.dbzbuffer(i).lt.80)then
		dBz_max = dBzsum
		ibeg = i
                if(nvelsum.gt.0)then
                 vel_max = velsum
                else
                 vel_max = -888.88
                endif
	   end if
	end do
        if(bin(Nr).gt.-800..and.abs(dv0).gt..5)then
         driftcor=-bin(Nr)/dv0
c        write(6,*)'bin(Nr),dv0,driftcor = =',bin(Nr),dv0,driftcor
c         write(6,*)'azm,lambda,vel,dv0,driftcor = ',
c     1             (phi/deg2rad)+180.,lambda*180./3.14159,bin(Nr),dv0,
c     1             driftcor
        else
         driftcor=-888.88
        endif
	iradius = ibeg + Ng2 * 0.5
	if( iradius .le.0) iradius = 1
        if( iradius .gt.nbins) iradius = nbins
	rs_m = radiita( iradius ) * 1000.0
        if(ibeg.lt.1)ibeg=1
	return
	end
      SUBROUTINE AZISORT(NUM_RAYS,AZI,X)
      REAL AZI(2,NUM_RAYS),X(NUM_RAYS),XSORT(800)
      AZITEST=361.
      JSTART=1
      IF(NUM_RAYS.GT.2)THEN
       AZICHECK=AZI(1,3)-AZI(1,2)
       IF(AZICHECK.LT.-180.)AZICHECK=AZICHECK+360.
       IF(AZICHECK.GT.180.)AZICHECK=AZICHECK-360.
      ELSE
       RETURN
      ENDIF
      DO J=1,NUM_RAYS
       IF(J.EQ.NUM_RAYS)THEN
        JLOW=NUM_RAYS
        JHIGH=1
       ELSE
        JLOW=J
        JHIGH=J+1
       ENDIF
       AZICHECK2=AZI(1,JHIGH)-AZI(1,JLOW)
       IF(ABS(AZICHECK2).GT.180.)THEN
        JSTART=J
        AZITEST=AZI(1,J)
       ENDIF
      ENDDO
      IF(JSTART.EQ.NUM_RAYS)THEN
       JSTART=1
      ELSE
       JSTART=JSTART+1
      ENDIF
      JEND=JSTART+NUM_RAYS-1
      DO JJ=JSTART,JEND
       J=JJ-JSTART+1
       IF(JJ.GT.NUM_RAYS)THEN
        I=JJ-NUM_RAYS
       ELSE
        I=JJ
       ENDIF
c       WRITE(6,*)'JJ,J,I,AZI = ',JJ,J,I,AZI(1,I)
       XSORT(J)=X(I)
      ENDDO
      DO J=1,NUM_RAYS
       I=NUM_RAYS-J+1
       IF(AZICHECK.LT.0.)THEN
        X(J)=XSORT(I)
       ELSE
        X(J)=XSORT(J)
       ENDIF
      ENDDO
      RETURN
      END
      SUBROUTINE AZISORT2(NUMI,NUM_RAYS,AZI,X)
      include "hrd_radar_settings.f"
      REAL AZI(2,NUM_RAYS),X(NUMI,NUM_RAYS),XSORT(MAX_HRD_DIM,800)
      JSTART=1
      AZITEST=361.
      IF(NUM_RAYS.GT.2)THEN
       AZICHECK=AZI(1,3)-AZI(1,2)
       IF(AZICHECK.LT.-180.)AZICHECK=AZICHECK+360.
       IF(AZICHECK.GT.180.)AZICHECK=AZICHECK-360.
      ELSE
       RETURN
      ENDIF
      DO J=1,NUM_RAYS
       IF(J.EQ.NUM_RAYS)THEN
        JLOW=NUM_RAYS
        JHIGH=1
       ELSE
        JLOW=J
        JHIGH=J+1
       ENDIF
       AZICHECK2=AZI(1,JHIGH)-AZI(1,JLOW)
       IF(ABS(AZICHECK2).GT.180.)THEN
        JSTART=J
        AZITEST=AZI(1,J)
       ENDIF
      ENDDO
      IF(JSTART.EQ.NUM_RAYS)THEN
       JSTART=1
      ELSE
       JSTART=JSTART+1
      ENDIF
      JEND=JSTART+NUM_RAYS-1
      DO JJ=JSTART,JEND
       J=JJ-JSTART+1
       IF(JJ.GT.NUM_RAYS)THEN
        K=JJ-NUM_RAYS
       ELSE
        K=JJ
       ENDIF
c       WRITE(6,*)'JJ,I,J,K,AZI = ',JJ,I,J,K,AZI(1,K)
       DO I=1,NUMI
        XSORT(I,J)=X(I,K)
       ENDDO
      ENDDO
      DO J=1,NUM_RAYS
       K=NUM_RAYS-J+1
       DO I=1,NUMI
        IF(AZICHECK.LT.0.)THEN
         X(I,J)=XSORT(I,K)
        ELSE
         X(I,J)=XSORT(I,J)
        ENDIF
       ENDDO       
      ENDDO
      RETURN
      END
      SUBROUTINE AZISORT2A(NUMI,NUM_RAYS,AZI,X)
      include "hrd_radar_settings.f"
      REAL AZI(2,NUM_RAYS),X(NUMI,NUM_RAYS),XSORT(MAX_HRD_DIM,800)
      JSTART=1
      AZITEST=361.
      IF(NUM_RAYS.GT.2)THEN
       AZICHECK=AZI(1,3)-AZI(1,2)
       IF(AZICHECK.LT.-180.)AZICHECK=AZICHECK+360.
       IF(AZICHECK.GT.180.)AZICHECK=AZICHECK-360.
      ELSE
       RETURN
      ENDIF
      DO J=1,NUM_RAYS
       IF(J.EQ.NUM_RAYS)THEN
        JLOW=NUM_RAYS
        JHIGH=1
       ELSE
        JLOW=J
        JHIGH=J+1
       ENDIF
       AZICHECK2=AZI(1,JHIGH)-AZI(1,JLOW)
       IF(ABS(AZICHECK2).GT.180.)THEN
        JSTART=J
        AZITEST=AZI(1,J)
       ENDIF
      ENDDO
      IF(JSTART.EQ.NUM_RAYS)THEN
       JSTART=1
      ELSE
       JSTART=JSTART+1
      ENDIF
      JEND=JSTART+NUM_RAYS-1
      DO JJ=JSTART,JEND
       J=JJ-JSTART+1
       IF(JJ.GT.NUM_RAYS)THEN
        K=JJ-NUM_RAYS
       ELSE
        K=JJ
       ENDIF
       WRITE(6,*)'JJ,I,J,K,AZI = ',JJ,I,J,K,AZI(1,K)
       DO I=1,NUMI
        XSORT(I,J)=X(I,K)
       ENDDO
      ENDDO
      DO J=1,NUM_RAYS
       K=NUM_RAYS-J+1
       DO I=1,NUMI
        IF(AZICHECK.LT.0.)THEN
         X(I,J)=XSORT(I,K)
        ELSE
         X(I,J)=XSORT(I,J)
        ENDIF
       ENDDO       
      ENDDO
      RETURN
      END
      SUBROUTINE IAZISORT(NUM_RAYS,AZI,X)
      REAL AZI(2,NUM_RAYS)
      INTEGER X(NUM_RAYS),XSORT(800)
      JSTART=1
      AZITEST=361.
      IF(NUM_RAYS.GT.2)THEN
       AZICHECK=AZI(1,3)-AZI(1,2)
       IF(AZICHECK.LT.-180.)AZICHECK=AZICHECK+360.
       IF(AZICHECK.GT.180.)AZICHECK=AZICHECK-360.
      ELSE
       RETURN
      ENDIF
      DO J=1,NUM_RAYS
       IF(J.EQ.NUM_RAYS)THEN
        JLOW=NUM_RAYS
        JHIGH=1
       ELSE
        JLOW=J
        JHIGH=J+1
       ENDIF
       AZICHECK2=AZI(1,JHIGH)-AZI(1,JLOW)
       IF(ABS(AZICHECK2).GT.180.)THEN
        JSTART=J
        AZITEST=AZI(1,J)
       ENDIF
      ENDDO
      IF(JSTART.EQ.NUM_RAYS)THEN
       JSTART=1
      ELSE
       JSTART=JSTART+1
      ENDIF
      JEND=JSTART+NUM_RAYS-1
      DO JJ=JSTART,JEND
       J=JJ-JSTART+1
       IF(JJ.GT.NUM_RAYS)THEN
        I=JJ-NUM_RAYS
       ELSE
        I=JJ
       ENDIF
c       WRITE(6,*)'JJ,J,I,AZI = ',JJ,J,I,AZI(1,I)
       XSORT(J)=X(I)
      ENDDO
      DO J=1,NUM_RAYS
       I=NUM_RAYS-J+1
       IF(AZICHECK.LT.0.)THEN
        X(J)=XSORT(I)
       ELSE
        X(J)=XSORT(J)
       ENDIF
      ENDDO
      RETURN
      END
      SUBROUTINE IAZISORT2(NUMI,NUM_RAYS,AZI,X)
      include "hrd_radar_settings.f"
      REAL AZI(2,NUM_RAYS)
      INTEGER X(NUMI,NUM_RAYS),XSORT(MAX_HRD_DIM,800)
      AZITEST=361.
      JSTART=1
      IF(NUM_RAYS.GT.2)THEN
       AZICHECK=AZI(1,3)-AZI(1,2)
       IF(AZICHECK.LT.-180.)AZICHECK=AZICHECK+360.
       IF(AZICHECK.GT.180.)AZICHECK=AZICHECK-360.
      ELSE
       RETURN
      ENDIF
      DO J=1,NUM_RAYS
       IF(J.EQ.NUM_RAYS)THEN
        JLOW=NUM_RAYS
        JHIGH=1
       ELSE
        JLOW=J
        JHIGH=J+1
       ENDIF
       AZICHECK2=AZI(1,JHIGH)-AZI(1,JLOW)
       IF(ABS(AZICHECK2).GT.180.)THEN
        JSTART=J
        AZITEST=AZI(1,J)
       ENDIF
      ENDDO
      IF(JSTART.EQ.NUM_RAYS)THEN
       JSTART=1
      ELSE
       JSTART=JSTART+1
      ENDIF
      JEND=JSTART+NUM_RAYS-1
      DO JJ=JSTART,JEND
       J=JJ-JSTART+1
       IF(JJ.GT.NUM_RAYS)THEN
        K=JJ-NUM_RAYS
       ELSE
        K=JJ
       ENDIF
c       WRITE(6,*)'JJ,I,J,K,AZI = ',JJ,I,J,K,AZI(1,K)
       DO I=1,NUMI
        XSORT(I,J)=X(I,K)
       ENDDO
      ENDDO
      DO J=1,NUM_RAYS
       K=NUM_RAYS-J+1
       DO I=1,NUMI
        IF(AZICHECK.LT.0.)THEN
         X(I,J)=XSORT(I,K)
        ELSE
         X(I,J)=XSORT(I,J)
        ENDIF
       ENDDO       
      ENDDO
      RETURN
      END
	subroutine find_groundA(rdtai,deg2rad, beam_wid, 
     +		rs_th, rs_m, dBz_max, ibeg, Ng2, ibst,bin,isecondtrip,
     +  rmaxtata,rasend)
C Find the surface, as in Testud's memo.
        include "hrd_radar_common_blocks.f"
	real lambda
        real rdtai(MAX_HRD_DIM),bin(max_hrd_dim)
C
c        write(6,*)'ra = ',ra
        ra=rasend
        radres=rdtai(101)-rdtai(100)
	theta = elev * deg2rad ! tilt relative to plane perp to radar axis
	beta = pitch * deg2rad
C In Testud's form, 0 is down, -90 port, 90 starboard:
c	phi = (180 - (azm + roll) ) * deg2rad 
        phi = (azm + roll -180) * deg2rad
	epsilon = beam_wid * deg2rad
C Now get elevation of beam rel to horizontal plane through radar
	sn_lambda = sin(theta) * sin(beta) - 
     *			cos(theta) * cos(beta) * cos(phi)
	lambda = asin(sn_lambda)
C Find theoretical range of surface. - sign because lambda neg
	rs_th = -ra / sn_lambda ! ra in m, radiita in km
C Find # of gates intersecting surface at theoretical range
C This would be formula if dR was constant:
C	Ng = rs_th * epsilon / (dR * tan(lambda) )
C But we may have varying beamwidths, so
Cout	slant_depth = -rs_th * epsilon / tan(lambda) ! slight approximation
Cout	rs_th_in = ( rs_th - slant_depth * 0.5 ) * 0.001
Cout	rs_th_out = ( rs_th + slant_depth * 0.5 ) * 0.001
C mod dec 8 92:
	rs_th_in = -ra / sin(lambda - epsilon * 0.75) * 0.001
	rs_th_out = -ra / sin(lambda + epsilon * 0.75) * 0.001
	rs_km = rs_th * 0.001
        if((rs_km.gt.rmaxtata.or.rs_th_out.le.0.)
     + .and.isecondtrip.eq.1)then
           ibeg=-2
           return
        elseif(rs_th_in.gt.rmaxtata)then
           ibeg=0
c           write(6,*)'returning with ibeg = 0'
           return
        endif
c        write(6,*)'rs_th_in,rs_km,rs_th_out = ',
c     +             rs_th_in,rs_km,rs_th_out
c	in = nbins-100
c        iout = nbins
        Nr = nbins-50
        in=-1
        iout=-1
	do i = 1, nbins
	    if( radiita(i) .gt. 0.0 )then
		if(radiita(i) .lt. rs_th_in) in = i
		if(radiita(i) .le. rs_th_out) iout = i
		if(radiita(i) .le. rs_km) Nr = i
	    end if
	end do
	if(in .eq. -1.or.iout.eq.-1)then
c		WRITE(6,*)' find_ground failure!'
c		WRITE(6,*)' ra:',ra
c		WRITE(6,*)'azm, phi: ', azm, phi
c		WRITE(6,*)'pitch, drift, roll: ',pitch, drift, roll
c		WRITE(6,*)'el, sin(lambda), lambda:',elev, 
c     +			sn_lambda, lambda
c		WRITE(6,*)'rs_th_in, rs_th_out, rs_km:'
c		WRITE(6,*)rs_th_in, rs_th_out, rs_km
c		WRITE(6,*)' find_gs in, iout, Nr: ',in, iout, Nr
c		pause ' pausing for this mystery '
		ibeg = 0
		return
	end if
	Ng = iout - in + 1
        Ng2 = Ng
	Ng2 =  0.5 * Ng
	if (Ng2 .eq. 0) Ng2 = 1
c        write(6,*)'in,iout,ng,ng2,nr = ',in,iout,ng,ng2,nr
C changed radius of check to 30 bins = 2.25 km, because of huge
C range delays in Andrew 8 dec 92
C Then search the gates within +- 30 of gate at theoretical
C range to find the swath Ng/2 wide with greatest Total Ze.
C Return bounding bins.
	dBz_max = -1.0
	ibeg = -1
        if(ng2.gt.30)then
         n30=ng2
        else
         n30=30
        endif
c        n30=ng2
c	ist = max(in, Nr - n30)
        ist = Nr - Ng2
	ien = min(nbins-Ng2, Nr + n30 -Ng2)
c        if(ist.gt.20)ist=ist-20
        if(ist.lt.1)ist=1
c        WRITE(6,*)'find_gd in,iout,Ng,Ng2,ibst = ',in,iout,Ng,Ng2,ibst
c	WRITE(6,*)'find_gd Nr, nbins,ist, ien: ',Nr,nbins,ist, ien
	do i = ist, ien
	   dBzsum = 0.0
           velsum = 0.0
           ndbzsum = 0
           nvelsum =0
	   do j = i, i + Ng2
c               write(6,*)'j,dbzbuffer(j) = ',j,dbzbuffer(j)
               if(j.gt.ibst.and.dbzbuffer(j).gt.-32.)then
		dBzsum = dBzsum + dbzbuffer(j)
                if(bin(j).gt.-800.)then
                 nvelsum=nvelsum+1
                 velsum=velsum+bin(j)
                endif
c                write(6,*)'bin ',bin(j)
                ndbzsum=ndbzsum+1
c                write(6,*)'j,dbzbuffer,ndbzsum,dBzsum = ',
c     1                     j,dbzbuffer(j),ndbzsum,dBzsum
               endif
c                dbzsum = dbzbuffer(i+Ng2)-dbzbuffer(i)
	   end do
           if(ndbzsum.gt.0)then
            dbzsum=dbzsum/ndbzsum
           else
            dbzsum=-32.
           endif
           if(nvelsum.gt.0)then
            velsum=velsum/nvelsum
           else
            velsum=-888.88
           endif
c           write(6,*)'i,dBzsum,dBz_max,dbzbuffer(i) = ',
c     1                i,dBzsum,dBz_max,dbzbuffer(i)
	   if( dBzsum .gt. dBz_max.and.dbzbuffer(i).lt.80)then
		dBz_max = dBzsum
		ibeg = i
c                write(6,*)'ibeg,dBz_max,dBzsum = ',
c     1                     ibeg,dBz_max,dBzsum
                if(nvelsum.gt.0)then
                 vel_max = velsum
                else
                 vel_max = -888.88
                endif
	   end if
	end do
c        write(6,*)'final computed ibeg = ',ibeg
        if(dbz_max.gt.0.)then
         extra=.1*40./dbz_max/abs(sn_lambda)
        else
         extra=0.
        endif
        ibeg=ibeg-int(extra/radres)
        if(ibeg.lt.1)ibeg=1
	iradius = ibeg + Ng2 * 0.5
	if( iradius .le.0) iradius = 1
        if( iradius .gt.nbins) iradius = nbins
	rs_m = radiita( iradius ) * 1000.0
        if(ibeg.lt.1)ibeg=1
	return
	end
      SUBROUTINE GROUNDCHECKI(REF,BIN,IBEG,NBINS,EVPASS,NUMMAX)
      REAL REF(NBINS),BIN(NBINS)
      NUMCHECK=-SIN(EVPASS*3.14159/180.)*NUMMAX
      IF(NUMCHECK.LT.4)NUMCHECK=4
      IF(REF(IBEG).LE.-32..AND.REF(IBEG-1).GT.-32..AND.
     +   REF(IBEG-2).LE.-32.)THEN
         REF(IBEG-1)=-32.
         BIN(IBEG-1)=-888.8
      ENDIF
      IF(REF(IBEG).LE.-32..AND.REF(IBEG-1).GT.-32..AND.
     +   REF(IBEG-3).LE.-32.)THEN
         REF(IBEG-1)=-32.
         BIN(IBEG-1)=-888.8
         REF(IBEG-2)=-32.
         BIN(IBEG-2)=-888.8
      ENDIF
      IF(REF(IBEG).LE.-32..AND.REF(IBEG-1).GT.-32..AND.
     +   REF(IBEG-4).LE.-32.)THEN
         REF(IBEG-1)=-32.
         BIN(IBEG-1)=-888.8
         REF(IBEG-2)=-32.
         BIN(IBEG-2)=-888.8
         REF(IBEG-3)=-32.
         BIN(IBEG-3)=-888.8
      ENDIF
      DO I=IBEG,IBEG-NUMCHECK,-1
c         IF(REF(I).GT.-32..AND.REF(I-1).GT.-32..AND.
         IF(REF(I).GT.-32..AND.
     +      REF(I)-REF(I-1).GT.3.)THEN
            DO II=I,IBEG
               REF(II)=-32.
               BIN(II)=-888.8
            ENDDO
         ENDIF
      ENDDO
      RETURN
      END
	subroutine find_ground(rdtai,deg2rad, beam_wid, 
     +		rs_th, rs_m, dBz_max, ibeg, Ng2, ibst,bin,isecondtrip,
     +          rmaxtata,rasend)
C Find the surface, as in Testud's memo.
        include "hrd_radar_common_blocks.f"
	real lambda
        real rdtai(MAX_HRD_DIM),bin(max_hrd_dim)
C
        ra=rasend
c        write(6,*)'ra = ',ra
        radres=rdtai(101)-rdtai(100)
	theta = elev * deg2rad ! tilt relative to plane perp to radar axis
	beta = pitch * deg2rad
C In Testud's form, 0 is down, -90 port, 90 starboard:
c	phi = (180 - (azm + roll) ) * deg2rad 
        phi = (azm + roll -180) * deg2rad
	epsilon = beam_wid * deg2rad
C Now get elevation of beam rel to horizontal plane through radar
	sn_lambda = sin(theta) * sin(beta) - 
     *			cos(theta) * cos(beta) * cos(phi)
	lambda = asin(sn_lambda)
C Find theoretical range of surface. - sign because lambda neg
	rs_th = -ra / sn_lambda ! ra in m, radiita in km
C Find # of gates intersecting surface at theoretical range
C This would be formula if dR was constant:
C	Ng = rs_th * epsilon / (dR * tan(lambda) )
C But we may have varying beamwidths, so
Cout	slant_depth = -rs_th * epsilon / tan(lambda) ! slight approximation
Cout	rs_th_in = ( rs_th - slant_depth * 0.5 ) * 0.001
Cout	rs_th_out = ( rs_th + slant_depth * 0.5 ) * 0.001
C mod dec 8 92:
	rs_th_in = -ra / sin(lambda - epsilon * 0.75) * 0.001
	rs_th_out = -ra / sin(lambda + epsilon * 0.75) * 0.001
	rs_km = rs_th * 0.001
c        write(6,*)'rs_th_out,rmaxtata,theta = ',
c     +    rs_th_out,rmaxtata,theta
        if((rs_km.gt.rmaxtata.or.rs_th_out.le.0.)
     + .and.isecondtrip.eq.1)then
           ibeg=-2
           return
        elseif(rs_th_in.gt.rmaxtata)then
           ibeg=0
c           write(6,*)'returning with ibeg = 0'
           return
        endif
c           do i=1,nbins
c              if(radiita(i).gt.0.0)then
c                 if(radiita(i).lt.rs_second)ibeg=i
c              endif
c           enddo
c           write(6,*)'i got here and'
c           write(6,*)'elev,azm,rs_th_out,rs_th_in,rs_second,ibeg = ',
c     +                elev,azm,rs_th_out,rs_th_in,rs_second,ibeg
c           return
c        endif
c        write(6,*)'rs_th_in,rs_km,rs_th_out = ',
c     +             rs_th_in,rs_km,rs_th_out
c	in = nbins-100
c        iout = nbins
        Nr = nbins-50
        in=-1
        iout=-1
	do i = 1, nbins
	    if( radiita(i) .gt. 0.0 )then
		if(radiita(i) .lt. rs_th_in) in = i
		if(radiita(i) .le. rs_th_out) iout = i
		if(radiita(i) .le. rs_km) Nr = i
	    end if
	end do
	if(in .eq. -1.or.iout.eq.-1)then
c		WRITE(6,*)' find_ground failure!'
c		WRITE(6,*)' ra:',ra
c		WRITE(6,*)'azm, phi: ', azm, phi
c		WRITE(6,*)'pitch, drift, roll: ',pitch, drift, roll
c		WRITE(6,*)'el, sin(lambda), lambda:',elev, 
c     +			sn_lambda, lambda
c		WRITE(6,*)'rs_th_in, rs_th_out, rs_km:'
c		WRITE(6,*)rs_th_in, rs_th_out, rs_km
c		WRITE(6,*)' find_gs in, iout, Nr: ',in, iout, Nr
c		pause ' pausing for this mystery '
		ibeg = 0
		return
	end if
	Ng = iout - in + 1
        Ng2 = Ng
	Ng2 =  0.5 * Ng
	if (Ng2 .eq. 0) Ng2 = 1
c        write(6,*)'in,iout,ng,ng2,nr = ',in,iout,ng,ng2,nr
C changed radius of check to 30 bins = 2.25 km, because of huge
C range delays in Andrew 8 dec 92
C Then search the gates within +- 30 of gate at theoretical
C range to find the swath Ng/2 wide with greatest Total Ze.
C Return bounding bins.
	dBz_max = -1.0
	ibeg = -1
        if(ng2.gt.30)then
         n30=ng2
        else
         n30=30
        endif
c        n30=ng2
c	ist = max(in, Nr - n30)
        ist = Nr - Ng2
	ien = min(nbins-Ng2, Nr + n30 -Ng2)
c        if(ist.gt.20)ist=ist-20
        if(ist.lt.1)ist=1
c        WRITE(6,*)'find_gd in,iout,Ng,Ng2,ibst = ',in,iout,Ng,Ng2,ibst
c	WRITE(6,*)'find_gd Nr, nbins,ist, ien: ',Nr,nbins,ist, ien
	do i = ist, ien
	   dBzsum = 0.0
           velsum = 0.0
           ndbzsum = 0
           nvelsum =0
	   do j = i, i + Ng2
c               write(6,*)'j,dbzbuffer(j) = ',j,dbzbuffer(j)
               if(j.gt.ibst.and.dbzbuffer(j).gt.-32.)then
		dBzsum = dBzsum + dbzbuffer(j)
                if(bin(j).gt.-800.)then
                 nvelsum=nvelsum+1
                 velsum=velsum+bin(j)
                endif
c                write(6,*)'bin ',bin(j)
                ndbzsum=ndbzsum+1
c                write(6,*)'j,dbzbuffer,ndbzsum,dBzsum = ',
c     1                     j,dbzbuffer(j),ndbzsum,dBzsum
               endif
c                dbzsum = dbzbuffer(i+Ng2)-dbzbuffer(i)
	   end do
           if(ndbzsum.gt.0)then
            dbzsum=dbzsum/ndbzsum
           else
            dbzsum=-32.
           endif
           if(nvelsum.gt.0)then
            velsum=velsum/nvelsum
           else
            velsum=-888.88
           endif
c           write(6,*)'i,dBzsum,dBz_max,dbzbuffer(i) = ',
c     1                i,dBzsum,dBz_max,dbzbuffer(i)
	   if( dBzsum .gt. dBz_max.and.dbzbuffer(i).lt.80)then
		dBz_max = dBzsum
		ibeg = i
c                write(6,*)'ibeg,dBz_max,dBzsum = ',
c     1                     ibeg,dBz_max,dBzsum
                if(nvelsum.gt.0)then
                 vel_max = velsum
                else
                 vel_max = -888.88
                endif
	   end if
	end do
c        write(6,*)'final computed ibeg = ',ibeg
        if(dbz_max.gt.0.)then
         extra=.1*40./dbz_max/abs(sn_lambda)
        else
         extra=0.
        endif
        ibeg=ibeg-int(extra/radres)
        if(ibeg.lt.1)ibeg=1
	iradius = ibeg + Ng2 * 0.5
	if( iradius .le.0) iradius = 1
        if( iradius .gt.nbins) iradius = nbins
	rs_m = radiita( iradius ) * 1000.0
        if(ibeg.lt.1)ibeg=1
	return
	end

